@@ -26,7 +26,20 @@ $(document).on(
 
 $(document).on(
   'click',
-  'a#add-dod-repository-link',
+  'a[data-dod-repository-add]',
+  function(e) {
+    e.preventDefault();
+    $(this).
+      parent('.add-dod-repository-link-container').
+      hide().
+      next('.add-dod-repository-form').
+      show();
+  }
+);
+
+$(document).on(
+  'click',
+  '#add-dod-repository-link',
   function(e) {
     e.preventDefault();
     $(this).hide();
