@@ -33,5 +33,6 @@ $(function() {
 
 $(function() {
   var hash = window.location.hash;
-  hash && $('ul.nav a[href="' + hash + '"]').tab('show');
+  if (hash)
+    $('ul.nav a[href="' + hash + '"]').tab('show');
 });
