@@ -1,21 +1,18 @@
 class CommentsController < ApplicationController
-  before_filter :find_obj, only: [:show_comments, :create]
+  before_action :find_obj, only: [:index, :create]
 
-  def show_comments
+  def index
     @comments = @obj.comments.order(:id)
-    render "show_#{@template}_comments"
   end
 
   def create
-    @obj.comments.create!(body: request.raw_post, user: User.current)
+    @obj.comments.create!(body: request.raw_post, user: User.current, parent_id: params[:parent_id])
     render_ok
   end
 
   def destroy
     comment = Comment.find params[:id]
-    unless comment.check_delete_permissions
-      raise NoPermission.new "No permission to delete #{params[:id]}"
-    end
+    authorize comment, :destroy?
     comment.blank_or_destroy
     render_ok
   end
@@ -25,15 +22,18 @@ class CommentsController < ApplicationController
   def find_obj
     if params[:project]
       if params[:package]
-        @template = 'package'
         @obj = Package.get_by_project_and_name(params[:project], params[:package])
+        @header = { project: @obj.project.name, package: @obj.name }
       else
-        @template = 'project'
         @obj = Project.get_by_name(params[:project])
+        @header = { project: @obj.name }
       end
+    elsif params[:request_number]
+      @obj = BsRequest.find_by_number!(params[:request_number])
+      @header = { request: @obj.number }
     else
-      @template = 'request'
-      @obj = BsRequest.find_by_number!(params[:id])
+      @obj = User.current
+      @header = { user: @obj.login }
     end
   end
 end
