@@ -8,7 +8,7 @@ class TestController < ApplicationController
     if Rails.env.test? || Rails.env.development?
       true
     else
-      render_error message: "This is only accessible for testing environments", :status => 403
+      render_error message: 'This is only accessible for testing environments', status: 403
       false
     end
   end
@@ -24,14 +24,14 @@ class TestController < ApplicationController
 
   # we need a way so the API uprises fully
   def startme
-     if @@started
-       render_ok
-       return
-     end
-     @@started = true
-     WebMock.disable_net_connect!(allow_localhost: true)
-     CONFIG['global_write_through'] = true
-     backend.direct_http(URI("/"))
-     render_ok
+    if @@started
+      render_ok
+      return
+    end
+    @@started = true
+    WebMock.disable_net_connect!(allow_localhost: true)
+    CONFIG['global_write_through'] = true
+    Backend::Api::Server.root
+    render_ok
   end
 end
