@@ -4,13 +4,13 @@ module Webui::SearchHelper
   # @param [Symbol] type :user if the names are logins, :group if they are
   #         group names
   def search_owners_list(names, type = :user)
-    return [] if names.nil? || names.empty?
+    return [] if names.blank?
     output = []
     names.each do |role, list|
       if type == :group
-        output += list.map {|name| "#{name} as #{role}" }
+        output += list.map { |name| "#{name} as #{role}" }
       else
-        output += list.map {|user| user_and_role(user, role)}
+        output += list.map { |user| user_and_role(user, role) }
       end
     end
     output
