@@ -1,10 +1,11 @@
 module Webui::LoadBuildresults
+  # TODO: Make use of the Project#buildresults method and get rid of this duplicated logic
   def fill_status_cache
-    @repohash = Hash.new
-    @statushash = Hash.new
-    @packagenames = Array.new
-    @repostatushash = Hash.new
-    @repostatusdetailshash = Hash.new
+    @repohash = {}
+    @statushash = {}
+    @packagenames = []
+    @repostatushash = {}
+    @repostatusdetailshash = {}
     @failures = 0
 
     @buildresult.elements('result') do |result|
@@ -15,32 +16,32 @@ module Webui::LoadBuildresults
       next unless @repo_filter.nil? || @repo_filter.include?(repo)
       next unless @arch_filter.nil? || @arch_filter.include?(arch)
 
-      @repohash[repo] ||= Array.new
+      @repohash[repo] ||= []
       @repohash[repo] << arch
 
       # package status cache
-      @statushash[repo] ||= Hash.new
-      stathash = @statushash[repo][arch] = Hash.new
+      @statushash[repo] ||= {}
+      stathash = @statushash[repo][arch] = {}
 
       result.elements('status') do |status|
         stathash[status['package']] = status
-        if %w(unresolvable failed broken).include? status['code']
+        if status['code'].in?(['unresolvable', 'failed', 'broken'])
           @failures += 1
         end
       end
       @packagenames << stathash.keys
 
       # repository status cache
-      @repostatushash[repo] ||= Hash.new
-      @repostatusdetailshash[repo] ||= Hash.new
+      @repostatushash[repo] ||= {}
+      @repostatusdetailshash[repo] ||= {}
 
-      if result.has_key? 'state'
-        if result.has_key? 'dirty'
+      if result.key? 'state'
+        if result.key? 'dirty'
           @repostatushash[repo][arch] = 'outdated_' + result['state']
         else
           @repostatushash[repo][arch] = result['state']
         end
-        if result.has_key? 'details'
+        if result.key? 'details'
           @repostatusdetailshash[repo][arch] = result['details']
         end
       end
