@@ -1,5 +1,5 @@
 # This class provides all existing architectures known to OBS
-class Architecture < ActiveRecord::Base
+class Architecture < ApplicationRecord
   #### Includes and extends
   #### Constants
   #### Self config
@@ -7,33 +7,29 @@ class Architecture < ActiveRecord::Base
 
   #### Associations macros (Belongs to, Has one, Has many)
   has_many :repository_architectures, inverse_of: :architecture
-  has_many :repositories, :through => :repository_architectures
+  has_many :repositories, through: :repository_architectures
   has_many :flags
 
   #### Callbacks macros: before_save, after_save, etc.
-  after_save 'Architecture.discard_cache'
-  after_destroy 'Architecture.discard_cache'
+  after_save :discard_cache
+  after_destroy :discard_cache
 
   #### Scopes (first the default_scope macro if is used)
   scope :available, -> { where(available: 1) }
 
   #### Validations macros
-  validates_uniqueness_of :name
-  validates_presence_of :name
+  validates :name, uniqueness: true
+  validates :name, presence: true
 
   #### Class methods using self. (public and then private)
 
-  def self.discard_cache
-    Rails.cache.delete("archcache")
+  def discard_cache
+    Rails.cache.delete('archcache')
   end
 
   def self.archcache
-    return Rails.cache.fetch("archcache") do
-      ret = Hash.new
-      Architecture.all.each do |arch|
-        ret[arch.name] = arch
-      end
-      ret
+    Rails.cache.fetch('archcache') do
+      Architecture.all.map { |arch| [arch.name, arch] }.to_h
     end
   end
 
@@ -46,3 +42,16 @@ class Architecture < ActiveRecord::Base
   end
   #### Alias of methods
 end
+
+# == Schema Information
+#
+# Table name: architectures
+#
+#  id        :integer          not null, primary key
+#  name      :string(255)      not null, indexed
+#  available :boolean          default(FALSE)
+#
+# Indexes
+#
+#  arch_name_index  (name) UNIQUE
+#
