@@ -1,4 +1,4 @@
-class BackendPackage < ActiveRecord::Base
+class BackendPackage < ApplicationRecord
   #### Includes and extends
   #### Constants
   #### Self config
@@ -20,7 +20,7 @@ class BackendPackage < ActiveRecord::Base
   # this is called from the UpdatePackageMetaJob and clockwork
   def self.refresh_dirty
     Package.dirty_backend_package.pluck(:project_id).uniq.each do |project_id|
-      Project.find(project_id).delay(priority: 10).update_packages_if_dirty
+      UpdatePackagesIfDirtyJob.perform_later(project_id)
     end
   end
 
@@ -29,3 +29,27 @@ class BackendPackage < ActiveRecord::Base
   #### Instance methods (public and then protected/private)
   #### Alias of methods
 end
+
+# == Schema Information
+#
+# Table name: backend_packages
+#
+#  package_id  :integer          not null, primary key
+#  links_to_id :integer          indexed
+#  updated_at  :datetime
+#  srcmd5      :string(255)
+#  changesmd5  :string(255)
+#  verifymd5   :string(255)
+#  expandedmd5 :string(255)
+#  error       :text(65535)
+#  maxmtime    :datetime
+#
+# Indexes
+#
+#  index_backend_packages_on_links_to_id  (links_to_id)
+#
+# Foreign Keys
+#
+#  backend_packages_ibfk_1  (package_id => packages.id)
+#  backend_packages_ibfk_2  (links_to_id => packages.id)
+#
