@@ -2,14 +2,11 @@ class Directory < ActiveXML::Node
   def self.hashed(opts)
     project = opts.delete :project
     package = opts.delete :package
-    path = Package.source_path(project, package, nil, opts)
-    d = nil
     begin
-      d = Suse::Backend.get(path).body
+      Xmlhash.parse(Backend::Api::Sources::Package.files(project, package, opts))
     rescue ActiveXML::Transport::Error => e
-      logger.debug "fetching #{path} #{e.inspect}"
+      logger.debug "Error fetching source file list for #{project}/#{package} #{e.inspect}"
       return Xmlhash::XMLHash.new(error: e.summary)
     end
-    Xmlhash.parse(d)
   end
 end
