@@ -1,5 +1,3 @@
-# those contain tons of others
-
 module Event
   # generate an Event class
   class Factory
@@ -7,7 +5,7 @@ module Event
       # as long as there is no overlap, all these Srcsrv prefixes only look silly
       type.gsub!(%r{^SRCSRV_}, '')
       begin
-        ("::Event::" + type.downcase.camelcase).constantize.new params
+        ('::Event::' + type.downcase.camelcase).constantize.new params
       rescue NameError => e
         bt = e.backtrace.join("\n")
         Rails.logger.debug "NameError #{e.inspect} #{bt}"
