@@ -2,8 +2,8 @@ class ApplicationPolicy
   attr_reader :user, :record
 
   def initialize(user, record)
-    raise Pundit::NotAuthorizedError, "must be logged in" unless user
-    raise Pundit::NotAuthorizedError, "record does not exist" unless record
+    raise Pundit::NotAuthorizedError, 'must be logged in' unless user
+    raise Pundit::NotAuthorizedError, 'record does not exist' unless record
     @user = user
     @record = record
   end
