@@ -1,10 +1,8 @@
 class PackagePolicy < ApplicationPolicy
   def branch?
     # same as Package.check_source_access!
-    if @record.disabled_for?('sourceaccess', nil, nil) or record.project.disabled_for?('sourceaccess', nil, nil)
-      unless @user.can_source_access?(@record)
-        return false
-      end
+    if @record.disabled_for?('sourceaccess', nil, nil) || record.project.disabled_for?('sourceaccess', nil, nil)
+      return false unless @user.can_source_access?(@record)
     end
     true
   end
