@@ -1,2 +1,2 @@
 Delayed::Worker.delay_jobs = !Rails.env.test?
-Delayed::Worker.default_queue_name = "quick"
+Delayed::Worker.default_queue_name = 'quick'
