@@ -1,5 +1,5 @@
 class ActiveRecord::Base
   def self.escape_sql(array)
-    self.send(:sanitize_sql_array, array)
+    send(:sanitize_sql_array, array)
   end
 end
