@@ -1,4 +1,4 @@
-class ProductMediumTracking < ActiveRecord::Migration
+class ProductMediumTracking < ActiveRecord::Migration[4.2]
   def up
     add_column :binary_releases, :medium, :string
   end
