@@ -1,4 +1,4 @@
-class CreateUndoneJobsCounter < ActiveRecord::Migration
+class CreateUndoneJobsCounter < ActiveRecord::Migration[4.2]
   def change
     add_column :events, :undone_jobs, :integer, default: 0
   end
