@@ -1,4 +1,4 @@
-class AddUpdateinfoTracking < ActiveRecord::Migration
+class AddUpdateinfoTracking < ActiveRecord::Migration[4.2]
   def up
     create_table :updateinfos do |t|
       t.references :repository, null: false
@@ -9,8 +9,8 @@ class AddUpdateinfoTracking < ActiveRecord::Migration
 
     add_index :updateinfos, :identifier
     add_index :updateinfos, [:repository_id, :package_id]
-    execute("alter table updateinfos add FOREIGN KEY (repository_id) references repositories(id)")
-    execute("alter table updateinfos add FOREIGN KEY (package_id) references packages(id)")
+    execute('alter table updateinfos add FOREIGN KEY (repository_id) references repositories(id)')
+    execute('alter table updateinfos add FOREIGN KEY (package_id) references packages(id)')
   end
 
   def down
