@@ -1,4 +1,4 @@
-class AddOriginForAcceptinfo < ActiveRecord::Migration
+class AddOriginForAcceptinfo < ActiveRecord::Migration[4.2]
   def self.up
     add_column :bs_request_action_accept_infos, :oproject, :string
     add_column :bs_request_action_accept_infos, :opackage, :string
