@@ -1,4 +1,4 @@
-class PatchinfoRequiresIssue < ActiveRecord::Migration
+class PatchinfoRequiresIssue < ActiveRecord::Migration[4.2]
   def up
     add_column :channel_targets, :requires_issue, :boolean
   end
