@@ -1,4 +1,4 @@
-class DelayedJobSpeedup < ActiveRecord::Migration
+class DelayedJobSpeedup < ActiveRecord::Migration[4.2]
   def up
     remove_index :delayed_jobs, :locked_at
   end
