@@ -1,9 +1,9 @@
-class AddTypeToProject < ActiveRecord::Migration
-  class TmpProject < ActiveRecord::Base
+class AddTypeToProject < ActiveRecord::Migration[4.2]
+  class TmpProject < ApplicationRecord
     self.table_name = 'projects'
   end
 
-  class TmpDbProjectType < ActiveRecord::Base
+  class TmpDbProjectType < ApplicationRecord
     self.table_name = 'db_project_types'
   end
 
@@ -15,7 +15,7 @@ class AddTypeToProject < ActiveRecord::Migration
       project.kind = project_type.name
       project.save
     end
-    remove_foreign_key :projects, name: "projects_ibfk_1"
+    remove_foreign_key :projects, name: 'projects_ibfk_1'
     remove_column :projects, :type_id
     drop_table :db_project_types
   end
