@@ -1,5 +1,4 @@
-
-class NewDodTable < ActiveRecord::Migration
+class NewDodTable < ActiveRecord::Migration[4.2]
   def self.up
     create_table :download_repositories do |t|
       t.references :repository, null: false
@@ -11,7 +10,7 @@ class NewDodTable < ActiveRecord::Migration
       t.string :mastersslfingerprint
       t.text :pubkey
     end
-    execute("alter table download_repositories add foreign key (repository_id) references repositories(id)")
+    execute('alter table download_repositories add foreign key (repository_id) references repositories(id)')
 
     # just drop, do not migrate. it was broken and unsupported before.
     drop_table :downloads
