@@ -1,4 +1,4 @@
-class RemoveRequestFromMaintenanceIncident < ActiveRecord::Migration
+class RemoveRequestFromMaintenanceIncident < ActiveRecord::Migration[4.2]
   def self.up
     remove_column :maintenance_incidents, :request
   end
