@@ -1,4 +1,4 @@
-class UniqNumberIndex < ActiveRecord::Migration
+class UniqNumberIndex < ActiveRecord::Migration[4.2]
   def self.up
     remove_index :bs_requests, :number
     add_index :bs_requests, :number, unique: true
