@@ -1,9 +1,9 @@
-class FixBsRequestCounter < ActiveRecord::Migration
-  class TempBsRequest < ActiveRecord::Base
+class FixBsRequestCounter < ActiveRecord::Migration[4.2]
+  class TempBsRequest < ApplicationRecord
     self.table_name = 'bs_requests'
   end
 
-  class TempBsRequestCounter < ActiveRecord::Base
+  class TempBsRequestCounter < ApplicationRecord
     self.table_name = 'bs_request_counter'
   end
 
@@ -11,6 +11,7 @@ class FixBsRequestCounter < ActiveRecord::Migration
     # BsRequestCounter is not set correctly
     # Introduced with 20160321105300_request_counter.rb
     # See https://github.com/openSUSE/open-build-service/issues/2068
+    change_column_default(:bs_request_counter, :counter, 1)
     counter = TempBsRequest.reorder(:number).pluck(:number).last || 0
     TempBsRequestCounter.destroy_all
     TempBsRequestCounter.create!(counter: counter + 1)
