@@ -8,10 +8,10 @@ module OBSApi
 
     def preprocess(fulldoc)
       # request#12345 links
-      fulldoc.gsub!(/(sr|req|request)#(\d+)/i) {|s| "[#{s}](#{request_show_url(number: Regexp.last_match(2))})" }
+      fulldoc.gsub!(/(sr|req|request)#(\d+)/i) { |s| "[#{s}](#{request_show_url(number: Regexp.last_match(2))})" }
       # @user links
       fulldoc.gsub!(/([^\w]|^)@([-\w]+)([^\w]|$)/) \
-                   {"#{Regexp.last_match(1)}[@#{Regexp.last_match(2)}](#{user_show_url(Regexp.last_match(2))})#{Regexp.last_match(3)}" }
+                   { "#{Regexp.last_match(1)}[@#{Regexp.last_match(2)}](#{user_show_url(Regexp.last_match(2))})#{Regexp.last_match(3)}" }
       # bnc#12345 links
       IssueTracker.all.each do |t|
         fulldoc = t.get_markdown(fulldoc)
@@ -19,8 +19,7 @@ module OBSApi
       # sanitize the HTML we get
       Sanitize.fragment(fulldoc, Sanitize::Config.merge(Sanitize::Config::RESTRICTED,
                                                         elements: Sanitize::Config::RESTRICTED[:elements] + ['pre'],
-                                                        remove_contents: true
-                                                       ))
+                                                        remove_contents: true))
     end
   end
 end
