@@ -1,7 +1,5 @@
-#!/usr/bin/env ruby.ruby2.3
+#!/usr/bin/env ruby.ruby2.5
 
 require File.expand_path(File.join(File.dirname(__FILE__), '..', 'config', 'environment'))
 require 'delayed/command'
-require 'workers/import_requests.rb'
-require 'workers/update_issues.rb'
 Delayed::Command.new(ARGV).daemonize
