@@ -1,4 +1,4 @@
-FactoryGirl.define do
+FactoryBot.define do
   factory :architecture do
     sequence(:name) { |n| "arch_factory_#{n}" }
   end
