@@ -1,4 +1,4 @@
-FactoryGirl.define do
+FactoryBot.define do
   factory :relationship do
     role { Role.find_by_title('maintainer') }
 
@@ -15,11 +15,19 @@ FactoryGirl.define do
     factory :relationship_package_user do
       package
       user
+
+      factory :relationship_package_user_as_bugowner do
+        role { Role.find_by_title('bugowner') }
+      end
     end
 
     factory :relationship_package_group do
       package
       group
+
+      factory :relationship_package_group_as_bugowner do
+        role { Role.find_by_title('bugowner') }
+      end
     end
   end
 end
