@@ -1,4 +1,4 @@
-FactoryGirl.define do
+FactoryBot.define do
   factory :release_target do
     repository
     target_repository { create(:repository) }
