@@ -1,6 +1,6 @@
-require "browser_helper"
+require 'browser_helper'
 
-RSpec.feature 'Groups', :type => :feature, :js => true do
+RSpec.feature 'Groups', type: :feature, js: true do
   let(:admin) { create(:admin_user, login: 'king') }
   let(:user) { create(:confirmed_user, login: 'eisendieter') }
   let!(:group) { create(:group, title: 'test_group', users: [admin, user]) }
@@ -12,7 +12,10 @@ RSpec.feature 'Groups', :type => :feature, :js => true do
 
     expect(page).to have_content('Showing 1 to 2 of 2 entries')
     click_link('test_group_b')
-    expect(page).to have_content('This group does not contain users')
+    expect(page).to have_content('Incoming Reviews')
+    find('#group-members-tab').click
+    expect(page).to have_content('This group does not contain users.')
+    expect(page).to have_link('Update group members')
 
     visit groups_path
     expect(page).to have_content('Showing 1 to 2 of 2 entries')
@@ -34,7 +37,7 @@ RSpec.feature 'Groups', :type => :feature, :js => true do
     page.find('input#members', visible: false).set 'eisendieter'
     click_button 'Save'
 
-    within :xpath, "//tr[@id='group-test_group_b']" do
+    within 'form', text: 'Members:' do
       expect(page).to have_content('eisendieter')
     end
   end
