@@ -1,21 +1,24 @@
 ENV['RAILS_ENV'] ||= 'test'
 require File.expand_path('../../config/environment', __FILE__)
 # Prevent database truncation if the environment is production
-abort("The Rails environment is running in production mode!") if Rails.env.production?
+abort('The Rails environment is running in production mode!') if Rails.env.production?
+# for generating test coverage
+require 'simplecov'
+# support test coverage
+require 'support/coverage'
 # as our base helper
 require 'spec_helper'
 # for rails
 require 'rspec/rails'
-# for generating test coverage
-require 'simplecov'
-# for tracking test coverage on
-# https://coveralls.io/github/openSUSE/open-build-service
-require 'coveralls'
+# for pundit policy
+require 'pundit/rspec'
 
 # check for pending migration and apply them before tests are run.
 ActiveRecord::Migration.maintain_test_schema!
 
 RSpec.configure do |config|
+  config.include Haml::Helpers
+
   # load ActiveRecord fixtures
   config.fixture_path = "#{::Rails.root}/spec/fixtures"
 
@@ -26,13 +29,22 @@ RSpec.configure do |config|
   config.filter_rails_from_backtrace!
   # arbitrary gems may also be filtered via:
   # config.filter_gems_from_backtrace("gem name")
+
+  # Wrap each test in Bullet api.
+  if Bullet.enable?
+    config.before(:each) do
+      Bullet.start_request
+    end
+
+    config.after(:each) do
+      Bullet.perform_out_of_channel_notifications if Bullet.notification?
+      Bullet.end_request
+    end
+  end
 end
 
-# support test coverage
-require 'support/coverage'
-
 # support fixtures
-require 'support/factory_girl'
+require 'support/factory_bot'
 
 # support database cleanup
 require 'support/database_cleaner'
@@ -43,5 +55,14 @@ require 'support/backend'
 # support shoulda matcher
 require 'support/shoulda_matchers'
 
-# helper methods for authentification in controllers tests
-require 'support/controllers/controllers_authentification'
+# helper methods for authentication in controllers tests
+require 'support/controllers/controllers_authentication'
+
+# helper methods for authentication in models tests
+require 'support/models/models_authentication'
+
+# support feature switch testing
+require 'feature/testing'
+
+# support Delayed Jobs
+require 'support/delayed_job'
