@@ -1,12 +1,10 @@
-require 'opensuse/backend'
-
 # Allow connections to localhost
 WebMock.disable_net_connect!(allow_localhost: true)
 
 RSpec.configure do |config|
   # build each factory and call #valid? on it
   config.before(:suite) do
-    # Suse::Backend.start_test_backend
+    # Backend::Test.start
   end
 end
 
