@@ -1,12 +1,11 @@
-require File.expand_path(File.dirname(__FILE__) + "/..") + "/test_consistency_helper"
-require File.join(Rails.root, 'app/jobs/consistency_check.rb')
+require File.expand_path(File.dirname(__FILE__) + '/..') + '/test_consistency_helper'
 
 class AAAPreConsistency < ActionDispatch::IntegrationTest
   fixtures :all
 
   def test_resubmit_fixtures
     login_king
-    wait_for_scheduler_start
+    Backend::Test.start(wait_for_scheduler: true)
 
     ConsistencyCheckJob.new.perform
 
