@@ -5,26 +5,26 @@ class InterConnectTests < ActionDispatch::IntegrationTest
   fixtures :all
 
   def setup
-    wait_for_scheduler_start
+    Backend::Test.start(wait_for_scheduler: true)
     reset_auth
   end
 
   def test_anonymous_access
     get '/public/lastevents' # OBS 2.1
     assert_response :success
-    assert_xml_tag :tag => 'events', :attributes => {:sync => 'lost' }
+    assert_xml_tag tag: 'events', attributes: { sync: 'lost' }
     post '/public/lastevents?start=1'
     assert_response :success
-    assert_xml_tag :tag => 'event', :attributes => {:type => 'project' }
-    assert_no_xml_tag :tag => 'events', :attributes => {:sync => 'lost' }
+    assert_xml_tag tag: 'event', attributes: { type: 'project' }
+    assert_no_xml_tag tag: 'events', attributes: { sync: 'lost' }
 
-    post '/public/lastevents', nil # OBS 2.3 and later
+    post '/public/lastevents' # OBS 2.3 and later
     assert_response :success
-    assert_xml_tag :tag => 'events', :attributes => {:sync => 'lost' }
-    post '/public/lastevents', :start => '1'
+    assert_xml_tag tag: 'events', attributes: { sync: 'lost' }
+    post '/public/lastevents', params: { start: '1' }
     assert_response :success
-    assert_xml_tag :tag => 'event', :attributes => {:type => 'project' }
-    assert_no_xml_tag :tag => 'events', :attributes => {:sync => 'lost' }
+    assert_xml_tag tag: 'event', attributes: { type: 'project' }
+    assert_no_xml_tag tag: 'events', attributes: { sync: 'lost' }
 
     # direct access
     get '/public/source/BaseDistro'
@@ -136,21 +136,21 @@ class InterConnectTests < ActionDispatch::IntegrationTest
   def test_backend_support
     get '/public/source/UseRemoteInstance?package=pack1&package=pack2&view=info'
     assert_response :success
-    assert_xml_tag( :tag => 'sourceinfo', :attributes => { :package => 'pack1' } )
-    assert_xml_tag( :tag => 'sourceinfo', :attributes => { :package => 'pack2' } )
-    assert_no_xml_tag( :tag => 'sourceinfo', :attributes => { :package => 'Pack3' } )
+    assert_xml_tag(tag: 'sourceinfo', attributes: { package: 'pack1' })
+    assert_xml_tag(tag: 'sourceinfo', attributes: { package: 'pack2' })
+    assert_no_xml_tag(tag: 'sourceinfo', attributes: { package: 'Pack3' })
 
     # with credentials
     login_tom
     get '/source/UseRemoteInstance?package=pack1&package=pack2&view=info'
     assert_response :success
-    assert_xml_tag( :tag => 'sourceinfo', :attributes => { :package => 'pack1' } )
-    assert_xml_tag( :tag => 'sourceinfo', :attributes => { :package => 'pack2' } )
-    assert_no_xml_tag( :tag => 'sourceinfo', :attributes => { :package => 'Pack3' } )
+    assert_xml_tag(tag: 'sourceinfo', attributes: { package: 'pack1' })
+    assert_xml_tag(tag: 'sourceinfo', attributes: { package: 'pack2' })
+    assert_no_xml_tag(tag: 'sourceinfo', attributes: { package: 'Pack3' })
   end
 
   def test_backend_post_with_forms
-    post '/public/lastevents', 'filter=pack1&filter=pack2'
+    post '/public/lastevents', params: 'filter=pack1&filter=pack2'
     assert_response :success
   end
 
@@ -158,7 +158,7 @@ class InterConnectTests < ActionDispatch::IntegrationTest
     login_tom
 
     # use repo
-    put '/source/home:tom:testing/_meta', '<project name="home:tom:testing">
+    put '/source/home:tom:testing/_meta', params: '<project name="home:tom:testing">
 	  <title />
 	  <description />
 	  <repository name="repo">
@@ -172,7 +172,7 @@ class InterConnectTests < ActionDispatch::IntegrationTest
     login_king
     get '/source/RemoteInstance/_meta'
     assert_response :success
-    put '/source/RemoteInstance/_meta', @response.body.dup
+    put '/source/RemoteInstance/_meta', params: @response.body.dup
     assert_response :success
 
     # cleanup
@@ -202,27 +202,27 @@ class InterConnectTests < ActionDispatch::IntegrationTest
     assert_response :success
     get '/source/RemoteInstance:BaseDistro/pack1?view=info&parse=1' # licensedigger needs it
     assert_response :success
-    assert_xml_tag( :tag => 'sourceinfo', :attributes => { :package => 'pack1' } )
-    post '/source/RemoteInstance:BaseDistro/pack1', :cmd => 'showlinked'
+    assert_xml_tag(tag: 'sourceinfo', attributes: { package: 'pack1' })
+    post '/source/RemoteInstance:BaseDistro/pack1', params: { cmd: 'showlinked' }
     assert_response :success
-    post '/source/RemoteInstance:BaseDistro/pack1', :cmd => 'branch'
+    post '/source/RemoteInstance:BaseDistro/pack1', params: { cmd: 'branch' }
     assert_response :success
     get '/source/RemoteInstance:BaseDistro2.0:LinkedUpdateProject'
     assert_response :success
-    assert_xml_tag( :tag => 'directory', :children => { :count => 1 } ) # backend does not provide a counter
+    assert_xml_tag(tag: 'directory', children: { count: 1 }) # backend does not provide a counter
     get '/source/RemoteInstance:BaseDistro2.0:LinkedUpdateProject?expand=1'
     assert_response :success
-    assert_xml_tag( :tag => 'entry', :attributes => { :name => 'pack2', :originproject => 'RemoteInstance:BaseDistro2.0' } )
-    assert_xml_tag( :tag => 'entry', :attributes => { :name => 'pack2.linked', :originproject => 'RemoteInstance:BaseDistro2.0' } )
+    assert_xml_tag(tag: 'entry', attributes: { name: 'pack2', originproject: 'RemoteInstance:BaseDistro2.0' })
+    assert_xml_tag(tag: 'entry', attributes: { name: 'pack2.linked', originproject: 'RemoteInstance:BaseDistro2.0' })
     # test binary operations
     login_king
-    post '/build/RemoteInstance:BaseDistro', :cmd => 'wipe', :package => 'pack1'
+    post '/build/RemoteInstance:BaseDistro', params: { cmd: 'wipe', package: 'pack1' }
     assert_response 403
-    post '/build/RemoteInstance:BaseDistro', :cmd => 'rebuild', :package => 'pack1'
+    post '/build/RemoteInstance:BaseDistro', params: { cmd: 'rebuild', package: 'pack1' }
     assert_response 403
-    post '/build/RemoteInstance:BaseDistro', :cmd => 'wipe'
+    post '/build/RemoteInstance:BaseDistro', params: { cmd: 'wipe' }
     assert_response 403
-    post '/build/RemoteInstance:BaseDistro', :cmd => 'rebuild'
+    post '/build/RemoteInstance:BaseDistro', params: { cmd: 'rebuild' }
     assert_response 403
     # the webui requires this for repository browsing in advanced repo add mask
     get '/build/RemoteInstance:BaseDistro'
@@ -253,11 +253,11 @@ class InterConnectTests < ActionDispatch::IntegrationTest
     assert_response :success
     get '/build/RemoteInstance:BaseDistro/_result?package=pack1&lastbuild=1' # for licensedigger
     assert_response :success
-    assert_xml_tag( :tag => 'result', :attributes => { :project => "BaseDistro", :repository => 'BaseDistro_repo', :arch => 'i586' } )
-    get "/build/RemoteInstance:BaseDistro/_result?view=summary"
+    assert_xml_tag(tag: 'result', attributes: { project: 'BaseDistro', repository: 'BaseDistro_repo', arch: 'i586' })
+    get '/build/RemoteInstance:BaseDistro/_result?view=summary'
     assert_response :success
-    assert_xml_tag( :tag => 'result', :attributes => { :project => "BaseDistro", :repository => 'BaseDistro_repo', :arch => 'i586' } )
-    assert_xml_tag( :tag => 'summary' )
+    assert_xml_tag(tag: 'result', attributes: { project: 'BaseDistro', repository: 'BaseDistro_repo', arch: 'i586' })
+    assert_xml_tag(tag: 'summary')
 
     # direct access to remote instance, not existing project/package
     login_tom
@@ -282,7 +282,7 @@ class InterConnectTests < ActionDispatch::IntegrationTest
     assert_match(/no pubkey available/, @response.body)
 
     # access to local project with project link to remote, and via a local indirection
-    %w(UseRemoteInstance UseRemoteInstanceIndirect).each do |project|
+    ['UseRemoteInstance', 'UseRemoteInstanceIndirect'].each do |project|
       get "/source/#{project}"
       assert_response :success
       get "/source/#{project}/_meta"
@@ -293,29 +293,28 @@ class InterConnectTests < ActionDispatch::IntegrationTest
       assert_response :success
       get "/source/#{project}/pack2.linked/package.spec"
       assert_response :success
-      post "/source/#{project}/pack2", :cmd => 'showlinked'
+      post "/source/#{project}/pack2", params: { cmd: 'showlinked' }
       assert_response :success
-      post "/source/#{project}/pack2", :cmd => 'branch'
+      post "/source/#{project}/pack2", params: { cmd: 'branch' }
       assert_response :success
       get "/source/#{project}"
       assert_response :success
-      assert_xml_tag( :tag => 'directory', :attributes => { :count => '0' } )
+      assert_xml_tag(tag: 'directory', attributes: { count: '0' })
       get "/source/#{project}?expand=1"
       assert_response :success
-if $ENABLE_BROKEN_TEST
-# FIXME2.4: remote packages get not added yet.
-      assert_xml_tag( :tag => 'directory', :attributes => { :count => '1' } )
-      assert_xml_tag( :tag => 'entry', :attributes => { :name => 'pack1', :originproject => 'BaseDistro2.0' } )
-end
+      next unless @ENABLE_BROKEN_TEST
+      # FIXME2.4: remote packages get not added yet.
+      assert_xml_tag(tag: 'directory', attributes: { count: '1' })
+      assert_xml_tag(tag: 'entry', attributes: { name: 'pack1', originproject: 'BaseDistro2.0' })
     end
 
     # check access to binaries of remote instance
     get '/build/UseRemoteInstance/pop/i586/pack2.linked/_log'
     assert_response :success
     # test source modifications
-    post '/build/UseRemoteInstance/pack2', :cmd => 'set_flag'
+    post '/build/UseRemoteInstance/pack2', params: { cmd: 'set_flag' }
     assert_response 403
-    post '/build/UseRemoteInstance/pack2', :cmd => 'unlock'
+    post '/build/UseRemoteInstance/pack2', params: { cmd: 'unlock' }
     assert_response 403
     get '/source/UseRemoteInstance/NotExisting'
     assert_response 404
@@ -325,13 +324,13 @@ end
     assert_response 404
     # test binary operations
     login_king
-    post '/build/UseRemoteInstance', :cmd => 'wipe', :package => 'pack2.linked'
+    post '/build/UseRemoteInstance', params: { cmd: 'wipe', package: 'pack2.linked' }
     assert_response :success
-    post '/build/UseRemoteInstance', :cmd => 'rebuild', :package => 'pack2.linked'
+    post '/build/UseRemoteInstance', params: { cmd: 'rebuild', package: 'pack2.linked' }
     assert_response :success
-    post '/build/UseRemoteInstance', :cmd => 'wipe'
+    post '/build/UseRemoteInstance', params: { cmd: 'wipe' }
     assert_response :success
-    post '/build/UseRemoteInstance', :cmd => 'rebuild'
+    post '/build/UseRemoteInstance', params: { cmd: 'rebuild' }
     assert_response :success
 
     # access via a local package linking to a remote package
@@ -341,7 +340,7 @@ end
     ret = Xmlhash.parse(@response.body)['linkinfo']
     xsrcmd5 = ret['xsrcmd5']
     assert_not_nil xsrcmd5
-    post '/source/LocalProject/remotepackage', :cmd => 'showlinked'
+    post '/source/LocalProject/remotepackage', params: { cmd: 'showlinked' }
     assert_response :success
     get '/source/LocalProject/remotepackage/_meta'
     assert_response :success
@@ -354,7 +353,7 @@ end
     assert_equal 'pack1', ret['package']
     get "/source/LocalProject/remotepackage/my_file?rev=#{xsrcmd5}"
     assert_response :success
-    post '/source/LocalProject/remotepackage', :cmd => 'branch'
+    post '/source/LocalProject/remotepackage', params: { cmd: 'branch' }
     assert_response :success
     get "/source/LocalProject/remotepackage/_link?rev=#{xsrcmd5}"
     assert_response 404
@@ -362,13 +361,13 @@ end
     assert_response 404
     # test binary operations
     login_king
-    post '/build/LocalProject', :cmd => 'wipe', :package => 'remotepackage'
+    post '/build/LocalProject', params: { cmd: 'wipe', package: 'remotepackage' }
     assert_response :success
-    post '/build/LocalProject', :cmd => 'rebuild', :package => 'remotepackage'
+    post '/build/LocalProject', params: { cmd: 'rebuild', package: 'remotepackage' }
     assert_response :success
-    post '/build/LocalProject', :cmd => 'wipe'
+    post '/build/LocalProject', params: { cmd: 'wipe' }
     assert_response :success
-    post '/build/LocalProject', :cmd => 'rebuild'
+    post '/build/LocalProject', params: { cmd: 'rebuild' }
     assert_response :success
 
     # cleanup
@@ -386,23 +385,22 @@ end
     login_king
     delete '/source/RemoteInstance:BaseDistro2.0'
     assert_response 403
-    assert_xml_tag :tag => 'status', :attributes => { :code => 'delete_project_no_permission' }
+    assert_xml_tag tag: 'status', attributes: { code: 'delete_project_no_permission' }
     delete '/source/RemoteInstance:BaseDistro2.0/pack2'
     assert_response 403
-    assert_xml_tag :tag => 'status', :attributes => { :code => 'delete_package_no_permission' }
-    post '/source/RemoteInstance:BaseDistro2.0/package', :cmd => :copy, :oproject => 'BaseDistro2.0', :opackage => 'pack2'
+    assert_xml_tag tag: 'status', attributes: { code: 'delete_package_no_permission' }
+    post '/source/RemoteInstance:BaseDistro2.0/package', params: { cmd: :copy, oproject: 'BaseDistro2.0', opackage: 'pack2' }
     assert_response 403
-    assert_xml_tag :tag => 'status', :attributes => { :code => 'cmd_execution_no_permission' }
-    put '/source/RemoteInstance:BaseDistro2.0/pack/_meta',
-        '<package name="pack" project="RemoteInstance:BaseDistro2.0">
+    assert_xml_tag tag: 'status', attributes: { code: 'cmd_execution_no_permission' }
+    put '/source/RemoteInstance:BaseDistro2.0/pack/_meta', params: '<package name="pack" project="RemoteInstance:BaseDistro2.0">
            <title/><description/></package>'
     assert_response 403
-    assert_xml_tag :tag => 'status', :attributes => { :code => 'create_package_no_permission' }
+    assert_xml_tag tag: 'status', attributes: { code: 'create_package_no_permission' }
   end
 
   def test_invalid_submit_to_remote_instance
     login_king
-    post '/request?cmd=create', '<request>
+    post '/request?cmd=create', params: '<request>
                                    <action type="submit">
                                      <source project="BaseDistro" package="pack1" rev="1"/>
                                      <target project="RemoteInstance:home:tom" package="pack1"/>
@@ -410,18 +408,18 @@ end
                                    <state name="new" />
                                  </request>'
     assert_response 400
-    assert_xml_tag :tag => 'status', :attributes => { :code => 'remote_target' }
+    assert_xml_tag tag: 'status', attributes: { code: 'remote_target' }
   end
 
   def test_submit_requests_from_remote
     login_king
-    post '/source/LocalProject/pack2.linked', :cmd => :copy, :oproject => 'LocalProject', :opackage => 'remotepackage'
+    post '/source/LocalProject/pack2.linked', params: { cmd: :copy, oproject: 'LocalProject', opackage: 'remotepackage' }
     assert_response :success
 
     login_tom
     # FIXME: submission from a remote project is not yet supported "RemoteInstance:BaseDistro2.0"
-    %w(LocalProject UseRemoteInstance).each do |prj|
-      post '/request?cmd=create', '<request>
+    ['LocalProject', 'UseRemoteInstance'].each do |prj|
+      post '/request?cmd=create', params: '<request>
                                    <action type="submit">
                                      <source project="' + prj + '" package="pack2.linked" rev="1"/>
                                      <target project="home:tom" package="pack1"/>
@@ -449,20 +447,20 @@ end
   def test_copy_and_diff_package
     # do copy commands twice to test it with existing target and without
     login_tom
-    post '/source/LocalProject/temporary', :cmd => :copy, :oproject => 'LocalProject', :opackage => 'remotepackage'
+    post '/source/LocalProject/temporary', params: { cmd: :copy, oproject: 'LocalProject', opackage: 'remotepackage' }
     assert_response :success
-    post '/source/LocalProject/temporary', :cmd => :copy, :oproject => 'LocalProject', :opackage => 'remotepackage'
+    post '/source/LocalProject/temporary', params: { cmd: :copy, oproject: 'LocalProject', opackage: 'remotepackage' }
     assert_response :success
     delete '/source/LocalProject/temporary'
     assert_response :success
-    post '/source/LocalProject/temporary', :cmd => :copy, :oproject => 'UseRemoteInstance', :opackage => 'pack2.linked'
+    post '/source/LocalProject/temporary', params: { cmd: :copy, oproject: 'UseRemoteInstance', opackage: 'pack2.linked' }
     assert_response :success
-    post '/source/LocalProject/temporary', :cmd => :copy, :oproject => 'RemoteInstance:BaseDistro', :opackage => 'pack1'
+    post '/source/LocalProject/temporary', params: { cmd: :copy, oproject: 'RemoteInstance:BaseDistro', opackage: 'pack1' }
     assert_response :success
 
-    post '/source/LocalProject/temporary', :cmd => :diff, :oproject => 'LocalProject', :opackage => 'remotepackage'
+    post '/source/LocalProject/temporary', params: { cmd: :diff, oproject: 'LocalProject', opackage: 'remotepackage' }
     assert_response :success
-    post '/source/LocalProject/temporary', :cmd => :diff, :oproject => 'UseRemoteInstance', :opackage => 'pack2.linked'
+    post '/source/LocalProject/temporary', params: { cmd: :diff, oproject: 'UseRemoteInstance', opackage: 'pack2.linked' }
     assert_response :success
 
     login_king
@@ -473,28 +471,29 @@ end
   def test_diff_package
     login_tom
 
-# FIXME: not supported in api atm
-#    post "/source/RemoteInstance:BaseDistro/pack1", :cmd => :branch, :target_project => "LocalProject", :target_package => "branchedpackage"
-#    assert_response :success
+    # FIXME: not supported in api atm
+    # post "/source/RemoteInstance:BaseDistro/pack1", :cmd => :branch, :target_project => "LocalProject", :target_package => "branchedpackage"
+    # assert_response :success
 
-    Suse::Backend.put( '/source/LocalProject/newpackage/_meta?user=king', Package.find_by_project_and_name('LocalProject', 'newpackage').to_axml)
-    Suse::Backend.put( '/source/LocalProject/newpackage/new_file?user=king', 'adding stuff')
-    post '/source/LocalProject/newpackage', :cmd => :diff, :oproject => 'RemoteInstance:BaseDistro', :opackage => 'pack1'
+    Backend::Connection.put('/source/LocalProject/newpackage/_meta?user=king',
+                            Package.find_by_project_and_name('LocalProject', 'newpackage').to_axml)
+    Backend::Connection.put('/source/LocalProject/newpackage/new_file?user=king', 'adding stuff')
+    post '/source/LocalProject/newpackage', params: { cmd: :diff, oproject: 'RemoteInstance:BaseDistro', opackage: 'pack1' }
     assert_response :success
   end
 
-# FIXME: backend does not support project copy from remote
-# def test_copy_project
-#   login_tom
-#   get "/source/RemoteInstance:BaseDistro"
-#   assert_response :success
-#   post "/source/home:tom:TEMPORARY?cmd=copy&oproject=RemoteInstance:BaseDistro&nodelay=1"
-#   assert_response :success
-#   get "/source/home:tom:TEMPORARY"
-#   assert_response :success
-#   delete "/source/home:tom:TEMPORARY"
-#   assert_response :success
-# end
+  # FIXME: backend does not support project copy from remote
+  # def test_copy_project
+  #   login_tom
+  #   get "/source/RemoteInstance:BaseDistro"
+  #   assert_response :success
+  #   post "/source/home:tom:TEMPORARY?cmd=copy&oproject=RemoteInstance:BaseDistro&nodelay=1"
+  #   assert_response :success
+  #   get "/source/home:tom:TEMPORARY"
+  #   assert_response :success
+  #   delete "/source/home:tom:TEMPORARY"
+  #   assert_response :success
+  # end
 
   def test_get_packagelist_with_hidden_remoteurlproject
     login_tom
@@ -537,23 +536,23 @@ end
   end
 
   def test_setup_remote_propject
-    p='<project name="home:tom:remote"> <title/> <description/>  <remoteurl>http://localhost</remoteurl> </project>'
+    p = '<project name="home:tom:remote"> <title/> <description/>  <remoteurl>http://localhost</remoteurl> </project>'
 
     login_tom
-    put '/source/home:tom:remote/_meta', p
+    put '/source/home:tom:remote/_meta', params: p
     assert_response 403
 
     login_king
-    put '/source/home:tom:remote/_meta', p
+    put '/source/home:tom:remote/_meta', params: p
     assert_response :success
-    p='<project name="home:tom:remote"> <title/> <description/>  <remoteurl>http://localhost2</remoteurl> </project>'
-    put '/source/home:tom:remote/_meta', p
+    p = '<project name="home:tom:remote"> <title/> <description/>  <remoteurl>http://localhost2</remoteurl> </project>'
+    put '/source/home:tom:remote/_meta', params: p
     assert_response :success
     get '/source/home:tom:remote/_meta'
     assert_response :success
-    assert_xml_tag :tag => 'remoteurl', :content => 'http://localhost2'
-    p='<project name="home:tom:remote"> <title/> <description/>  </project>'
-    put '/source/home:tom:remote/_meta', p
+    assert_xml_tag tag: 'remoteurl', content: 'http://localhost2'
+    p = '<project name="home:tom:remote"> <title/> <description/>  </project>'
+    put '/source/home:tom:remote/_meta', params: p
     assert_response :success
 
     # cleanup
@@ -566,25 +565,25 @@ end
     # package meta
     get '/source/home:Iggy/TestPack/_meta'
     assert_response :success
-    assert_xml_tag :tag => 'person'
+    assert_xml_tag tag: 'person'
     get '/source/RemoteInstance:home:Iggy/TestPack/_meta'
     assert_response :success
-    assert_no_xml_tag :tag => 'person'
+    assert_no_xml_tag tag: 'person'
 
     # project meta
     get '/source/home:Iggy/_meta'
     assert_response :success
-    assert_xml_tag :tag => 'person'
+    assert_xml_tag tag: 'person'
     get '/source/RemoteInstance:home:Iggy/_meta'
     assert_response :success
-    assert_no_xml_tag :tag => 'person'
+    assert_no_xml_tag tag: 'person'
   end
 
   def test_remove_broken_link
     login_Iggy
-    put '/source/home:Iggy/TestLinkPack/_meta', "<package project='home:Iggy' name='TestLinkPack'> <title/> <description/> </package>"
+    put '/source/home:Iggy/TestLinkPack/_meta', params: "<package project='home:Iggy' name='TestLinkPack'> <title/> <description/> </package>"
     assert_response :success
-    put '/source/home:Iggy/TestLinkPack/_link', "<link project='RemoteInstance:home:Iggy' package='TestPack' rev='invalid' />"
+    put '/source/home:Iggy/TestLinkPack/_link', params: "<link project='RemoteInstance:home:Iggy' package='TestPack' rev='invalid' />"
     assert_response :success
     get '/source/home:Iggy/TestLinkPack'
     assert_response :success
@@ -602,9 +601,8 @@ end
 
   def test_submit_from_remote
     login_Iggy
-    raw_post '/request?cmd=create',
-             "<request><action type='submit'><source project='RemoteInstance:home:Iggy' package='TestPack'/>
-              <target project='home:Iggy' package='TEMPORARY'/></action></request>"
+    post '/request?cmd=create', params: "<request><action type='submit'><source project='RemoteInstance:home:Iggy' package='TestPack'/>
+          <target project='home:Iggy' package='TEMPORARY'/></action></request>"
     assert_response :success
     id = Xmlhash.parse(@response.body)['id']
     post "/request/#{id}?cmd=changestate&newstate=accepted"
@@ -616,10 +614,9 @@ end
     assert_response :success
 
     # cleanup option can not work, do not allow to create requests
-    raw_post '/request?cmd=create',
-             "<request><action type='submit'><source project='RemoteInstance:home:Iggy' package='TestPack'/>
-              <target project='home:Iggy' package='TEMPORARY'/> <options><sourceupdate>cleanup</sourceupdate></options></action></request>"
+    post '/request?cmd=create', params: "<request><action type='submit'><source project='RemoteInstance:home:Iggy' package='TestPack'/>
+          <target project='home:Iggy' package='TEMPORARY'/> <options><sourceupdate>cleanup</sourceupdate></options></action></request>"
     assert_response 400
-    assert_xml_tag :tag => 'status', :attributes => { :code => 'not_supported' }
+    assert_xml_tag tag: 'status', attributes: { code: 'not_supported' }
   end
 end
