@@ -5,7 +5,7 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
   fixtures :all
 
   def setup
-    wait_for_scheduler_start
+    Backend::Test.start(wait_for_scheduler: true)
     reset_auth
   end
 
@@ -16,51 +16,45 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     login_tom
     get '/service'
     assert_response :success
-    assert_xml_tag :tag => 'servicelist'
+    assert_xml_tag tag: 'servicelist'
 
     # not using assert_xml_tag for doing a propper error message on missing
     # source service packages
     download_url = set_version = download_files = nil
     services = ActiveXML::Node.new(@response.body)
     services.each(:service) do |s|
-      if s.value(:name) == 'download_url'
-        download_url = 1
-      end
-      if s.value(:name) == 'download_files'
-        download_files = 1
-      end
-      if s.value(:name) == 'set_version'
-        set_version = 1
-      end
+      download_url = 1 if s.value(:name) == 'download_url'
+      download_files = 1 if s.value(:name) == 'download_files'
+      set_version = 1 if s.value(:name) == 'set_version'
     end
-    assert_xml_tag :tag => 'service', :attributes => { :name => 'set_version' }
-    assert_xml_tag :tag => 'service', :attributes => { :name => 'download_url' }
-    assert_xml_tag :tag => 'service', :attributes => { :name => 'download_files' }
+    assert_xml_tag tag: 'service', attributes: { name: 'set_version' }
+    assert_xml_tag tag: 'service', attributes: { name: 'download_url' }
+    assert_xml_tag tag: 'service', attributes: { name: 'download_files' }
   end
 
   def test_combine_project_service_list
     login_king
 
-    raw_put '/source/BaseDistro2.0/_project/_service',
-            '<services> <service name="set_version" > <param name="version">0815</param> </service> </services>'
+    put '/source/BaseDistro2.0/_project/_service',
+        params: '<services> <service name="set_version" > <param name="version">0815</param> </service> </services>'
     assert_response :success
-    raw_put '/source/BaseDistro2.0:LinkedUpdateProject/_project/_service', '<services> <service name="download_files" /> </services>'
+    put '/source/BaseDistro2.0:LinkedUpdateProject/_project/_service', params: '<services> <service name="download_files" /> </services>'
     assert_response :success
 
     login_tom
-    post '/source/BaseDistro2.0:LinkedUpdateProject/pack2', :cmd => 'branch'
+    post '/source/BaseDistro2.0:LinkedUpdateProject/pack2', params: { cmd: 'branch' }
     assert_response :success
-    raw_put '/source/home:tom:branches:BaseDistro2.0:LinkedUpdateProject/_project/_service',
-            '<services> <service name="download_url" > <param name="host">blahfasel</param> </service> </services>'
+    put '/source/home:tom:branches:BaseDistro2.0:LinkedUpdateProject/_project/_service',
+        params: '<services> <service name="download_url" > <param name="host">blahfasel</param> </service> </services>'
     assert_response :success
 
-    post '/source/home:tom:branches:BaseDistro2.0:LinkedUpdateProject/pack2', :cmd => 'getprojectservices'
+    post '/source/home:tom:branches:BaseDistro2.0:LinkedUpdateProject/pack2', params: { cmd: 'getprojectservices' }
     assert_response :success
-    assert_xml_tag( :tag => 'service', :attributes => { :name => 'download_files' } )
-    assert_xml_tag( :parent => { :tag => 'service', :attributes => { :name => 'download_url' } },
-                    :tag => 'param', :attributes => { :name => 'host' }, :content => 'blahfasel')
-    assert_xml_tag( :parent => { :tag => 'service', :attributes => { :name => 'set_version' } },
-                    :tag => 'param', :attributes => { :name => 'version' }, :content => '0815')
+    assert_xml_tag(tag: 'service', attributes: { name: 'download_files' })
+    assert_xml_tag(parent: { tag: 'service', attributes: { name: 'download_url' } },
+                    tag: 'param', attributes: { name: 'host' }, content: 'blahfasel')
+    assert_xml_tag(parent: { tag: 'service', attributes: { name: 'set_version' } },
+                    tag: 'param', attributes: { name: 'version' }, content: '0815')
 
     # cleanup
     login_king
@@ -74,31 +68,30 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
 
   def test_run_source_service
     login_tom
-    raw_put '/source/home:tom/service/_meta', "<package project='home:tom' name='service'> <title /> <description /> </package>"
+    put '/source/home:tom/service/_meta', params: "<package project='home:tom' name='service'> <title /> <description /> </package>"
     assert_response :success
-    raw_put '/source/home:tom/service/pack.spec', "# Comment \nName: pack\nVersion: 12\nRelease: 9\nSummary: asd"
+    put '/source/home:tom/service/pack.spec', params: "# Comment \nName: pack\nVersion: 12\nRelease: 9\nSummary: asd"
     assert_response :success
 
-    raw_put '/source/home:tom/service/_service', '<services> <service name="not_existing" /> </services>'
+    put '/source/home:tom/service/_service', params: '<services> <service name="not_existing" /> </services>'
     assert_response :success
-    assert_nil Package.find_by_project_and_name("home:tom", "service").backend_package.error
+    assert_nil Package.find_by_project_and_name('home:tom', 'service').backend_package.error
     post '/source/home:tom/service?cmd=runservice'
     assert_response :success
     post '/source/home:tom/service?cmd=waitservice'
     assert_response 400 # broken service
     get '/source/home:tom/service'
     assert_response :success
-    assert_xml_tag :tag => 'serviceinfo', :attributes => { :code => 'failed' }
+    assert_xml_tag tag: 'serviceinfo', attributes: { code: 'failed' }
     UpdateNotificationEvents.new.perform
     get '/source/home:tom/service?expand=1'
     assert_response 400
     assert_match(/not_existing/, @response.body) # multiple line error shows up
 
-    raw_put '/source/home:tom/service/_service',
-            '<services> <service name="download_url" >
-             <param name="host">localhost</param>
-             <param name="path">/directory/subdirectory/file</param>
-             </service> </services>'
+    put '/source/home:tom/service/_service', params: '<services> <service name="download_url" >
+         <param name="host">localhost</param>
+         <param name="path">/directory/subdirectory/file</param>
+         </service> </services>'
     assert_response :success
     post '/source/home:tom/service?cmd=runservice'
     assert_response :success
@@ -106,16 +99,16 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     assert_response :success
     get '/source/home:tom/service'
     assert_response :success
-    assert_xml_tag :tag => 'serviceinfo', :attributes => { :code => 'succeeded' }
-    assert_no_xml_tag :parent => { :tag => 'serviceinfo' }, :tag => 'error'
+    assert_xml_tag tag: 'serviceinfo', attributes: { code: 'succeeded' }
+    assert_no_xml_tag parent: { tag: 'serviceinfo' }, tag: 'error'
     get '/source/home:tom/service/_service:download_url:file?expand=1'
     assert_response :success
-    post '/source/home:tom/service?cmd=servicediff', nil
+    post '/source/home:tom/service?cmd=servicediff'
     assert_match(/download_url:file/, @response.body)
     assert_response :success
 
     # submit to other package
-    raw_post '/request?cmd=create', '<request>
+    post '/request?cmd=create', params: '<request>
                                    <action type="submit">
                                      <source project="home:tom" package="service"/>
                                      <target project="home:tom" package="new_package"/>
@@ -133,25 +126,25 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     # same result as in source package
     get '/source/home:tom/new_package'
     assert_response :success
-    assert_xml_tag :tag => 'serviceinfo', :attributes => { :code => 'succeeded' }
-    assert_no_xml_tag :parent => { :tag => 'serviceinfo' }, :tag => 'error'
+    assert_xml_tag tag: 'serviceinfo', attributes: { code: 'succeeded' }
+    assert_no_xml_tag parent: { tag: 'serviceinfo' }, tag: 'error'
     get '/source/home:tom/new_package/_service:download_url:file?expand=1'
     assert_response :success
 
     # branch and submit requsts
-    post '/source/home:tom/service', :cmd => 'branch'
+    post '/source/home:tom/service', params: { cmd: 'branch' }
     assert_response :success
-    assert_nil Package.find_by_project_and_name("home:tom:branches:home:tom", "service").backend_package.error
-    put '/source/home:tom:branches:home:tom/service/new_file', 'content'
+    assert_nil Package.find_by_project_and_name('home:tom:branches:home:tom', 'service').backend_package.error
+    put '/source/home:tom:branches:home:tom/service/new_file', params: 'content'
     assert_response :success
-    assert_nil Package.find_by_project_and_name("home:tom:branches:home:tom", "service").backend_package.error
+    assert_nil Package.find_by_project_and_name('home:tom:branches:home:tom', 'service').backend_package.error
     post '/source/home:tom:branches:home:tom/service?cmd=waitservice'
     assert_response :success
     UpdateNotificationEvents.new.perform
-    assert_nil Package.find_by_project_and_name("home:tom:branches:home:tom", "service").backend_package.error
+    assert_nil Package.find_by_project_and_name('home:tom:branches:home:tom', 'service').backend_package.error
     get '/source/home:tom:branches:home:tom/service/_service:download_url:file?expand=1'
     assert_response :success
-    post '/request?cmd=create', '<request>
+    post '/request?cmd=create', params: '<request>
                                    <action type="submit">
                                      <source project="home:tom:branches:home:tom" package="service"/>
                                      <target project="home:tom" package="service"/>
@@ -176,19 +169,19 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     get '/source/home:tom/service/_service:download_url:file?expand=1'
     assert_response :success
     original_file = @response.body
-    post '/source/home:tom/copied_service', :cmd => 'copy', :noservice => '1', :opackage => 'service', :oproject => 'home:tom'
+    post '/source/home:tom/copied_service', params: { cmd: 'copy', noservice: '1', opackage: 'service', oproject: 'home:tom' }
     assert_response :success
     get '/source/home:tom/copied_service?expand=1'
     assert_response :success
-    assert_xml_tag :tag => "entry", :attributes => { :name => "_service:download_url:file" }
+    assert_xml_tag tag: 'entry', attributes: { name: '_service:download_url:file' }
     get '/source/home:tom/copied_service/_service:download_url:file?expand=1'
     assert_response :success
     assert_equal(@response.body, original_file)
-    post '/source/home:tom/copied_service', :cmd => 'copy', :opackage => 'service', :oproject => 'home:tom'
+    post '/source/home:tom/copied_service', params: { cmd: 'copy', opackage: 'service', oproject: 'home:tom' }
     assert_response :success
     get '/source/home:tom/copied_service?expand=1'
     assert_response :success
-    assert_xml_tag :tag => "entry", :attributes => { :name => "_service:download_url:file" }
+    assert_xml_tag tag: 'entry', attributes: { name: '_service:download_url:file' }
     get '/source/home:tom/copied_service/_service:download_url:file?expand=1'
     assert_response :success
     delete '/source/home:tom/copied_service'
@@ -196,19 +189,19 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     assert_not_equal(@response.body, original_file)
 
     # project copy tests
-    post '/source/home:tom:COPY', :cmd => 'copy', :noservice => '1', :oproject => 'home:tom'
+    post '/source/home:tom:COPY', params: { cmd: 'copy', noservice: '1', oproject: 'home:tom' }
     assert_response :success
     get '/source/home:tom:COPY/service?expand=1'
     assert_response :success
-    assert_xml_tag :tag => "entry", :attributes => { :name => "_service:download_url:file" }
+    assert_xml_tag tag: 'entry', attributes: { name: '_service:download_url:file' }
     get '/source/home:tom:COPY/service/_service:download_url:file?expand=1'
     assert_response :success
     assert_equal(@response.body, original_file)
-    post '/source/home:tom:COPY/service', :cmd => 'copy', :oproject => 'home:tom'
+    post '/source/home:tom:COPY/service', params: { cmd: 'copy', oproject: 'home:tom' }
     assert_response :success
     get '/source/home:tom:COPY/service?expand=1'
     assert_response :success
-    assert_xml_tag :tag => "entry", :attributes => { :name => "_service:download_url:file" }
+    assert_xml_tag tag: 'entry', attributes: { name: '_service:download_url:file' }
     get '/source/home:tom:COPY/service/_service:download_url:file?expand=1'
     assert_response :success
     assert_not_equal(@response.body, original_file)
@@ -216,7 +209,7 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     assert_response :success
 
     # remove service
-    put '/source/home:tom/service/_service', '<services/>' # empty list
+    put '/source/home:tom/service/_service', params: '<services/>' # empty list
     assert_response :success
     post '/source/home:tom/service?cmd=runservice'
     assert_response :success
@@ -224,8 +217,8 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     assert_response :success
     get '/source/home:tom/service'
     assert_response :success
-    assert_xml_tag :tag => 'serviceinfo', :attributes => { :code => 'succeeded' }
-    assert_no_xml_tag :parent => { :tag => 'serviceinfo' }, :tag => 'error'
+    assert_xml_tag tag: 'serviceinfo', attributes: { code: 'succeeded' }
+    assert_no_xml_tag parent: { tag: 'serviceinfo' }, tag: 'error'
     get '/source/home:tom/service/_service:download_url:file?expand=1'
     assert_response 404
 
@@ -250,14 +243,14 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
   def test_service_merge_invalid
     login_tom
     # Setup package
-    raw_put '/source/home:tom/service/_meta', "<package project='home:tom' name='service'> <title /> <description /> </package>"
+    put '/source/home:tom/service/_meta', params: "<package project='home:tom' name='service'> <title /> <description /> </package>"
     assert_response :success
-    raw_put '/source/home:tom/service/pack.spec', "# Comment \nName: pack\nVersion: 12\nRelease: 9\nSummary: asd"
+    put '/source/home:tom/service/pack.spec', params: "# Comment \nName: pack\nVersion: 12\nRelease: 9\nSummary: asd"
     assert_response :success
 
-    raw_put '/source/home:tom/service/_service', '<services> <service name="not_existing" /> </services>'
+    put '/source/home:tom/service/_service', params: '<services> <service name="not_existing" /> </services>'
     assert_response :success
-    assert_nil Package.find_by_project_and_name("home:tom", "service").backend_package.error
+    assert_nil Package.find_by_project_and_name('home:tom', 'service').backend_package.error
     post '/source/home:tom/service?cmd=runservice'
     assert_response :success
     post '/source/home:tom/service?cmd=waitservice'
@@ -265,7 +258,7 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     assert_response 400
     get '/source/home:tom/service'
     assert_response :success
-    assert_xml_tag :tag => 'serviceinfo', :attributes => { :code => 'failed' }
+    assert_xml_tag tag: 'serviceinfo', attributes: { code: 'failed' }
     UpdateNotificationEvents.new.perform
     get '/source/home:tom/service?expand=1'
     assert_response 400
@@ -275,16 +268,15 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
   def test_service_merge_valid
     login_tom
     # Setup package
-    raw_put '/source/home:tom/service/_meta', "<package project='home:tom' name='service'> <title /> <description /> </package>"
+    put '/source/home:tom/service/_meta', params: "<package project='home:tom' name='service'> <title /> <description /> </package>"
     assert_response :success
-    raw_put '/source/home:tom/service/pack.spec', "# Comment \nName: pack\nVersion: 12\nRelease: 9\nSummary: asd"
+    put '/source/home:tom/service/pack.spec', params: "# Comment \nName: pack\nVersion: 12\nRelease: 9\nSummary: asd"
     assert_response :success
 
-    raw_put '/source/home:tom/service/_service',
-            '<services> <service name="download_url" >
-             <param name="host">localhost</param>
-             <param name="path">/directory/subdirectory/file</param>
-             </service> </services>'
+    put '/source/home:tom/service/_service', params: '<services> <service name="download_url" >
+         <param name="host">localhost</param>
+         <param name="path">/directory/subdirectory/file</param>
+         </service> </services>'
     assert_response :success
     post '/source/home:tom/service?cmd=runservice'
     assert_response :success
@@ -293,11 +285,11 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
 
     get '/source/home:tom/service'
     assert_response :success
-    assert_xml_tag :tag => 'serviceinfo', :attributes => { :code => 'succeeded' }
-    assert_no_xml_tag :parent => { :tag => 'serviceinfo' }, :tag => 'error'
+    assert_xml_tag tag: 'serviceinfo', attributes: { code: 'succeeded' }
+    assert_no_xml_tag parent: { tag: 'serviceinfo' }, tag: 'error'
     get '/source/home:tom/service/_service:download_url:file?expand=1'
     assert_response :success
-    post '/source/home:tom/service?cmd=mergeservice', nil
+    post '/source/home:tom/service?cmd=mergeservice'
     assert_response :success
     get '/source/home:tom/service'
     assert_response :success
@@ -317,16 +309,15 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
 
   def test_buildtime_service
     login_Iggy
-    raw_put '/source/home:Iggy/service/_meta',
-            "<package project='home:Iggy' name='service'> <title /> <description /> <build><enable/></build></package>"
+    put '/source/home:Iggy/service/_meta',
+        params: "<package project='home:Iggy' name='service'> <title /> <description /> <build><enable/></build></package>"
     assert_response :success
-    raw_put '/source/home:Iggy/service/pack.spec', "# Comment \nName: pack\nVersion: 12\nRelease: 9\nSummary: asd"
+    put '/source/home:Iggy/service/pack.spec', params: "# Comment \nName: pack\nVersion: 12\nRelease: 9\nSummary: asd"
     assert_response :success
 
     post '/source/home:Iggy/service?cmd=waitservice'
     assert_response :success
-    put '/source/home:Iggy/service/_service',
-        '<services> <service name="set_version" mode="buildtime">
+    put '/source/home:Iggy/service/_service', params: '<services> <service name="set_version" mode="buildtime">
          <param name="version">0817</param>
          <param name="file">pack.spec</param>
          </service> </services>'
@@ -336,17 +327,17 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     run_scheduler('i586')
     get '/build/home:Iggy/_result'
     assert_response :success
-    assert_xml_tag :tag => "details", :content => "nothing provides obs-service-set_version"
+    assert_xml_tag tag: 'details', content: 'nothing provides obs-service-set_version'
 
     # osc local package build call
-    get "/build/home:Iggy/10.2/i586/service/_buildinfo"
+    get '/build/home:Iggy/10.2/i586/service/_buildinfo'
     assert_response :success
-    assert_xml_tag :tag => "error", :content => "unresolvable: nothing provides obs-service-set_version"
+    assert_xml_tag tag: 'error', content: 'unresolvable: nothing provides obs-service-set_version'
     # osc local package build call sending own spec and _service file
-    cpio=IO.popen("cd #{Rails.root}/test/fixtures/backend/source/buildtime_service_source/; exec ls -1 | cpio -H newc -o 2>/dev/null")
-    raw_post "/build/home:Iggy/10.2/i586/service/_buildinfo", cpio.read
+    cpio = IO.popen("cd #{Rails.root}/test/fixtures/backend/source/buildtime_service_source/; exec ls -1 | cpio -H newc -o 2>/dev/null")
+    raw_post '/build/home:Iggy/10.2/i586/service/_buildinfo', cpio.read
     assert_response :success
-    assert_xml_tag :tag => "error", :content => "unresolvable: nothing provides obs-service-recompresserator"
+    assert_xml_tag tag: 'error', content: 'unresolvable: nothing provides obs-service-recompresserator'
 
     delete '/source/home:Iggy/service'
     assert_response :success
@@ -354,18 +345,17 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
 
   def test_source_commit_with_service
     login_tom
-    put '/source/home:tom/service/_meta', "<package project='home:tom' name='service'> <title /> <description /> </package>"
+    put '/source/home:tom/service/_meta', params: "<package project='home:tom' name='service'> <title /> <description /> </package>"
     assert_response :success
     post '/source/home:tom/service?cmd=waitservice'
     assert_response :success
-    put '/source/home:tom/service/_service',
-        '<services> <service name="set_version" >
+    put '/source/home:tom/service/_service', params: '<services> <service name="set_version" >
          <param name="version">0819</param>
          <param name="file">pack.spec</param> </service> </services>'
     assert_response :success
     post '/source/home:tom/service?cmd=waitservice'
     assert_response :success
-    put '/source/home:tom/service/pack.spec', "# Comment \nVersion: 12\nRelease: 9\nSummary: asd"
+    put '/source/home:tom/service/pack.spec', params: "# Comment \nVersion: 12\nRelease: 9\nSummary: asd"
     assert_response :success
     post '/source/home:tom/service?cmd=waitservice'
     assert_response :success
@@ -378,7 +368,7 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     md5sum_spec = doc.elements["//entry[@name='pack.spec']"].attributes['md5']
 
     # do a commit to trigger the service
-    put '/source/home:tom/service/filename?rev=repository', 'CONTENT'
+    put '/source/home:tom/service/filename?rev=repository', params: 'CONTENT'
     assert_response :success
     filelist = '<directory> <entry name="filename" md5="45685e95985e20822fb2538a522a5ccf" /> <entry name="_service" md5="' +
                md5sum_service + '" /> <entry name="pack.spec" md5="' + md5sum_spec + '" /> </directory> '
@@ -400,16 +390,16 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     assert_response :success
     get '/source/home:tom/service?rev=3&expand=1' # show service generated files
     assert_response :success
-    assert_xml_tag :tag => 'entry', :attributes => { :name => '_service:set_version:pack.spec' }
-    assert_xml_tag :tag => 'entry', :attributes => { :name => 'filename' }
+    assert_xml_tag tag: 'entry', attributes: { name: '_service:set_version:pack.spec' }
+    assert_xml_tag tag: 'entry', attributes: { name: 'filename' }
     get '/source/home:tom/service?rev=4' # second commit
     assert_response :success
-    assert_no_xml_tag :tag => 'entry', :attributes => { :name => '_service:set_version:pack.spec' }
-    assert_no_xml_tag :tag => 'entry', :attributes => { :name => 'filename' }                      # user file got removed
+    assert_no_xml_tag tag: 'entry', attributes: { name: '_service:set_version:pack.spec' }
+    assert_no_xml_tag tag: 'entry', attributes: { name: 'filename' } # user file got removed
     get '/source/home:tom/service?rev=4&expand=1' # with generated files
     assert_response :success
-    assert_xml_tag :tag => 'entry', :attributes => { :name => '_service:set_version:pack.spec' }
-    assert_no_xml_tag :tag => 'entry', :attributes => { :name => 'filename' }
+    assert_xml_tag tag: 'entry', attributes: { name: '_service:set_version:pack.spec' }
+    assert_no_xml_tag tag: 'entry', attributes: { name: 'filename' }
 
     # cleanup
     delete '/source/home:tom/service'
@@ -418,13 +408,13 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
 
   def test_run_project_source_service
     login_tom
-    put '/source/home:tom/service/_meta', "<package project='home:tom' name='service'> <title /> <description /> </package>"
+    put '/source/home:tom/service/_meta', params: "<package project='home:tom' name='service'> <title /> <description /> </package>"
     assert_response :success
-    put '/source/home:tom/service/pack.spec', "# Comment \nVersion: 12\nRelease: 9\nSummary: asd"
+    put '/source/home:tom/service/pack.spec', params: "# Comment \nVersion: 12\nRelease: 9\nSummary: asd"
     assert_response :success
 
     # unknown service
-    put '/source/home:tom/_project/_service', '<services> <service name="not_existing" /> </services>'
+    put '/source/home:tom/_project/_service', params: '<services> <service name="not_existing" /> </services>'
     assert_response :success
     post '/source/home:tom/service?cmd=runservice'
     assert_response :success
@@ -432,11 +422,12 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     assert_response 400 # broken service
     get '/source/home:tom/service'
     assert_response :success
-    assert_xml_tag :tag => 'serviceinfo', :attributes => { :code => 'failed' }
+    assert_xml_tag tag: 'serviceinfo', attributes: { code: 'failed' }
     assert_match(/not_existing.service  No such file or directory/, @response.body)
 
     # unknown parameter
-    put '/source/home:tom/_project/_service', '<services> <service name="set_version" > <param name="INVALID">0817</param></service> </services>'
+    put '/source/home:tom/_project/_service',
+        params: '<services> <service name="set_version" > <param name="INVALID">0817</param></service> </services>'
     assert_response :success
     post '/source/home:tom/service?cmd=runservice'
     assert_response :success
@@ -444,28 +435,30 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     assert_response 400 # broken service
     get '/source/home:tom/service'
     assert_response :success
-    assert_xml_tag :tag => 'serviceinfo', :attributes => { :code => 'failed' }
+    assert_xml_tag tag: 'serviceinfo', attributes: { code: 'failed' }
     assert_match(/service parameter &quot;INVALID&quot; is not defined/, @response.body)
 
     # invalid names
-    put '/source/home:tom/_project/_service', '<services> <service name="set_version ; `ls`" ></service> </services>'
+    put '/source/home:tom/_project/_service', params: '<services> <service name="set_version ; `ls`" ></service> </services>'
     assert_response 400
     assert_match(/service name.*contains invalid chars/, @response.body)
-    put '/source/home:tom/_project/_service', '<services> <service name="../blahfasel" ></service> </services>'
+    put '/source/home:tom/_project/_service', params: '<services> <service name="../blahfasel" ></service> </services>'
     assert_response 400
     assert_match(/service name.*contains invalid chars/, @response.body)
-    put '/source/home:tom/_project/_service', '<services> <service name="set_version" > <param name="asd; `ls`">0817</param></service> </services>'
+    put '/source/home:tom/_project/_service',
+        params: '<services> <service name="set_version" > <param name="asd; `ls`">0817</param></service> </services>'
     assert_response 400
     assert_match(/service parameter.*contains invalid chars/, @response.body)
 
     # reset
     put '/source/home:tom/_project/_service',
-        '<services> <service name="set_version" > <param name="version">0817</param> <param name="file">pack.spec</param> </service> </services>'
+        params: '<services> <service name="set_version" > <param name="version">0817</param> <param name="file">pack.spec</param> </service> '\
+                '</services>'
     assert_response :success
 
-    put '/source/home:tom/service2/_meta', "<package project='home:tom' name='service2'> <title /> <description /> </package>"
+    put '/source/home:tom/service2/_meta', params: "<package project='home:tom' name='service2'> <title /> <description /> </package>"
     assert_response :success
-    put '/source/home:tom/service2/pack.spec', "# Comment \nVersion: 12\nRelease: 9\nSummary: asd"
+    put '/source/home:tom/service2/pack.spec', params: "# Comment \nVersion: 12\nRelease: 9\nSummary: asd"
     assert_response :success
     post '/source/home:tom/service2?cmd=runservice'
     assert_response :success
@@ -473,8 +466,8 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     assert_response :success
     get '/source/home:tom/service2'
     assert_response :success
-    assert_xml_tag :tag => 'serviceinfo', :attributes => { :code => 'succeeded' }
-    assert_no_xml_tag :parent => { :tag => 'serviceinfo' }, :tag => 'error'
+    assert_xml_tag tag: 'serviceinfo', attributes: { code: 'succeeded' }
+    assert_no_xml_tag parent: { tag: 'serviceinfo' }, tag: 'error'
     get '/source/home:tom/service2/_service:set_version:pack.spec?expand=1'
     assert_response :success
 
@@ -492,19 +485,19 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     assert_response 401
 
     login_tom
-    put '/source/home:tom/service/_meta', "<package project='home:tom' name='service'> <title /> <description /> </package>"
+    put '/source/home:tom/service/_meta', params: "<package project='home:tom' name='service'> <title /> <description /> </package>"
     assert_response :success
 
     post '/person/tom/token?cmd=create'
     assert_response :success
     doc = REXML::Document.new(@response.body)
     alltoken = doc.elements['//data'].text
-    assert_equal 40, alltoken.length
+    assert_equal 24, alltoken.length
     post '/person/tom/token?cmd=create&project=home:tom&package=service'
     assert_response :success
     doc = REXML::Document.new(@response.body)
     token = doc.elements['//data'].text
-    assert_equal 40, token.length
+    assert_equal 24, token.length
 
     # ANONYMOUS
     reset_auth
@@ -514,61 +507,61 @@ class SourceServicesTest < ActionDispatch::IntegrationTest
     assert_response 401
     post '/trigger/runservice'
     assert_response 403
-    assert_xml_tag :tag => 'status', :attributes => { :code => 'permission_denied' }
+    assert_xml_tag tag: 'status', attributes: { code: 'permission_denied' }
     assert_match(/No valid token found/, @response.body)
 
     # with wrong token
-    post '/trigger/runservice', nil, { 'Authorization' => 'Token wrong' }
+    post '/trigger/runservice', headers: { 'Authorization' => 'Token wrong' }
     assert_response 404
-    assert_xml_tag :tag => 'status', :attributes => { :code => 'not_found' }
+    assert_xml_tag tag: 'status', attributes: { code: 'not_found' }
 
     # with right token
-    post '/trigger/runservice', nil, { 'Authorization' => "Token #{token}" }
+    post '/trigger/runservice', headers: { 'Authorization' => "Token #{token}" }
     # success, but no source service configured :)
     assert_response 404
     assert_match(/no source service defined/, @response.body)
 
     # with global token
-    post '/trigger/runservice?project=home:tom&package=service', nil, { 'Authorization' => "Token #{alltoken}" }
+    post '/trigger/runservice?project=home:tom&package=service', headers: { 'Authorization' => "Token #{alltoken}" }
     # success, but no source service configured :)
     assert_response 404
     assert_match(/no source service defined/, @response.body)
 
     # Locking user blocks the trigger
-    tom = User.find_by_login("tom")
-    tom.state = User::STATES['locked']
+    tom = User.find_by_login('tom')
+    tom.state = 'locked'
     tom.save!
     # with right token
-    post '/trigger/runservice', nil, { 'Authorization' => "Token #{token}" }
+    post '/trigger/runservice', headers: { 'Authorization' => "Token #{token}" }
     # success, but no source service configured :)
     assert_response 403
-    assert_xml_tag tag: "status", attributes: { code: "no_permission" }
+    assert_xml_tag tag: 'status', attributes: { code: 'no_permission' }
     # with global token
-    post '/trigger/runservice?project=home:tom&package=service', nil, { 'Authorization' => "Token #{alltoken}" }
+    post '/trigger/runservice?project=home:tom&package=service', headers: { 'Authorization' => "Token #{alltoken}" }
     # success, but no source service configured :)
     assert_response 403
-    assert_xml_tag tag: "status", attributes: { code: "no_permission" }
+    assert_xml_tag tag: 'status', attributes: { code: 'no_permission' }
 
     # reset and drop stuff as tom
-    tom.state = User::STATES['confirmed']
+    tom.state = 'confirmed'
     tom.save!
     login_tom
     get '/person/tom/token'
     assert_response :success
-    assert_xml_tag :tag => 'directory', :attributes => { :count => '2' }
-    assert_xml_tag :tag => 'entry', :attributes => { :project => 'home:tom', :package => 'service' }
+    assert_xml_tag tag: 'directory', attributes: { count: '2' }
+    assert_xml_tag tag: 'entry', attributes: { project: 'home:tom', package: 'service' }
     doc = REXML::Document.new(@response.body)
     id = doc.elements['//entry'].attributes['id']
     assert_not_nil id
     assert_not_nil doc.elements['//entry'].attributes['string']
     delete "/person/tom/token/#{id}"
     assert_response :success
-    assert_xml_tag :tag => 'status', :attributes => { :code => 'ok' }
+    assert_xml_tag tag: 'status', attributes: { code: 'ok' }
     delete "/person/tom/token/#{id}"
     assert_response 404
     get '/person/tom/token'
     assert_response :success
-    assert_xml_tag :tag => 'directory', :attributes => { :count => '1' }
+    assert_xml_tag tag: 'directory', attributes: { count: '1' }
 
     # cleanup
     delete '/source/home:tom/service'
