@@ -1,7 +1,7 @@
 require File.expand_path(File.dirname(__FILE__) + '/..') + '/test_helper'
 
 class PublicHelperTest < ActiveSupport::TestCase
-  YMP_URL = 'http://example.com/ymp'
+  YMP_URL = 'http://example.com/ymp'.freeze
   include PublicHelper
 
   def test_ymp_url
