@@ -289,16 +289,49 @@ to a free worker.
 =cut
 
 sub writejob {
-  my ($gctx, $job, $binfo) = @_;
+  my ($ctx, $job, $binfo, $reason) = @_;
+
+  # jay! ready for building, write status, reason, and job info
+  my $gctx = $ctx->{'gctx'};
+  $binfo->{'job'} = $job if $job;
+  $binfo->{'readytime'} = time();
+  if ($reason) {
+    $binfo->{'reason'} = $reason->{'explain'};
+    my $dst = "$ctx->{'gdst'}/$binfo->{'package'}";
+    mkdir_p($dst);
+    my $now = $binfo->{'readytime'};
+    writexml("$dst/.status", "$dst/status", { 'status' => 'scheduled', 'readytime' => $now, 'job' => $job}, $BSXML::buildstatus);
+    # And store reason and time
+    $reason->{'time'} = $now;
+    writexml("$dst/.reason", "$dst/reason", $reason, $BSXML::buildreason);
+  }
 
   $binfo->{'srcserver'} ||= $workersrcserver;
   $binfo->{'reposerver'} ||= $workerreposerver;
+  $binfo->{'genmetaalgo'} = $ctx->{'genmetaalgo'} if $ctx->{'genmetaalgo'};
+
   my $myjobsdir = $gctx->{'myjobsdir'};
+  $ctx->{'otherjobscache'} ||= [ grep {/-[0-9a-f]{32}$/} grep {!/^\./} ls($myjobsdir) ];
   writexml("$myjobsdir/.$job", "$myjobsdir/$job", $binfo, $BSXML::buildinfo);
   add_crossmarker($gctx, $binfo->{'hostarch'}, $job) if $binfo->{'hostarch'};
   $ourjobs{$1}->{$job} = 1 if $job =~ /^(:.+?|[^:].*?::.+?)::/s;
+  push @{$ctx->{'otherjobscache'}}, $job;
 }
 
+=head2 find_otherjobs - find all jobs for the same build
+
+Note that the job must not contain the srcmd5
+
+=cut
+
+sub find_otherjobs {
+  my ($ctx, $jobprefix) = @_;
+  my $myjobsdir = $ctx->{'gctx'}->{'myjobsdir'};
+  $ctx->{'otherjobscache'} ||= [ grep {/-[0-9a-f]{32}$/} grep {!/^\./} ls($myjobsdir) ];
+  my @otherjobs = grep {/^\Q$jobprefix\E-[0-9a-f]{32}$/} @{$ctx->{'otherjobscache'}};
+  @otherjobs = BSUtil::unify(grep {-e "$myjobsdir/$_"} @otherjobs) if @otherjobs;
+  return @otherjobs;
+}
 
 =head2 add_crossmarker - add a marker into a foreign jobdir
 
@@ -555,7 +588,7 @@ sub fakejobfinished {
     'job' => $job,
     %{$buildinfoskel || {}},
   };
-  writejob($gctx, $job, $binfo);
+  writejob($ctx, $job, $binfo);
   close(F);
   my $ev = {'type' => 'built', 'arch' => $myarch, 'job' => $job};
   if ($needsign) {
@@ -694,6 +727,8 @@ sub addjobhist {
 sub nextbcnt {
   my ($ctx, $packid, $pdata) = @_;
 
+  return undef unless defined $packid;
+  return 1 unless exists $pdata->{'versrel'},;
   my $h;
   my $gdst = $ctx->{'gdst'};
   my $relsyncmax = $ctx->{'relsyncmax'};
@@ -713,8 +748,90 @@ sub nextbcnt {
   return $h->{'bcnt'} + 1;
 }
 
+=head2 filljobdata - create a job skel
+
+ TODO: add description
+
 =cut
 
+sub create_jobdata {
+  my ($ctx, $packid, $pdata, $info, $subpacks) = @_;
+
+  my $gctx = $ctx->{'gctx'};
+  my $bconf = $ctx->{'conf'};
+  my $myarch = $gctx->{'arch'};
+  my $projid = $ctx->{'project'};
+  my $repoid = $ctx->{'repository'};
+  my $binfo = {
+    'project' => $projid,
+    'repository' => $repoid,
+    'arch' => $myarch,
+    'subpack' => $subpacks || [],
+  };
+  $binfo->{'package'} = $packid if defined $packid;
+  $binfo->{'rev'} = $pdata->{'rev'} if $pdata->{'rev'};
+  $binfo->{'srcmd5'} = $pdata->{'srcmd5'} if $pdata->{'srcmd5'};
+  $binfo->{'verifymd5'} = $pdata->{'verifymd5'} || $pdata->{'srcmd5'} if $pdata->{'verifymd5'} || $pdata->{'srcmd5'};
+  $binfo->{'file'} = $info->{'file'} if defined $info->{'file'};
+  $binfo->{'imagetype'} = $info->{'imagetype'} if $info->{'imagetype'};
+  $binfo->{'nodbgpkgs'} = $info->{'nodbgpkgs'} if $info->{'nodbgpkgs'};
+  $binfo->{'nosrcpkgs'} = $info->{'nosrcpkgs'} if $info->{'nosrcpkgs'};
+  $binfo->{'hostarch'} = $bconf->{'hostarch'} if $bconf->{'hostarch'};
+  my $obsname = $gctx->{'obsname'};
+  $binfo->{'disturl'} = "obs://$obsname/$projid/$repoid/$pdata->{'srcmd5'}-$packid" if defined($obsname) && defined($packid);
+  if (defined($packid) && exists($pdata->{'versrel'})) {
+    $binfo->{'versrel'} = $pdata->{'versrel'};
+    # find the last build count we used for this version/release
+    my $bcnt = nextbcnt($ctx, $packid, $pdata);
+    $binfo->{'bcnt'} = $bcnt;
+    my $release = $pdata->{'versrel'};
+    $release = '0' unless defined $release;
+    $release =~ s/.*-//;
+    if (exists($bconf->{'release'})) {
+      if (defined($bconf->{'release'})) {
+	$binfo->{'release'} = $bconf->{'release'};
+	$binfo->{'release'} =~ s/\<CI_CNT\>/$release/g;
+	$binfo->{'release'} =~ s/\<B_CNT\>/$bcnt/g;
+      }
+    } else {
+      $binfo->{'release'} = "$release.$bcnt" if $ctx->{'dobuildinfo'};
+    }
+  }
+  my $projpacks = $gctx->{'projpacks'};
+  my $proj = $projpacks->{$projid};
+  my $debuginfo = $bconf->{'debuginfo'};
+  $debuginfo = BSUtil::enabled($repoid, $proj->{'debuginfo'}, $debuginfo, $myarch);
+  $debuginfo = BSUtil::enabled($repoid, $pdata->{'debuginfo'}, $debuginfo, $myarch);
+  $binfo->{'debuginfo'} = 1 if $debuginfo;
+  return $binfo;
+}
+
+=head2 add_expanddebug - add debug data from the expander
+
+ input:  $ctx           - prp context
+         $type          - expandsion type information 
+         $xp            - expander (optional)
+
+=cut
+
+sub add_expanddebug {
+  my ($ctx, $type, $xp) = @_;
+  my $expanddebug = $ctx->{'expanddebug'};
+  return unless ref($expanddebug);
+  $xp ||= $ctx->{'expander'};
+  return unless $xp;
+  return unless defined &BSSolv::expander::debugstr;
+  my $dbg = $xp->debugstr();
+  return unless $dbg;
+  $dbg = substr($dbg, $ctx->{"xp_cut_hack$xp"}) if $ctx->{"xp_cut_hack$xp"};
+  return unless $dbg;
+  $$expanddebug .= "\n" if $$expanddebug;
+  $$expanddebug .= "=== $type\n";
+  $$expanddebug .= $dbg;
+  $dbg = $xp->debugstr();
+  $ctx->{"xp_cut_hack$xp"} = length($dbg) if $dbg;	# sigh
+}
+
 =head2 create - create a new build job
 
  input:  $ctx           - prp context
@@ -734,7 +851,6 @@ sub nextbcnt {
  other jobs of the same prp/package, write status and job info.
  not that hard, was it?
 
-
 =cut
 
 sub create {
@@ -750,92 +866,137 @@ sub create {
   my $proj = $projpacks->{$projid};
   my $prp = "$projid/$repoid";
   my $srcmd5 = $pdata->{'srcmd5'};
-  my $job = jobname($prp, $packid);
+  my $jobprefix = $packid ? jobname($prp, $packid) : undef;
   my $myjobsdir = $gctx->{'myjobsdir'};
-  if (-s "$myjobsdir/$job-$srcmd5") {
-    add_crossmarker($gctx, $bconf->{'hostarch'}, "$job-$srcmd5") if $bconf->{'hostarch'};	# just in case...
-    return ('scheduled', "$job-$srcmd5");
+  my $dobuildinfo = $ctx->{'dobuildinfo'};
+
+  if ($myjobsdir) {
+    if (-s "$myjobsdir/$jobprefix-$srcmd5") {
+      add_crossmarker($gctx, $bconf->{'hostarch'}, "$jobprefix-$srcmd5") if $bconf->{'hostarch'};	# just in case...
+      return ('scheduled', "$jobprefix-$srcmd5");
+    }
+    return ('scheduled', $jobprefix) if -s "$myjobsdir/$jobprefix";   # obsolete
   }
-  return ('scheduled', $job) if -s "$myjobsdir/$job";   # obsolete
-  my @otherjobs = grep {/^\Q$job\E-[0-9a-f]{32}$/} ls($myjobsdir);
-  $job = "$job-$srcmd5";
+  my $job = $jobprefix;
+  $job .= "-$srcmd5" if defined($job) && $srcmd5;
 
   # a new one. expand usedforbuild. write info file.
-  my $buildtype = Build::recipe2buildtype($info->{'file'});
+  my $buildtype = $pdata->{'buildtype'} || Build::recipe2buildtype($info->{'file'});
+
+  my $kiwimode;
+  $kiwimode = $buildtype if $buildtype eq 'kiwi' || $buildtype eq 'docker' || $buildtype eq 'fissile';
 
   my $syspath;
   my $searchpath = path2buildinfopath($gctx, $ctx->{'prpsearchpath'});
-  if ($buildtype eq 'kiwi') {
+  if ($kiwimode) {
     # switch searchpath to kiwi info path
     $syspath = $searchpath if @$searchpath;
     $searchpath = path2buildinfopath($gctx, [ expandkiwipath($info, $ctx->{'prpsearchpath'}) ]);
   }
 
+  my $expanddebug = $ctx->{'expanddebug'};
+
+  # calculate build time service debs
+  my @btdeps;
+  if ($info->{'buildtimeservice'}) {
+    for my $service (@{$info->{'buildtimeservice'} || []}) {
+      if ($bconf->{'substitute'}->{"obs-service:$service"}) {
+	push @btdeps, @{$bconf->{'substitute'}->{"obs-service:$service"}};
+      } else {
+	my $pkgname = "obs-service-$service";
+	$pkgname =~ s/_/-/g if $bconf->{'binarytype'} eq 'deb';
+	push @btdeps, $pkgname;
+      }
+    }
+    @btdeps = BSUtil::unify(@btdeps);
+  }
+
   # calculate sysdeps (cannot cache in the kiwi case)
   my @sysdeps;
   if ($buildtype eq 'kiwi') {
-    @sysdeps = Build::get_sysbuild($bconf, 'kiwi-image', [ grep {/^kiwi-.*:/} @{$info->{'dep'} || []} ]);
+    my $kiwitype = '';
+    $kiwitype = $info->{'imagetype'} && $info->{'imagetype'}->[0] eq 'product' ? 'kiwi-product' : 'kiwi-image';
+    @sysdeps = grep {/^kiwi-.*:/} @{$info->{'dep'} || []};
+    @sysdeps = Build::get_sysbuild($bconf, $kiwitype, [ @sysdeps, @btdeps, @{$ctx->{'extradeps'} || []} ]);
   } else {
     $ctx->{"sysbuild_$buildtype"} ||= [ Build::get_sysbuild($bconf, $buildtype) ];
     @sysdeps = @{$ctx->{"sysbuild_$buildtype"}};
   }
+  add_expanddebug($ctx,'sysdeps expansion') if $expanddebug && @sysdeps;
 
   # calculate packages needed for building
   my @bdeps = grep {!/^\// || $bconf->{'fileprovides'}->{$_}} @{$info->{'prereq'} || []};
   unshift @bdeps, '--directdepsend--' if @bdeps;
-  unshift @bdeps, @{$info->{'dep'} || []};
+  unshift @bdeps, @{$info->{'dep'} || []}, @btdeps, @{$ctx->{'extradeps'} || []};
   push @bdeps, '--ignoreignore--' if @sysdeps;
 
-  if ($buildtype eq 'kiwi') {
+  if ($kiwimode || $buildtype eq 'buildenv') {
     @bdeps = (1, @$edeps);      # reuse edeps packages, no need to expand again
   } else {
     @bdeps = Build::get_build($bconf, $subpacks, @bdeps);
+    add_expanddebug($ctx, 'build expansion') if $expanddebug;
   }
   if (!shift(@bdeps)) {
-    print "        unresolvable:\n";
-    print "          $_\n" for @bdeps;
+    if ($ctx->{'verbose'}) {
+      print "        unresolvable:\n";
+      print "          $_\n" for @bdeps;
+    }
     return ('unresolvable', join(', ', @bdeps));
   }
   if (@sysdeps && !shift(@sysdeps)) {
-    print "        unresolvable:\n";
-    print "          $_\n" for @sysdeps;
+    if ($ctx->{'verbose'}) {
+      print "        unresolvable:\n";
+      print "          $_\n" for @sysdeps;
+    }
     return ('unresolvable', join(', ', @sysdeps));
   }
-  if ($BSConfig::enable_download_on_demand) {
-    my $dods = BSSched::DoD::dodcheck($ctx, $ctx->{'pool'}, $myarch, Build::get_preinstalls($bconf), Build::get_vminstalls($bconf), @bdeps, @sysdeps);
+
+  my $pool = $ctx->{'pool'};
+  my @pdeps = Build::get_preinstalls($bconf);
+  my @vmdeps = Build::get_vminstalls($bconf);
+
+  # do DoD checking
+  if (!$ctx->{'isreposerver'} && $BSConfig::enable_download_on_demand) {
+    my $dods;
+    if ($kiwimode) {
+      # image packages are already checked (they come from a different pool anyway)
+      $dods = BSSched::DoD::dodcheck($ctx, $pool, $myarch, @pdeps, @vmdeps, @sysdeps);
+    } else {
+      $dods = BSSched::DoD::dodcheck($ctx, $pool, $myarch, @pdeps, @vmdeps, @bdeps, @sysdeps);
+    }
     if ($dods) {
-      print "        blocked: $dods\n";
+      print "        blocked: $dods\n" if $ctx->{'verbose'};
       return ('blocked', $dods);
     }
   }
 
-  my $dst = "$gdst/$packid";
-  # find the last build count we used for this version/release
-  mkdir_p($dst);
-  my $bcnt = nextbcnt($ctx, $packid, $pdata);
-
-  # kill those ancient other jobs
-  for my $otherjob (@otherjobs) {
-    print "        killing old job $otherjob\n";
-    killjob($gctx, $otherjob);
+  # make sure we have the preinstalls and vminstalls
+  my @missing = grep {!$ctx->{'dep2pkg'}->{$_}} (@pdeps, @vmdeps);
+  if (@missing) {
+    @missing = sort(BSUtil::unify(@missing));
+    return ('unresolvable', "missing pre/vminstalls: ".join(', ', @missing));
   }
 
-  # jay! ready for building, write status and job info
-  my $now = time();
-  writexml("$dst/.status", "$dst/status", { 'status' => 'scheduled', 'readytime' => $now, 'job' => $job}, $BSXML::buildstatus);
-  # And store reason and time
-  $reason->{'time'} = $now;
-  writexml("$dst/.reason", "$dst/reason", $reason, $BSXML::buildreason);
+  # kill those ancient other jobs
+  if ($myjobsdir) {
+    my @otherjobs = find_otherjobs($ctx, $jobprefix);
+    for my $otherjob (@otherjobs) {
+      print "        killing old job $otherjob\n" if $ctx->{'verbose'};
+      killjob($gctx, $otherjob);
+    }
+  }
 
-  my @pdeps = Build::get_preinstalls($bconf);
-  my @vmdeps = Build::get_vminstalls($bconf);
+  # create bdep section
   my %runscripts = map {$_ => 1} Build::get_runscripts($bconf);
   my %bdeps = map {$_ => 1} @bdeps;
   my %pdeps = map {$_ => 1} @pdeps;
   my %vmdeps = map {$_ => 1} @vmdeps;
   my %edeps = map {$_ => 1} @$edeps;
   my %sysdeps = map {$_ => 1} @sysdeps;
+
+  my $needextradata = $dobuildinfo || $ctx->{'unorderedrepos'};
   @bdeps = BSUtil::unify(@pdeps, @vmdeps, @$edeps, @bdeps, @sysdeps);
+  @bdeps = () if $buildtype eq 'buildenv';
   for (@bdeps) {
     my $n = $_;
     $_ = {'name' => $_};
@@ -844,9 +1005,22 @@ sub create {
     $_->{'runscripts'} = 1 if $runscripts{$n};
     $_->{'notmeta'} = 1 unless $edeps{$n};
     if (@sysdeps) {
-      $_->{'installonly'} = 1 if $sysdeps{$n} && !$bdeps{$n} && $buildtype ne 'kiwi';
+      $_->{'installonly'} = 1 if $sysdeps{$n} && !$bdeps{$n} && !$kiwimode;
       $_->{'noinstall'} = 1 if $bdeps{$n} && !($sysdeps{$n} || $vmdeps{$n} || $pdeps{$n});
     }
+    if ($needextradata) {
+      my $p = $ctx->{'dep2pkg'}->{$n};
+      my $prp = $pool->pkg2reponame($p);
+      ($_->{'project'}, $_->{'repository'}) = split('/', $prp, 2) if $prp;
+      if ($dobuildinfo) {
+        my $d = $pool->pkg2data($p);
+        $_->{'epoch'}      = $d->{'epoch'} if $d->{'epoch'};
+        $_->{'version'}    = $d->{'version'};
+        $_->{'release'}    = $d->{'release'} if defined $d->{'release'};
+        $_->{'arch'}       = $d->{'arch'} if $d->{'arch'};
+        $_->{'preimghdrmd5'} = $d->{'hdrmd5'} if !$_->{'noinstall'} &&  $d->{'hdrmd5'};
+      }
+    }
   }
   if ($info->{'extrasource'}) {
     push @bdeps, map {{
@@ -854,33 +1028,16 @@ sub create {
       'project' => $_->{'project'}, 'package' => $_->{'package'}, 'srcmd5' => $_->{'srcmd5'},
     }} @{$info->{'extrasource'}};
   }
+  unshift @bdeps, @{$ctx->{'extrabdeps'}} if $ctx->{'extrabdeps'};
 
-  my $vmd5 = $pdata->{'verifymd5'} || $pdata->{'srcmd5'};
-  my $binfo = {
-    'project' => $projid,
-    'repository' => $repoid,
-    'package' => $packid,
-    'srcserver' => $workersrcserver,
-    'reposerver' => $workerreposerver,
-    'job' => $job,
-    'arch' => $myarch,
-    'reason' => $reason->{'explain'},
-    'readytime' => $now,
-    'srcmd5' => $pdata->{'srcmd5'},
-    'verifymd5' => $vmd5,
-    'rev' => $pdata->{'rev'},
-    'file' => $info->{'file'},
-    'versrel' => $pdata->{'versrel'},
-    'bcnt' => $bcnt,
-    'subpack' => ($subpacks || []),
-    'bdep' => \@bdeps,
-    'path' => $searchpath,
-    'needed' => $needed,
-  };
-  my $obsname = $gctx->{'obsname'};
-  $binfo->{'disturl'} = "obs://$obsname/$projid/$repoid/$pdata->{'srcmd5'}-$packid";
+  # fill job data
+  my $binfo = create_jobdata($ctx, $packid, $pdata, $info, $subpacks);
+  $binfo->{'bdep'} = \@bdeps;
+  $binfo->{'path'} = $searchpath;
   $binfo->{'syspath'} = $syspath if $syspath;
-  $binfo->{'hostarch'} = $bconf->{'hostarch'} if $bconf->{'hostarch'};
+  $binfo->{'containerpath'} = path2buildinfopath($gctx, $ctx->{'containerpath'}) if $ctx->{'containerpath'};
+  $binfo->{'containerannotation'} = $ctx->{'containerannotation'} if $ctx->{'containerannotation'};
+  $binfo->{'needed'} = $needed;
   $binfo->{'constraintsmd5'} = $pdata->{'constraintsmd5'} if $pdata->{'constraintsmd5'};
   $binfo->{'prjconfconstraint'} = $bconf->{'constraint'} if @{$bconf->{'constraint'} || []};
   $binfo->{'nounchanged'} = 1 if $info->{'nounchanged'};
@@ -893,21 +1050,8 @@ sub create {
       $binfo->{'revtime'} = $lpdata->{'revtime'} if ($lpdata->{'revtime'} || 0) > $binfo->{'revtime'};
     }
   }
-  $binfo->{'imagetype'} = $info->{'imagetype'} if $info->{'imagetype'};
-  my $release = $pdata->{'versrel'};
-  $release = '0' unless defined $release;
-  $release =~ s/.*-//;
-  if (defined($bconf->{'release'})) {
-    $binfo->{'release'} = $bconf->{'release'};
-    $binfo->{'release'} =~ s/\<CI_CNT\>/$release/g;
-    $binfo->{'release'} =~ s/\<B_CNT\>/$bcnt/g;
-  }
-  my $debuginfo = $bconf->{'debuginfo'};
-  $debuginfo = BSUtil::enabled($repoid, $proj->{'debuginfo'}, $debuginfo, $myarch);
-  $debuginfo = BSUtil::enabled($repoid, $pdata->{'debuginfo'}, $debuginfo, $myarch);
-  $binfo->{'debuginfo'} = 1 if $debuginfo;
+  $ctx->writejob($job, $binfo, $reason);
 
-  writejob($gctx, $job, $binfo);
   # all done. the dispatcher will now pick up the job and send it
   # to a worker.
   return ('scheduled', $job);
@@ -971,37 +1115,47 @@ sub path2buildinfopath {
 =cut
 
 sub metacheck {
-  my ($ctx, $packid, $buildtype, $new_meta, $data) = @_;
+  my ($ctx, $packid, $pdata, $buildtype, $new_meta, $data) = @_;
 
-  my $gctx = $ctx->{'gctx'};
-  my $prp = $ctx->{'prp'};
   my $gdst = $ctx->{'gdst'};
+  return ('scheduled', [ @$data, {'explain' => 'buildinfo generation'} ]) if $ctx->{'isreposerver'};
+  unshift @$new_meta, ($pdata->{'verifymd5'} || $pdata->{'srcmd5'})."  $packid";
   my @meta = split("\n", (readstr("$gdst/:meta/$packid", 1) || ''));
   if (!@meta) {
-    print "      - $packid ($buildtype)\n";
-    print "        no former build, start build\n";
+    if ($ctx->{'verbose'}) {
+      print "      - $packid ($buildtype)\n";
+      print "        no former build, start build\n";
+    }
     return ('scheduled', [ @$data, {'explain' => 'new build'} ]);
   }
   if ($meta[0] ne $new_meta->[0]) {
-    print "      - $packid ($buildtype)\n";
-    print "        src change, start build\n";
+    if ($ctx->{'verbose'}) {
+      print "      - $packid ($buildtype)\n";
+      print "        src change, start build\n";
+    }
     return ('scheduled', [ @$data, {'explain' => 'source change', 'oldsource' => substr($meta[0], 0, 32)} ]);
   }
   if (@meta == 2 && $meta[1] =~ /^fake/) {
     my @s = stat("$gdst/:meta/$packid");
     if (!@s || $s[9] + 14400 > time()) {
-      print "      - $packid ($buildtype)\n";
-      print "        buildsystem setup failure\n";
+      if ($ctx->{'verbose'}) {
+        print "      - $packid ($buildtype)\n";
+        print "        buildsystem setup failure\n";
+      }
       return ('failed')
     }
-    print "      - $packid ($buildtype)\n";
-    print "        retrying bad build\n";
+    if ($ctx->{'verbose'}) {
+      print "      - $packid ($buildtype)\n";
+      print "        retrying bad build\n";
+    }
     return ('scheduled', [ @$data, { 'explain' => 'retrying bad build' } ]);
   }
   if (join('\n', @meta) eq join('\n', @$new_meta)) {
     if (($buildtype eq 'kiwi-image' || $buildtype eq 'kiwi-product') && $ctx->{'relsynctrigger'}->{$packid}) {
-      print "      - $packid ($buildtype)\n";
-      print "        rebuild counter sync\n";
+      if ($ctx->{'verbose'}) {
+        print "      - $packid ($buildtype)\n";
+        print "        rebuild counter sync\n";
+      }
       return ('scheduled', [ @$data, {'explain' => 'rebuild counter sync'} ]);
     }
     #print "      - $packid ($buildtype)\n";
@@ -1018,9 +1172,11 @@ sub metacheck {
     }
   }
   my @diff = diffsortedmd5(\@meta, $new_meta);
-  print "      - $packid ($buildtype)\n";
-  print "        $_\n" for @diff;
-  print "        meta change, start build\n";
+  if ($ctx->{'verbose'}) {
+    print "      - $packid ($buildtype)\n";
+    print "        $_\n" for @diff;
+    print "        meta change, start build\n";
+  }
   return ('scheduled', [ @$data, {'explain' => 'meta change', 'packagechange' => sortedmd5toreason(@diff)} ]);
 }
 
@@ -1084,17 +1240,49 @@ sub diffsortedmd5 {
 =cut
 
 sub expandkiwipath {
-  my ($info, $prpsearchpath) = @_;
+  my ($info, $prpsearchpath, $prios) = @_;
   my @path;
   for (@{$info->{'path'} || []}) {
     if ($_->{'project'} eq '_obsrepositories') {
       push @path, @{$prpsearchpath || []}; 
     } else {
-      push @path, "$_->{'project'}/$_->{'repository'}";
-    }    
+      my $prp = "$_->{'project'}/$_->{'repository'}";
+      push @path, $prp;
+      if ($prios) {
+        my $prio = $_->{'priority'} || 0;
+        $prios->{$prp} = $prio if !defined($prios->{$prp}) || $prio > $prios->{$prp};
+      }
+    }
   }
   return @path;
 }
 
+=head2 getcontainerannotation - get the annotation from a container package
+
+ Also add annotation to container bdep if provided as argument.
+
+=cut
+
+sub getcontainerannotation {
+  my ($pool, $p, $bdep) = @_;
+  return undef unless defined &BSSolv::pool::pkg2annotation;
+  my $annotation = $pool->pkg2annotation($p);
+  return undef unless $annotation;
+  $annotation = BSUtil::fromxml($annotation, $BSXML::binannotation, 1);
+  return undef unless $annotation;
+  if ($bdep) {
+    # add extra data from the package data
+    my $data = $pool->pkg2data($p);
+    $annotation->{'hdrmd5'} = $data->{'hdrmd5'} if $data->{'hdrmd5'};
+    $annotation->{'package'} = $1 if $data->{'path'} && $data->{'path'} =~ /^\.\.\/([^\/]+)\//;
+    $annotation->{'epoch'} = $data->{'epoch'} if $data->{'epoch'};
+    $annotation->{'version'} = $data->{'version'};
+    $annotation->{'release'} = $data->{'release'} if defined $data->{'release'};
+    $annotation->{'binaryarch'} = $data->{'arch'} if $data->{'arch'};
+    $bdep->{'annotation'} = BSUtil::toxml($annotation, $BSXML::binannotation);
+  }
+  return $annotation;
+}
+
 1;
 
