@@ -25,9 +25,8 @@ use Build;
 use BSSolv;
 use BSConfiguration;
 use BSSched::BuildResult;
-use BSSched::BuildJob;                # for expandkiwipath
-use BSSched::ProjPacks;		          # for orderpackids
-use BSSched::EventSource::Directory;  # for sendunblockedevent
+use BSSched::BuildJob;			# for expandkiwipath
+use BSSched::ProjPacks;			# for orderpackids
 my %bininfo_oldok_cache;
 
 =head1 NAME
@@ -93,9 +92,12 @@ sub check {
   my $buildarch = ($repo->{'arch'} || [])->[0] || '';
   # compat to old OBS versions, prefer local...
   $buildarch = 'local' if $BSConfig::localarch && grep {$_ eq 'local'} @{$repo->{'arch'} || []};
+  # reposerver buildinfo is always the right build arch
+  $buildarch = $myarch if $ctx->{'isreposerver'};
   # localbuildarch is where we take the buildenv from
   my $localbuildarch = $buildarch eq 'local' && $BSConfig::localarch ? $BSConfig::localarch : $buildarch;
-  my $markerdir = "$reporoot/$projid/$repoid/$buildarch/$packid";
+  my $markerdir;
+  $markerdir = "$reporoot/$projid/$repoid/$buildarch/$packid" unless $ctx->{'isreposerver'};
 
   my %imagearch = map {$_ => 1} @{$info->{'imagearch'} || []};
   return ('broken', 'no architectures for packages') unless grep {$imagearch{$_}} @{$repo->{'arch'} || []};
@@ -103,8 +105,10 @@ sub check {
 
   if ($myarch ne $buildarch && $myarch ne $localbuildarch) {
     if (!grep {$_ eq $myarch} @archs) {
-      print "      - $packid (kiwi-product)\n";
-      print "        not mine\n";
+      if ($ctx->{'verbose'}) {
+        print "      - $packid (kiwi-product)\n";
+        print "        not mine\n";
+      }
       return ('excluded');
     }
   }
@@ -120,10 +124,15 @@ sub check {
   if (!@{$repo->{'path'} || []}) {
     # have no configured path, use repos from kiwi file instead
     @bprps = @aprps;
-    $bconf = BSSched::ProjPacks::getconfig($gctx, $projid, $repoid, $myarch, \@bprps);
+    my @configpath = @aprps;
+    # always put ourselfs in front
+    unshift @configpath, "$projid/$repoid" unless @configpath && $configpath[0] eq "$projid/$repoid";
+    $bconf = $ctx->getconfig($projid, $repoid, $myarch, \@configpath);
     if (!$bconf) {
-      print "      - $packid (kiwi-product)\n";
-      print "        no config\n";
+      if ($ctx->{'verbose'}) {
+        print "      - $packid (kiwi-product)\n";
+        print "        no config\n";
+      }
       return ('broken', 'no config');
     }
   }
@@ -132,27 +141,34 @@ sub check {
   my @rpms;
   my %rpms_meta;
   my %rpms_hdrmd5;
+  my $neverblock = $ctx->{'isreposerver'};
 
 #print "prps: @aprps\n";
 #print "archs: @archs\n";
 #print "deps: @deps\n";
+  my $pool;
+  my %dep2pkg;
   if ($myarch eq $buildarch || $myarch eq $localbuildarch) {
     # calculate packages needed for building
-    my $pool = BSSolv::pool->new();
+    $pool = BSSolv::pool->new();
     $pool->settype('deb') if $bconf->{'binarytype'} eq 'deb';
     my $delayed_errors = '';
     for my $aprp (@bprps) {
       if (!$ctx->checkprpaccess($aprp)) {
-	print "      - $packid (kiwi-product)\n";
-	print "        repository $aprp is unavailable";
+	if ($ctx->{'verbose'}) {
+	  print "      - $packid (kiwi-product)\n";
+	  print "        repository $aprp is unavailable";
+	}
 	return ('broken', "repository $aprp is unavailable");
       }
       my $r = $ctx->addrepo($pool, $aprp, $localbuildarch);
       if (!$r) {
 	my $error = "repository '$aprp' is unavailable";
 	$error .= " (delayed)" if defined $r;
-	print "      - $packid (kiwi-product)\n";
-	print "        $error\n";
+	if ($ctx->{'verbose'}) {
+	  print "      - $packid (kiwi-product)\n";
+	  print "        $error\n";
+	}
 	if (defined $r) {
 	  $delayed_errors .= ", $error";
 	  next;
@@ -168,20 +184,24 @@ sub check {
     use warnings 'redefine';
     my ($eok, @kdeps) = Build::get_sysbuild($bconf, 'kiwi-product', [ grep {/^kiwi-.*:/} @{$info->{'dep'} || []} ]);
     if (!$eok) {
-      print "      - $packid (kiwi-product)\n";
-      print "        unresolvable for sysbuild:\n";
-      print "          $_\n" for @kdeps;
+      BSSched::BuildJob::add_expanddebug($ctx, 'kiwi sysdeps expansion', $xp) if $ctx->{'expanddebug'};
+      if ($ctx->{'verbose'}) {
+        print "      - $packid (kiwi-product)\n";
+        print "        unresolvable for sysbuild:\n";
+        print "          $_\n" for @kdeps;
+      }
       return ('unresolvable', join(', ', @kdeps));
     }
-    my %dep2pkg;
     for my $p ($pool->consideredpackages()) {
       $dep2pkg{$pool->pkg2name($p)} = $p;
     }
     # check access
     for my $aprp (@aprps) {
       if (!$ctx->checkprpaccess($aprp)) {
-	print "      - $packid (kiwi-product)\n";
-	print "        repository $aprp is unavailable for sysbuild";
+	if ($ctx->{'verbose'}) {
+	  print "      - $packid (kiwi-product)\n";
+	  print "        repository $aprp is unavailable for sysbuild";
+	}
 	return ('broken', "repository $aprp is unavailable");
       }
     }
@@ -207,13 +227,15 @@ sub check {
 	# FIXME: this assumes packid == pname
 	push @blocked, grep {$ps->{$_} && ($ps->{$_} eq 'scheduled' || $ps->{$_} eq 'blocked' || $ps->{$_} eq 'finished')} sort keys %pnames;
       }
-      if (@blocked) {
-	if (! -e "$markerdir/.waiting_for_$localbuildarch") {
-	  mkdir_p($markerdir);
-	  BSUtil::touch("$markerdir/.waiting_for_$localbuildarch");
+      if ($markerdir) {
+        if (@blocked) {
+	  if (! -e "$markerdir/.waiting_for_$localbuildarch") {
+	    mkdir_p($markerdir);
+	    BSUtil::touch("$markerdir/.waiting_for_$localbuildarch");
+	  }
+        } else {
+	  unlink("$markerdir/.waiting_for_$localbuildarch");
 	}
-      } else {
-	unlink("$markerdir/.waiting_for_$localbuildarch");
       }
     } else {
       my $notready = $ctx->{'notready'};
@@ -226,12 +248,15 @@ sub check {
 	push @blocked, $bin if $nr->{$pname};
       }
     }
+    @blocked = () if $neverblock;
     if (@blocked) {
-      print "      - $packid (kiwi-product)\n";
-      if (@blocked < 10) {
-        print "        blocked for sysbuild (@blocked)\n";
-      } else {
-        print "        blocked for sysbuild (@blocked[0..9] ...)\n";
+      if ($ctx->{'verbose'}) {
+        print "      - $packid (kiwi-product)\n";
+        if (@blocked < 10) {
+          print "        blocked for sysbuild (@blocked)\n";
+        } else {
+          print "        blocked for sysbuild (@blocked[0..9] ...)\n";
+        }
       }
       return ('blocked', join(', ', @blocked));
     }
@@ -272,28 +297,25 @@ sub check {
       }
       $ps = ($ps || {})->{'packstatus'} || {};
 
-      my $gbininfo;
-      if ($remoteprojs->{$aprojid}) {
-	$gbininfo = BSSched::Remote::read_gbininfo_remote($ctx, "$aprp/$arch", $remoteprojs->{$aprojid}, $ps);
-	if (!$gbininfo) {
-	  my $error = "project binary state of $aprp/$arch is unavailable";
-	  $error .= " (delayed)" if defined $gbininfo;
+      my $gbininfo = $ctx->read_gbininfo($aprp, $arch, $ps);
+      if (!$gbininfo && $remoteprojs->{$aprojid}) {
+	my $error = "project binary state of $aprp/$arch is unavailable";
+	$error .= " (delayed)" if defined $gbininfo;
+	if ($ctx->{'verbose'}) {
 	  print "      - $packid (kiwi-product)\n";
 	  print "        $error\n";
-	  if (defined $gbininfo) {
-	    $delayed_errors .= ", $error";
-	    next;
-	  }
-	  return ('broken', $error);
 	}
-      } else {
-	$gbininfo = BSSched::BuildResult::read_gbininfo("$reporoot/$aprp/$arch", $arch eq $myarch ? 0 : 1);
+	if (defined $gbininfo) {
+	  $delayed_errors .= ", $error";
+	  next;
+	}
+	return ('broken', $error);
       }
       next if $delayed_errors;
-      if (!$gbininfo && $arch ne $myarch && -d "$gctx->{'eventdir'}/$arch") {
+      if (!$gbininfo && $arch ne $myarch && $gctx->{'eventdir'} && -d "$gctx->{'eventdir'}/$arch") {
 	# mis-use unblocked to tell other scheduler that it is missing
-	print "    requesting :repoinfo for $aprp/$arch\n";
-	BSSched::EventSource::Directory::sendunblockedevent($gctx, $aprp, $arch);
+	print "    requesting :repoinfo for $aprp/$arch\n" if $ctx->{'verbose'};
+	$ctx->{'sendunblockedevents'}->{"$aprp/$arch"} = 2;
       }
       @apackids = BSUtil::unify(@apackids, sort keys %$gbininfo) if $gbininfo;
 
@@ -310,7 +332,7 @@ sub check {
 	if (($allpacks && !$deps{"-$apackid"} && !$deps{'-'.($known{$apackid} || '')}) || $deps{$apackid} || $deps{$known{$apackid} || ''}) {
 	  # hey, we probably need this package! wait till it's finished
 	  my $code = $ps->{$apackid} || 'unknown';
-	  if ($code eq 'scheduled' || $code eq 'blocked' || $code eq 'finished') {
+	  if (!$neverblock && ($code eq 'scheduled' || $code eq 'blocked' || $code eq 'finished')) {
 	    push @blocked, "$aprp/$arch/$apackid";
 	    $blockedarch{$arch} = 1;
 	    last if @blocked > $maxblocked;
@@ -359,7 +381,7 @@ sub check {
 	next unless $needit;
 	# ok we need it. check if the package is built.
 	my $code = $ps->{$apackid} || 'unknown';
-	if ($code eq 'scheduled' || $code eq 'blocked' || $code eq 'finished') {
+	if (!$neverblock && ($code eq 'scheduled' || $code eq 'blocked' || $code eq 'finished')) {
 	  push @blocked, "$aprp/$arch/$apackid";
 	  $blockedarch{$arch} = 1;
 	  last if @blocked > $maxblocked;
@@ -372,7 +394,7 @@ sub check {
     last if @blocked > $maxblocked;
   }
   return ('delayed', substr($delayed_errors, 2)) if $delayed_errors;
-  if ($myarch eq $buildarch) {
+  if ($markerdir && $myarch eq $buildarch) {
     # update waiting_for markers
     for my $arch (grep {$_ ne $buildarch} @archs) {
       if ($blockedarch{$arch}) {
@@ -386,25 +408,29 @@ sub check {
   }
   if (@blocked) {
     push @blocked, '...' if @blocked > $maxblocked;
-    print "      - $packid (kiwi-product)\n";
-    print "        blocked (@blocked)\n";
+    if ($ctx->{'verbose'}) {
+      print "      - $packid (kiwi-product)\n";
+      print "        blocked (@blocked)\n";
+    }
     return ('blocked', join(', ', @blocked));
   }
 
   if ($myarch ne $buildarch) {
     # looks good from our side. tell master arch to check it
-    if (-e "$markerdir/.waiting_for_$myarch") {
+    if ($markerdir && -e "$markerdir/.waiting_for_$myarch") {
       unlink("$markerdir/.waiting_for_$myarch");
-      BSSched::EventSource::Directory::sendunblockedevent($gctx, $prp, $buildarch);
-      print "      - $packid (kiwi-product)\n";
-      print "        unblocked\n";
+      $ctx->{'sendunblockedevents'}->{"$prp/$buildarch"} = 2;
+      if ($ctx->{'verbose'}) {
+        print "      - $packid (kiwi-product)\n";
+        print "        unblocked\n";
+      }
     }
+    $ctx->{'sendunblockedevents'}->{"$prp/$buildarch"} ||= 1 unless $ctx->{'isreposerver'};
     return ('excluded', "is built in architecture '$buildarch'");
   }
 
   # now create meta info
   my @new_meta;
-  push @new_meta, ($pdata->{'verifymd5'} || $pdata->{'srcmd5'})."  $packid";
   push @new_meta, map {"$_->{'srcmd5'}  $_->{'project'}/$_->{'package'}"} @{$info->{'extrasource'} || []};
   for my $rpm (sort {$rpms_meta{$a} cmp $rpms_meta{$b} || $a cmp $b} grep {$rpms_meta{$_}} @rpms) {
     my $id = $rpms_hdrmd5{$rpm};
@@ -412,7 +438,7 @@ sub check {
     $id ||= "deaddeaddeaddeaddeaddeaddeaddead";
     push @new_meta, "$id  $rpms_meta{$rpm}";
   }
-  return BSSched::BuildJob::metacheck($ctx, $packid, 'kiwi-product', \@new_meta, [ $bconf, \@rpms ]);
+  return BSSched::BuildJob::metacheck($ctx, $packid, $pdata, 'kiwi-product', \@new_meta, [ $bconf, \@rpms, $pool, \%dep2pkg ]);
 }
 
 
@@ -434,110 +460,57 @@ sub build {
   my $remoteprojs = $gctx->{'remoteprojs'};
   my $gdst = $ctx->{'gdst'};
 
-  my $bconf = $data->[0];
-  my $rpms = $data->[1];
-  my $reason = $data->[2];
+  my ($bconf, $rpms, $pool, $dep2pkg, $reason) = @$data;
   my $prp = "$projid/$repoid";
-  my $srcmd5 = $pdata->{'srcmd5'};
-  my $job = BSSched::BuildJob::jobname($prp, $packid);
-  my $myjobsdir = $gctx->{'myjobsdir'};
-  return ('scheduled', "$job-$srcmd5") if -s "$myjobsdir/$job-$srcmd5";
-  my @otherjobs = grep {/^\Q$job\E-[0-9a-f]{32}$/} ls($myjobsdir);
-  $job = "$job-$srcmd5";
 
-  # kill those ancient other jobs
-  for my $otherjob (@otherjobs) {
-    print "        killing old job $otherjob\n";
-    BSSched::BuildJob::killjob($gctx, $otherjob);
-  }
-
-  my $localbuildarch = $myarch eq 'local' && $BSConfig::localarch ? $BSConfig::localarch : $myarch;
-  my $now = time(); # ensure that we use the same time in all logs
-
-  my $syspath;
-  if (@{$repo->{'path'} || []}) {
-    # images repo has a configured path, use it to set up the kiwi system
-    $syspath = BSSched::BuildJob::path2buildinfopath($gctx, $gctx->{'prpsearchpath'}->{$prp});
-  }
-  my @aprps = BSSched::BuildJob::expandkiwipath($info, $ctx->{'prpsearchpath'});
-  my $searchpath = BSSched::BuildJob::path2buildinfopath($gctx, \@aprps);
+  my $dobuildinfo = $ctx->{'dobuildinfo'};
   my @bdeps;
-  my @pdeps = Build::get_preinstalls($bconf);
-  my @vmdeps = Build::get_vminstalls($bconf);
-  my %runscripts = map {$_ => 1} Build::get_runscripts($bconf);
-  my %pdeps = map {$_ => 1} @pdeps;
-  my %vmdeps = map {$_ => 1} @vmdeps;
-  for my $rpm (BSUtil::unify(@pdeps, @vmdeps, @{$rpms || []})) {
+  for my $rpm (BSUtil::unify(@{$rpms || []})) {
     my @b = split('/', $rpm);
-    if (@b == 1) {
-      # this is a build environment package
-      push @bdeps, { 'name' => $rpm, 'notmeta' => 1, };
-      $bdeps[-1]->{'preinstall'} = 1 if $pdeps{$rpm};
-      $bdeps[-1]->{'vminstall'} = 1 if $vmdeps{$rpm};
-      $bdeps[-1]->{'repoarch'} = $localbuildarch if $localbuildarch ne $myarch;
+    next if @b == 1;
+    next unless @b == 5;
+    my $b;
+    if ($b[4] =~ /^(?:::import::.*::)?(.+)-([^-]+)-([^-]+)\.([a-zA-Z][^\.\-]*)\.rpm$/) {
+      $b = {
+        'name' => $1,
+        'version' => $2,
+        'release' => $3,
+        'arch' => $4,
+        'project' => $b[0],
+        'repository' => $b[1],
+        'repoarch' => $b[2],
+        'package' => $b[3],
+      };
+    } elsif ($dobuildinfo && ($b[4] =~  /^(.*)[-.]appdata\.xml$/)) {
+      $b = {
+        'project' => $b[0],
+        'repository' => $b[1],
+        'repoarch' => $b[2],
+        'package' => $b[3],
+      };
+    } else {
       next;
     }
-    next unless @b == 5;
-    next unless $b[4] =~ /^(?:::import::.*::)?(.+)-([^-]+)-([^-]+)\.([a-zA-Z][^\.\-]*)\.rpm$/;
-    push @bdeps, {
-      'name' => $1,
-      'version' => $2,
-      'release' => $3,
-      'arch' => $4,
-      'project' => $b[0],
-      'repository' => $b[1],
-      'repoarch' => $b[2],
-      'package' => $b[3],
-    };
-  }
-  if ($info->{'extrasource'}) {
-    push @bdeps, map {{
-      'name' => $_->{'file'}, 'version' => '', 'repoarch' => 'src',
-      'project' => $_->{'project'}, 'package' => $_->{'package'}, 'srcmd5' => $_->{'srcmd5'},
-    }} @{$info->{'extrasource'}};
+    if ($dobuildinfo) {
+      $b->{'noinstall'} = 1;
+      $b->{'binary'} = $b[4];
+      delete $b->{'repoarch'} if $b->{'repoarch'} eq $myarch;
+    }
+    push @bdeps, $b;
   }
+  my $prpsearchpath = $ctx->{'prpsearchpath'};
+  $prpsearchpath = [] if !@{$repo->{'path'} || []};
 
-  my $dst = "$gdst/$packid";
-  mkdir_p($dst);
+  # setup expander again for now, to be removed
+  my $xp = BSSolv::expander->new($pool, $bconf);
+  no warnings 'redefine';
+  local *Build::expand = sub { $_[0] = $xp; goto &BSSolv::expander::expand; };
+  use warnings 'redefine';
 
-  my $bcnt = BSSched::BuildJob::nextbcnt($ctx, $packid, $pdata);
-
-  my $binfo = {
-    'project' => $projid,
-    'repository' => $repoid,
-    'package' => $packid,
-    'job' => $job,
-    'arch' => $myarch,
-    'srcmd5' => $srcmd5,
-    'verifymd5' => $pdata->{'verifymd5'} || $srcmd5,
-    'rev' => $pdata->{'rev'},
-    'file' => $info->{'file'},
-    'versrel' => $pdata->{'versrel'},
-    'bcnt' => $bcnt,
-    'bdep' => \@bdeps,
-    'path' => $searchpath,
-    'reason' => $reason->{'explain'},
-    'readytime' => $now,
-  };
-  my $obsname = $gctx->{'obsname'};
-  $binfo->{'disturl'} = "obs://$obsname/$projid/$repoid/$srcmd5-$packid";
-  $binfo->{'syspath'} = $syspath if $syspath;
-  $binfo->{'hostarch'} = $bconf->{'hostarch'} if $bconf->{'hostarch'};
-  $binfo->{'revtime'} = $pdata->{'revtime'} if $pdata->{'revtime'};
-  $binfo->{'imagetype'} = $info->{'imagetype'} if $info->{'imagetype'};
-  $binfo->{'nodbgpkgs'} = $info->{'nodbgpkgs'} if $info->{'nodbgpkgs'};
-  $binfo->{'nosrcpkgs'} = $info->{'nosrcpkgs'} if $info->{'nosrcpkgs'};
-  $binfo->{'constraintsmd5'} = $pdata->{'constraintsmd5'} if $pdata->{'constraintsmd5'};
-  $binfo->{'prjconfconstraint'} = $bconf->{'constraint'} if @{$bconf->{'constraint'} || []};
-  mkdir_p($dst);
-  writexml("$dst/.status", "$dst/status", { 'status' => 'scheduled', 'readytime' => $now, 'job' => $job}, $BSXML::buildstatus);
-  $reason->{'time'} = $now;
-  writexml("$dst/.reason", "$dst/reason", $reason, $BSXML::buildreason);
-  BSSched::BuildJob::writejob($gctx, $job, $binfo);
-  return ('scheduled', $job);
+  my $nctx = bless { %$ctx, 'prpsearchpath' => $prpsearchpath, 'conf' => $bconf, 'pool' => $pool, 'dep2pkg' => $dep2pkg, 'extrabdeps' => \@bdeps, 'realctx' => $ctx, 'expander' => $xp}, ref($ctx);
+  return BSSched::BuildJob::create($nctx, $packid, $pdata, $info, [], [], $reason, 0);
 }
 
-
 sub read_bininfo_oldok {
   my ($dir) = @_;
   my @s = stat("$dir/.bininfo");
