@@ -23,9 +23,8 @@ use Digest::MD5 ();
 use BSUtil;
 use BSSched::BuildJob;
 use BSXML;
-use Build;		                      # for query
-use BSVerify;		                  # for verify_nevraquery
-use BSSched::EventSource::Directory;  # for sendunblockedevent
+use Build;			# for query
+use BSVerify;			# for verify_nevraquery
 
 =head1 NAME
 
@@ -63,6 +62,28 @@ sub expand {
   return 1, splice(@_, 3);
 }
 
+sub get_bins {
+  my ($d) = @_;
+  my @dd = sort(ls($d));
+  my @d;
+  my $havebinlink;
+  for my $bin (@dd) {
+    next if $bin =~ /^::import::/;
+    if ($bin =~ /\.obsbinlnk$/) {
+      my $binlnk = BSUtil::retrieve("$d/$bin", 1);
+      next unless $binlnk;
+      push @d, $bin;
+      my $p = $binlnk->{'path'};
+      $p =~ s/.*\///;
+      push @d, grep {$_ ne $bin && /^\Q$p\E/}  @dd;
+      $havebinlink = 1;
+    }
+    push @d, $bin if $bin =~ /\.rpm$/;
+  }
+  @d = BSUtil::unify(@d) if $havebinlink;
+  return @d;
+}
+
 =head2 check - check if a patchinfo needs to be rebuilt
 
  TODO: add description
@@ -140,20 +161,19 @@ sub check {
     my $packstatus = $ctx->{'packstatus'};
     for my $apackid (@packages) {
       my $code = $packstatus->{$apackid} || '';
-      if ($code eq 'excluded') {
-        next;
-      }
-      if ($code ne 'done' && $code ne 'disabled') {
+      next if $code eq 'excluded';
+      if ($code ne 'done' && $code ne 'disabled' && $code ne 'locked') {
         $blocked = 1;
         last;
       }
       if (-e "$gdst/:logfiles.fail/$apackid") {
-        $blocked = 1;
-        last;
-      }
-      if (! -e "$gdst/:logfiles.success/$apackid") {
+        if (($code ne 'locked' && $code ne 'disabled') || -e "$gdst/:logfiles.success/$apackid") {
+          $blocked = 1;
+          last;
+	}
+      } elsif (! -e "$gdst/:logfiles.success/$apackid") {
         if (! -e "$gdst/$apackid/.channelinfo") {
-          next if $code eq 'disabled';
+          next if $code eq 'disabled' || $code eq 'locked';
           $blocked = 1;
           last;
         }
@@ -162,20 +182,21 @@ sub check {
     if (!$blocked) {
       if (-e "$markerdir/.waiting_for_$myarch") {
         unlink("$markerdir/.waiting_for_$myarch");
-        BSSched::EventSource::Directory::sendunblockedevent($gctx, $prp, $buildarch);
+        $ctx->{'sendunblockedevents'}->{"$prp/$buildarch"} = 2;
         print "      - $packid (patchinfo)\n";
         print "        unblocked\n";
       }
     }
     if ($blocked && !$broken) {
       # hmm, we should be blocked. trigger build arch check
-      if (!-e "$markerdir/.waiting_for_$myarch") {
+      if (! -e "$markerdir/.waiting_for_$myarch") {
         BSUtil::touch("$reporoot/$prp/$buildarch/:schedulerstate.dirty") if -d "$reporoot/$prp/$buildarch";
-        BSSched::EventSource::Directory::sendunblockedevent($gctx, $prp, $buildarch);
+        $ctx->{'sendunblockedevents'}->{"$prp/$buildarch"} = 2;
         print "      - $packid (patchinfo)\n";
         print "        blocked\n";
       }
     }
+    $ctx->{'sendunblockedevents'}->{"$prp/$buildarch"} ||= 1 unless $ctx->{'isreposerver'};
     return ('excluded', "is built in architecture '$buildarch'");
   }
 
@@ -223,32 +244,33 @@ sub check {
     for my $apackid (@packages) {
       my $code = $apackstatus->{$apackid} || '';
       next if $code eq 'excluded';
-      $enabled_seen = 1 unless $code eq 'disabled';
-      if ($code ne 'done' && $code ne 'disabled') {
+      if ($code ne 'done' && $code ne 'disabled' && $code ne 'locked') {
         $blockedarch = 1;
         push @blocked, "$arch/$apackid";
         next;
       }
       if (-e "$agdst/:logfiles.fail/$apackid") {
         # last build failed
-        if ($code ne 'disabled' || -e "$agdst/:logfiles.success/$apackid") {
+        if (($code ne 'locked' && $code ne 'disabled') || -e "$agdst/:logfiles.success/$apackid") {
           $blockedarch = 1;
           push @blocked, "$arch/$apackid (failed)";
           next;
         }
+	next;	# locked or disabled and nothing built, nothing to pick up
       } elsif (! -e "$agdst/:logfiles.success/$apackid") {
         # package was never built yet or channel
         if (! -e "$agdst/$apackid/.channelinfo") {
-          next if $code eq 'disabled';
+          next if $code eq 'disabled' || $code eq 'locked';
           $blockedarch = 1;
           push @blocked, "$arch/$apackid (no logfiles.success)";
           next;
-        }
+	}
       }
+      $enabled_seen = 1 unless $code eq 'disabled';
       if ($ptype eq 'binary') {
         # like aggregates
         my $d = "$agdst/$apackid";
-        my @d = grep {/\.rpm$/ && !/^::import::/} ls($d);
+        my @d = get_bins($d);
         my $m = '';
         for my $b (sort @d) {
           my @s = stat("$d/$b");
@@ -415,7 +437,7 @@ sub build {
       $target ||= $updateinfodata->{'target'} if $updateinfodata->{'target'};
     } else {
       $from = "$reporoot/$prp/$tocopy";
-      @bins = grep {/\.rpm$/ && !/^::import::/} ls($from);
+      @bins = get_bins($from);
       if (-e "$from/.channelinfo") {
         $channelinfo = BSUtil::retrieve("$from/.channelinfo");
         $target ||= $channelinfo->{'/target'} if $channelinfo->{'/target'};
@@ -452,6 +474,14 @@ sub build {
         # be extra careful with em, recalculate meta
         $m .= "$bin\0$s[9]/$s[7]/$s[1]\0" if @s;
       }
+      if ($bin !~ /\.rpm$/) {
+        if (%binaryfilter) {
+          unlink("$jobdatadir/$bin");
+          next;
+	}
+	$donebins{$bin} = $tocopy; 
+	next;
+      }
       my $d;
       eval {
         $d = Build::query("$jobdatadir/$bin", 'evra' => 1, 'unstrippedsource' => 1);
@@ -476,6 +506,13 @@ sub build {
           return ('broken', $error);
         }
       }
+      if ($d->{'arch'} ne 'src' && $d->{'arch'} ne 'nosrc' && -e "$from/$d->{'name'}.appdata.xml") {
+        unlink("$jobdatadir/$d->{'name'}.appdata.xml");
+        if (!link("$from/$d->{'name'}.appdata.xml", "$jobdatadir/$d->{'name'}.appdata.xml")) {
+          my $error = "link $from/$d->{'name'}.appdata.xml $jobdatadir/$d->{'name'}.appdata.xml: $!\n";
+          return ('broken', $error);
+        }
+      }
       $donebins{$bin} = $tocopy;
       $bininfo->{$bin} = {'name' => $d->{'name'}, 'arch' => $d->{'arch'}, 'hdrmd5' => $d->{'hdrmd5'}, 'filename' => $bin, 'id' => "$s[9]/$s[7]/$s[1]"};
       $bininfo->{$bin}->{'leadsigmd5'} = $d->{'leadsigmd5'} if $d->{'leadsigmd5'};
