@@ -87,11 +87,14 @@ use BSUtil;
 use BSConfiguration;
 use Build::Rpm;
 use BSSched::ProjPacks;		# for orderpackids
+use BSSched::DoD;
 #use BSSched::BuildResult;	# circular dep
 
 my $exportcnt = 0;
 my @binsufs = qw{rpm deb pkg.tar.gz pkg.tar.xz};
+my @binsufs_lnk = (@binsufs, 'obsbinlnk');
 my $binsufsre = join('|', map {"\Q$_\E"} @binsufs);
+my $binsufsre_lnk = join('|', map {"\Q$_\E"} @binsufs_lnk);
 
 =head1 FUNCTIONS / METHODS
 
@@ -164,7 +167,7 @@ sub fctx_add_binary_to_full {
   rename("$dir/$fn.dup", "$gdst/:full/$n.$suf") || die("rename $dir/$fn.dup $gdst/:full/$n.$suf: $!\n");
   unlink("$dir/$fn.dup");
   $fctx->{'oldids'}->{"$n.$suf"} = $r->{'id'};
-  for my $osuf (@binsufs) {
+  for my $osuf (@binsufs_lnk) {
     next if $suf eq $osuf;
     unlink("$gdst/:full/$n.$osuf");
     delete $fctx->{'oldids'}->{"$n.$osuf"};
@@ -189,7 +192,11 @@ sub fctx_add_binary_to_full {
       $fctx->{'metacache'}->{$n} = undef if $fctx->{'metacache_ismerge'};
     }
   }
-  delete $fctx->{'dep2meta'}->{$n} if $fctx->{'dep2meta'};
+  my $dep2meta = $fctx->{'dep2meta'};
+  if ($dep2meta) {
+    my $m = delete $dep2meta->{$n};
+    delete $dep2meta->{$m->[1]} if $m && $m->[1];
+  }
 }
 
 =head2 fctx_del_binary_from_full - remove a single binary from the full tree
@@ -202,7 +209,7 @@ sub fctx_del_binary_from_full {
   my $suf = $r->{'suf'};
   print "      - :full/$n.$suf\n";
   my $gdst = $fctx->{'gdst'};
-  for my $osuf (@binsufs) {
+  for my $osuf (@binsufs_lnk) {
     unlink("$gdst/:full/$n.$osuf");
     delete $fctx->{'oldids'}->{"$n.$osuf"};
   }
@@ -212,7 +219,11 @@ sub fctx_del_binary_from_full {
     delete $fctx->{'metacache'}->{$n};
     $fctx->{'metacache'}->{$n} = undef if $fctx->{'metacache_ismerge'};
   }
-  delete $fctx->{'dep2meta'}->{$n} if $fctx->{'dep2meta'};
+  my $dep2meta = $fctx->{'dep2meta'};
+  if ($dep2meta) {
+    my $m = delete $dep2meta->{$n};
+    delete $dep2meta->{$m->[1]} if $m && $m->[1];
+  }
 }
 
 =head2 volatile_cmp - compare evr of two volatile packages
@@ -247,7 +258,7 @@ sets packid and filename as side effect
 =cut
 
 sub fctx_gbininfo2full {
-  my ($fctx, $gbininfo, $oldpackid, $old, $useforbuildoverride) = @_;
+  my ($fctx, $gbininfo, $oldpackid, $old, $useforbuild) = @_;
   my $hadoldpackid;
   if (defined($oldpackid)) {
     $hadoldpackid = $gbininfo->{$oldpackid};
@@ -257,25 +268,35 @@ sub fctx_gbininfo2full {
   my $myarch = $gctx->{'arch'};
   my $projpacks = $gctx->{'projpacks'};
   my ($projid, $repoid) = split('/', $fctx->{'prp'}, 2);
-  my $proj = $projpacks->{$projid} || {},
-  my $prjuseforbuildenabled = 1;
-  $prjuseforbuildenabled = BSUtil::enabled($repoid, $proj->{'useforbuild'}, $prjuseforbuildenabled, $myarch);
-  my $pdatas = $proj->{'package'} || {};
+  my $proj = $projpacks->{$projid} || {};
   my @packids = BSSched::ProjPacks::orderpackids($proj, keys %$gbininfo);
+
+  # generate useforbuild from package data if not specified
+  if (!$useforbuild) {
+    $useforbuild = {};
+    my $prjuseforbuildenabled = 1;
+    $prjuseforbuildenabled = BSUtil::enabled($repoid, $proj->{'useforbuild'}, $prjuseforbuildenabled, $myarch);
+    my $pdatas = $proj->{'package'} || {};
+    for my $packid (@packids) {
+      next if $packid eq '_volatile';
+      my $useforbuildflags = ($pdatas->{$packid} || {})->{'useforbuild'};
+      my $useforbuildenabled = $prjuseforbuildenabled;
+      $useforbuildenabled = BSUtil::enabled($repoid, $useforbuildflags, $useforbuildenabled, $myarch) if $useforbuildflags;
+      $useforbuild->{$packid} = 1 if $useforbuildenabled;
+    }
+
+    if ($proj->{'missingpackages'}) {
+      # packages missing from pdatas, use old data
+      for my $packid (@{BSUtil::retrieve("$fctx->{'gdst'}/:full.useforbuild", 1) || []}) {
+        $useforbuild->{$packid} = 1 unless $pdatas->{$packid};
+      }
+    }
+  }
+
   # construct new full
   my %full;
   for my $packid (@packids) {
-    if ($packid ne '_volatile') {
-      if ($useforbuildoverride) {
-        next unless $useforbuildoverride->{$packid};
-      } else {
-        my $useforbuildflags = ($pdatas->{$packid} || {})->{'useforbuild'};
-        my $useforbuildenabled = $prjuseforbuildenabled;
-        $useforbuildenabled = BSUtil::enabled($repoid, $useforbuildflags, $useforbuildenabled, $myarch) if $useforbuildflags;
-        $useforbuildenabled = 1 if $packid eq '_volatile';
-        next unless $useforbuildenabled;
-      }
-    }
+    next unless $packid eq '_volatile' || $useforbuild->{$packid};
     my $bininfo = $gbininfo->{$packid};
     next if $bininfo->{'.nouseforbuild'};               # channels/patchinfos don't go into the full tree
     $bininfo = $old if defined($oldpackid) && $oldpackid eq $packid;
@@ -289,7 +310,7 @@ sub fctx_gbininfo2full {
         my $or = $full{$r->{'name'}};
         $full{$r->{'name'}} = $r if $or && $or->{'packid'} eq '_volatile' && volatile_cmp($r, $or);
       }
-      $full{$r->{'name'}} ||= $r;
+      $full{$r->{'name'}} ||= $r;		# first one wins
     }
   }
   delete $gbininfo->{$oldpackid} if defined($oldpackid) && !$hadoldpackid;
@@ -319,7 +340,7 @@ sub fctx_rebuild_full {
   my %newfullsuf = map {("$_->{'name'}.$_->{'suf'}" => $_)} values %$newfull;
   my %kept;
   for my $bin (sort(ls("$gdst/:full"))) {
-    next unless $bin =~ /\.($binsufsre)$/;      # hmm?
+    next unless $bin =~ /\.($binsufsre_lnk)$/;      # hmm?
     my $suf = $1;
     my $r = $newfullsuf{$bin};
     if ($r) {
@@ -401,7 +422,7 @@ sub fctx_migrate_full {
   my $dirty;
   my %packidschecked;
   for my $bin (sort(ls("$gdst/:full"))) {
-    next unless $bin =~ /\.($binsufsre)$/;      # hmm?
+    next unless $bin =~ /\.($binsufsre_lnk)$/;      # hmm?
     my $suf = $1;
     my @s = stat("$gdst/:full/$bin");
     next unless @s;
@@ -814,6 +835,13 @@ sub checkuseforbuild {
   if (!$olduseforbuild) {
     $olduseforbuild = [] unless -d "$gdst/:full";
   }
+  if ($olduseforbuild && $proj->{'missingpackages'}) {
+    # our pdatas are incomplete. Add missing entries from old data.
+    for my $packid (@$olduseforbuild) {
+      push @$newuseforbuild, $packid unless $pdatas->{$packid};
+    }
+    @$newuseforbuild = sort(@$newuseforbuild);
+  }
   $olduseforbuild = undef if $forcerebuild;
   if ($olduseforbuild) {
     return if join('/', @$olduseforbuild) eq join('/', @$newuseforbuild);
@@ -885,7 +913,7 @@ sub addrepo_scan {
   my @bins;
   local *D;
   if (opendir(D, $dir)) {
-    @bins = grep {/\.(?:$binsufsre)$/s && !/^\.dod\./s} readdir(D);
+    @bins = grep {/\.(?:$binsufsre_lnk)$/s && !/^\.dod\./s} readdir(D);
     closedir D;
     if (!@bins && -s "$dir.subdirs") {
       for my $subdir (split(' ', readstr("$dir.subdirs"))) {
