@@ -59,6 +59,7 @@ use BSSched::ProjPacks;			# for getconfig
 
 my @binsufs = qw{rpm deb pkg.tar.gz pkg.tar.xz};
 my $binsufsre = join('|', map {"\Q$_\E"} @binsufs);
+my $binsufsre_binlnk = join('|', map {"\Q$_\E"} (@binsufs, 'obsbinlnk'));
 
 our $new_full_handling = 1;
 $new_full_handling = $BSConfig::new_full_handling if defined $BSConfig::new_full_handling;
@@ -129,9 +130,10 @@ sub compile_exportfilter {
   my ($filter) = @_;
   return undef unless $filter;
   my @res;
-  for (@$filter) {
+  for my $f (@$filter) {
     eval {
-      push @res, [ qr/$_->[0]/, $_->[1] ];
+      $_ eq '.' || BSVerify::verify_arch($_) for @{$f->[1] || []};
+      push @res, [ qr/$f->[0]/, $f->[1] ];
     };
   }
   return \@res;
@@ -182,7 +184,7 @@ sub set_suf_and_filter_exports {
     next unless $r->{'source'};         # no src in full tree
     next unless $r->{'name'};           # need binary name
     my $suf;
-    $suf = $1 if $rp =~ /\.($binsufsre)$/;
+    $suf = $1 if $rp =~ /\.($binsufsre_binlnk)$/;
     next unless $suf;                   # need a valid suffix
     $r->{'suf'} = $suf;
     my $nn = $rp;
@@ -227,7 +229,15 @@ sub set_suf_and_filter_exports {
 sub update_bininfo_merge {
   my ($gdst, $packid, $bininfo) = @_;
   my $gbininfo = {};
-  $gbininfo = BSUtil::retrieve("$gdst/:bininfo.merge", 1) if -e "$gdst/:bininfo.merge";
+  if (-e "$gdst/:bininfo.merge") {
+    if (-s _ > 100000) {
+      # quite big. better merge now.
+      read_gbininfo($gdst);
+      $gbininfo = BSUtil::retrieve("$gdst/:bininfo.merge", 1) if -e "$gdst/:bininfo.merge";
+    } else {
+      $gbininfo = BSUtil::retrieve("$gdst/:bininfo.merge", 1);
+    }
+  }
   if ($gbininfo) {
     if ($bininfo) {
       # currently not needed, maybe later
@@ -252,18 +262,24 @@ sub update_bininfo_merge {
 =cut
 
 sub repofromfiles {
-  my ($files, $cache) = @_;
-  my @bins =  grep {/\.(?:$binsufsre)$/} @$files;
+  my ($dir, $files, $cache) = @_;
   my $repobins = {};
-  for my $bin (@bins) {
-    my @s = stat($bin);
+  for my $bin (@$files) {
+    next unless $bin =~ /\.(?:$binsufsre_binlnk)$/;
+    next if $bin =~ /\.delta\.rpm$/;	# those go not into the full tree
+    my @s = stat("$dir/$bin");
     next unless @s;
     my $id = "$s[9]/$s[7]/$s[1]";
     my $data;
     if ($cache && $cache->{$id}) {
       $data = { %{$cache->{$id}} };
     } else {
-      $data = Build::query($bin, 'evra' => 1);  # need arch
+      if ($bin =~ /\.obsbinlnk$/) {
+	$data = BSUtil::retrieve("$dir/$bin", 1);
+	delete $data->{'path'} if $data;
+      } else {
+        $data = Build::query("$dir/$bin", 'evra' => 1);  # need arch
+      }
       next unless $data;
     }
     eval {
@@ -272,7 +288,7 @@ sub repofromfiles {
     next if $@;
     delete $data->{'disttag'};
     $data->{'id'} = $id;
-    $repobins->{$bin} = $data;
+    $repobins->{"$dir/$bin"} = $data;
   }
   return $repobins;
 }
@@ -334,7 +350,7 @@ sub update_dst_full {
     $jobbininfo ||= read_bininfo($jobdir);
     delete $jobbininfo->{'.bininfo'};   # delete new version marker
     my $cache = { map {$_->{'id'} => $_} grep {$_->{'id'}} values %$jobbininfo };
-    $jobrepo = repofromfiles([ map {"$jobdir/$_"} grep {/\.(?:$binsufsre)$/ && !/\.delta\.rpm$/} @jobfiles ], $cache);
+    $jobrepo = repofromfiles($jobdir, \@jobfiles, $cache);
     $useforbuildenabled = 0 if -e "$jobdir/.channelinfo" || -e "$jobdir/updateinfo.xml";        # just in case
   } else {
     $jobrepo = {};
@@ -360,7 +376,7 @@ sub update_dst_full {
     my $oldbininfo = read_bininfo($dst);
     delete $oldbininfo->{'.bininfo'};   # delete new version marker
     my $oldcache = { map {$_->{'id'} => $_} grep {$_->{'id'}} values %$oldbininfo };
-    $oldrepo = repofromfiles([ map {"$dst/$_"} grep {/\.(?:$binsufsre)$/ && !/\.delta\.rpm$/} @oldfiles ], $oldcache);
+    $oldrepo = repofromfiles($dst, \@oldfiles, $oldcache);
 
     # move files over (and rename in import case)
     my %new;
@@ -536,7 +552,14 @@ sub read_bininfo {
     if ($file !~ /\.(?:$binsufsre)$/) {
       if ($file eq '.channelinfo' || $file eq 'updateinfo.xml') {
         $bininfo->{'.nouseforbuild'} = {};
-      } elsif ($file =~ /-appdata\.xml$/) {
+      } elsif ($file =~ /\.obsbinlnk$/) {
+	my @s = stat("$dir/$file");
+	my $d = BSUtil::retrieve("$dir/$file", 1);
+	next unless @s && $d;
+	my $r = {%$d, 'filename' => $file, 'id' => "$s[9]/$s[7]/$s[1]"};
+	delete $r->{'path'};
+	$bininfo->{$file} = $r;
+      } elsif ($file =~ /[-.]appdata\.xml$/) {
         local *F;
         open(F, '<', "$dir/$file") || next;
         my @s = stat(F);
@@ -663,7 +686,7 @@ sub remove_from_volatile {
   my ($gdst, $del) = @_;
   for my $r (@$del) {
     my $bin = $r->{'filename'};
-    next unless $bin =~ /^(.*)\.($binsufsre)$/; # hmm?
+    next unless $bin =~ /^(.*)\.($binsufsre_binlnk)$/; # hmm?
     print "      - _volatile/$bin\n";
     unlink("$gdst/_volatile/$1.meta");
     unlink("$gdst/_volatile/$bin");
@@ -693,7 +716,7 @@ sub wipe {
   my $useforbuildenabled = 1;
   $useforbuildenabled = BSUtil::enabled($repoid, $proj->{'useforbuild'}, $useforbuildenabled, $myarch) if $proj;
   $useforbuildenabled = BSUtil::enabled($repoid, $pdata->{'useforbuild'}, $useforbuildenabled, $myarch);
-  my $importarch = '';  # keep those imports
+  my $importarch = '';					# keep those imports
   my $prpsearchpath = $gctx->{'prpsearchpath'}->{$prp};
   update_dst_full($gctx, $prp, $packid, undef, undef, $useforbuildenabled, $prpsearchpath, undef, $importarch);
   delete $gctx->{'repounchanged'}->{$prp};
@@ -702,7 +725,9 @@ sub wipe {
   unlink("$gdst/:logfiles.fail/$packid");
   unlink("$gdst/:meta/$packid");
   for my $f (ls("$gdst/$packid")) {
-    next if $f eq 'history';
+    next if $f eq 'history' || $f eq '.bininfo';
+    next if $f =~ /^::import::/;			# keep those imports
+    next if $f =~ /^\.meta\.success\.import\./;		# keep those imports
     if (-d "$gdst/$packid/$f") {
       BSUtil::cleandir("$gdst/$packid/$f");
       rmdir("$gdst/$packid/$f");
