@@ -21,6 +21,7 @@ use strict;
 use warnings;
 
 use Data::Dumper;
+use Storable;
 
 use BSUtil;
 use BSXML;
@@ -51,6 +52,7 @@ our %event_handlers = (
   'recheck'         => \&BSSched::EventHandler::event_check,
   'admincheck'      => \&BSSched::EventHandler::event_check,
   'unblocked'       => \&BSSched::EventHandler::event_check_med,
+  'lowunblocked'    => \&BSSched::EventHandler::event_check_med,
   'relsync'         => \&BSSched::EventHandler::event_check_med,
   'scanrepo'        => \&BSSched::EventHandler::event_scanrepo,
   'scanprjbinaries' => \&BSSched::EventHandler::event_scanprjbinaries,
@@ -64,6 +66,10 @@ our %event_handlers = (
   'useforbuild'     => \&BSSched::EventHandler::event_useforbuild,
   'configuration'   => \&BSSched::EventHandler::event_configuration,
   'suspendproject'  => \&BSSched::EventHandler::event_suspendproject,
+  'resumeproject'   => \&BSSched::EventHandler::event_resumeproject,
+  'memstats'        => \&BSSched::EventHandler::event_memstats,
+  'dispatchdetails' => \&BSSched::EventHandler::event_dispatchdetails,
+  'force_publish'   => \&BSSched::EventHandler::event_force_publish,
 );
 
 =head1 NAME
@@ -235,13 +241,13 @@ sub event_check_med {
   my ($ectx, $ev) = @_;
 
   my $gctx = $ectx->{'gctx'};
-  my $changed_med = $gctx->{'changed_med'};
+  my $changed = $ev->{'type'} eq 'lowunblocked' ?  $gctx->{'changed_low'} : $gctx->{'changed_med'};
   my $projid = $ev->{'project'};
   my $repoid = $ev->{'repository'};
   return unless defined($projid) && defined($repoid);
   my $prp = "$projid/$repoid";
   print "$prp is $ev->{'type'}\n";
-  $changed_med->{$prp} ||= 1;
+  $changed->{$prp} ||= 1;
 }
 
 =head2 event_scanrepo - TODO: add summary
@@ -293,7 +299,14 @@ sub event_scanprjbinaries {
   my $remoteprojs = $gctx->{'remoteprojs'};
   if (defined($projid) && defined($repoid)) {
     my $prp = "$projid/$repoid";
-    delete $gctx->{'remotegbininfos'}->{"$prp/$myarch"};
+    my $arch = $ev->{'arch'} || $myarch;
+    delete $gctx->{'remotegbininfos'}->{"$prp/$arch"};
+    if ($ev->{'arch'}) {
+      # remote gbininfo retry event
+      my $changed_med = $gctx->{'changed_med'};
+      $changed_med->{$prp} = 2;
+      return;
+    }
     return if $remoteprojs->{$projid};
     if (defined($packid)) {
       unlink("$prp/$myarch/$packid/.bininfo");
@@ -370,8 +383,7 @@ sub event_wipe {
   my $reporoot = $gctx->{'reporoot'};
   my $gdst = "$reporoot/$prp/$myarch";
   print "wiping $prp $packid\n";
-  return unless -d "$gdst/$packid";
-  BSSched::BuildResult::wipe($gctx, $prp, $packid);
+  BSSched::BuildResult::wipe($gctx, $prp, $packid) if -d "$gdst/$packid";
   for $prp (@{$gctx->{'prps'}}) {
     if ((split('/', $prp, 2))[0] eq $projid) {
       $changed_high->{$prp} = 2;
@@ -477,7 +489,7 @@ sub event_exit {
   $schedstate->{'repounchanged'} = $gctx->{'repounchanged'};
   $schedstate->{'projsuspended'} = $gctx->{'projsuspended'};
   $schedstate->{'delayedfetchprojpacks'} = $gctx->{'delayedfetchprojpacks'};
-  $schedstate->{'watchremote_start'} = $gctx->{'watchremote_start'};
+  $schedstate->{'watchremote_start'} = $gctx->{'watchremote_start_copy'} || $gctx->{'watchremote_start'};
   $schedstate->{'fetchprojpacks'} = $ectx->{'fetchprojpacks'} if %{$ectx->{'fetchprojpacks'} || {}};
   # collect all running async projpack requests
   my $running = BSSched::ProjPacks::runningfetchprojpacks($gctx);
@@ -485,6 +497,8 @@ sub event_exit {
     $schedstate->{'fetchprojpacks'} ||= {};
     $schedstate->{'fetchprojpacks'}->{$projid} = [ @{$schedstate->{'fetchprojpacks'}->{$projid} || []}, @{$running->{$projid}} ];
   }
+  my @retryevents = $gctx->{'retryevents'}->events();
+  $schedstate->{'retryevents'} = \@retryevents if @retryevents;
 
   my $rundir = $gctx->{'rundir'};
   unlink("$rundir/bs_sched.$myarch.state");
@@ -534,6 +548,29 @@ sub event_suspendproject {
   }
 }
 
+sub event_resumeproject {
+  my ($ectx, $ev) = @_;
+  my $projid = $ev->{'project'};
+  my $gctx = $ectx->{'gctx'};
+  my $job = $gctx->{'projsuspended'}->{$projid};
+  my $evjob = $ev->{'job'} || '';
+  if (!$job) {
+    print "ignoring resumeproject for project $projid ($evjob)\n";
+    return;
+  }
+  print "resuming project $projid: $job ($evjob)\n";
+  delete $gctx->{'projsuspended'}->{$projid};
+  my $changed_high = $gctx->{'changed_high'};
+  my $changed_dirty = $gctx->{'changed_dirty'};
+  $changed_high->{$projid} ||= 1;
+  for my $prp (@{$gctx->{'prps'}}) {
+    if ((split('/', $prp, 2))[0] eq $projid) {
+      $changed_high->{$prp} ||= 1;
+      $changed_dirty->{$prp} = 1;
+    }
+  }
+}
+
 =head2 event_uploadbuildimport_delay - check if an upload event needs to be delayed
 
  TODO: add description
@@ -556,6 +593,10 @@ sub event_uploadbuildimport_delay {
   my $info = readxml("$myjobsdir/$ev->{'job'}", $BSXML::buildinfo, 1) || {};
   my $projid = $info->{'project'};
   my $packid = $info->{'package'};
+  if ($packid =~ /(?<!^_product)(?<!^_patchinfo):./) {
+    # remove multibuild flavor
+    $packid =~ s/(?<!^_product)(?<!^_patchinfo):.*//;
+  }
   return 0 unless defined($projid);
   return 1 if $gctx->{'rctx'}->xrpc_busy($projid);      # delay if getprojpack in progress
   return 0 unless defined($packid);
@@ -570,4 +611,59 @@ sub event_uploadbuildimport_delay {
   return 0;
 }
 
+sub event_memstats {
+  my ($ectx, $ev) = @_;
+  my $gctx = $ectx->{'gctx'};
+  my %gctx = %$gctx;
+  %$gctx = ();
+  eval{
+    my %m = %gctx;
+    for my $q ('rctx') {
+      my $qq = delete $m{$q};
+      $m{"${q}_$_"} = $qq->{$_} for keys %$qq;
+    }
+
+    %m = %{$m{$ev->{'job'}} || {}} if $ev->{'job'};
+
+    my %mm;
+    local $Storable::forgive_me = 1;
+    local $SIG{__WARN__} = sub {};
+    for my $k (sort keys %m) {
+      next unless ref $m{$k};
+      my $l = length(Storable::nfreeze($m{$k}));
+      $mm{$k} = $l;
+    }
+    my @k = sort {$mm{$b} <=> $mm{$a}} keys %mm;
+    @k = splice(@k, 0, 10) if $ev->{'job'};	# top 10 only
+    for my $k (@k) {
+      my $l = int($mm{$k} / 1024);
+      print "$k: $l KB\n" if $l || $ev->{'job'};
+    }
+  };
+  warn($@) if $@;
+  %$gctx = %gctx;
+}
+
+sub event_dispatchdetails {
+  my ($ectx, $ev) = @_;
+  my $gctx = $ectx->{'gctx'};
+  my $myarch = $gctx->{'arch'};
+  my $myjobsdir = $gctx->{'myjobsdir'};
+  my $reporoot = $gctx->{'reporoot'};
+  my $info = readxml("$myjobsdir/$ev->{'job'}", $BSXML::buildinfo, 1);
+  return unless $info;
+  return if -e "$myjobsdir/$ev->{'job'}:status";
+  my $gdst = "$reporoot/$info->{'project'}/$info->{'repository'}/$myarch";
+  BSUtil::appendstr("$gdst/:packstatus.finished", "scheduled $info->{'package'}/$ev->{'job'}/$ev->{'details'}\n");
+}
+
+sub event_force_publish {
+  my ($ectx, $ev) = @_;
+  my $gctx = $ectx->{'gctx'};
+  my $repoid = $ev->{'repository'};
+  my $projid = $ev->{'project'};
+  my $ctx = BSSched::Checker->new($gctx, "$projid/$repoid");
+  $ctx->publish(undef, undef, 1);
+}
+
 1;
