@@ -99,6 +99,39 @@ sub checkbuildrepoid {
   die("ERROR: source server repository id($projpacksin->{'repoid'}) does not match my repository id($buildrepoid)") unless $buildrepoid eq $projpacksin->{'repoid'};
 }
 
+=head2 get_projpacks_all_sync -   get/update project/package information of all packages
+
+ This is used as emergency fallback when we hit some problem.
+
+=cut
+
+sub get_projpacks_all_sync {
+  my ($gctx) = @_;
+  my $myarch = $gctx->{'arch'};
+  my @args = ('withsrcmd5', 'withdeps', 'withrepos', 'withconfig', 'withremotemap', "arch=$myarch");
+  push @args, "partition=$BSConfig::partition" if $BSConfig::partition;
+  my $projpacksin;
+  while (1) {
+    my $param = {
+      'uri' => "$BSConfig::srcserver/getprojpack",
+    };
+    eval {
+      if ($usestorableforprojpack) {
+        $projpacksin = $gctx->{'rctx'}->xrpc($gctx, undef, $param, \&BSUtil::fromstorable, 'view=storable', @args);
+      } else {
+        $projpacksin = $gctx->{'rctx'}->xrpc($gctx, undef, $param, $BSXML::projpack, @args);
+      }
+    };
+    last if !$@ && $projpacksin;
+    print $@ if $@;
+    printf("could not get project/package information, sleeping 1 minute\n");
+    sleep(60);
+    print "retrying...\n";
+  }
+  update_projpacks($gctx, $projpacksin);
+  get_projpacks_postprocess($gctx);	# just in case
+  return 1;
+}
 
 =head2 get_projpacks -   get/update project/package information
 
@@ -119,66 +152,54 @@ sub get_projpacks {
 
   $projid ||= $testprojid;
 
-  my @args;
+  my @args = ('withsrcmd5', 'withdeps', 'withrepos', 'withconfig', 'withremotemap', "arch=$myarch");
   push @args, "partition=$BSConfig::partition" if $BSConfig::partition;
-  if (@packids) {
+  if (!defined($projid)) {
+    print "getting data for all projects from $BSConfig::srcserver\n";
+  } elsif (!@packids) {
+    print "getting data for project '$projid' from $BSConfig::srcserver\n";
+    push @args, "project=$projid";
+    push @args, 'nopackages' if $testprojid && $projid ne $testprojid;
+  } else {
     print "getting data for project '$projid' package '".join("', '", @packids)."' from $BSConfig::srcserver\n";
     push @args, "project=$projid";
     for my $packid (@packids) {
+      if ($packid =~ /(?<!^_product)(?<!^_patchinfo):./ && $packid =~ /^(.*):[^:]+$/) {
+	push @args, "package=$1" unless grep {$_ eq "package=$1"} @args;
+	next;
+      }
       push @args, "package=$packid";
     }
-  } elsif (defined($projid)) {
-    print "getting data for project '$projid' from $BSConfig::srcserver\n";
-    push @args, "project=$projid";
-  } else {
-    print "getting data for all projects from $BSConfig::srcserver\n";
-  }
-  my $projpacksin;
-  while (1) {
-    push @args, 'nopackages' if $testprojid && $projid ne $testprojid;
-    for my $tries (4, 3, 2, 1, 0) {
-      my $param = {
-	'uri' => "$BSConfig::srcserver/getprojpack",
-      };
-      if ($doasync) {
-	$param->{'async'} = { %$doasync, '_resume' => \&get_projpacks_resume, '_projid' => $projid, '_changeprp' => $projid };
-	$param->{'async'}->{'_packids'} = [ @packids ] if @packids;
-      }
-      eval {
-	if ($usestorableforprojpack) {
-	  $projpacksin = $gctx->{'rctx'}->xrpc($gctx, $projid, $param, \&BSUtil::fromstorable, 'view=storable', 'withsrcmd5', 'withdeps', 'withrepos', 'withconfig', 'withremotemap', "arch=$myarch", @args);
-	} else {
-	  $projpacksin = $gctx->{'rctx'}->xrpc($gctx, $projid, $param, $BSXML::projpack, 'withsrcmd5', 'withdeps', 'withrepos', 'withconfig', 'withremotemap', "arch=$myarch", @args);
-	}
-      };
-      return 0 if !$@ && $projpacksin && $param->{'async'};
-      last unless $@ || !$projpacksin;
-      last unless $tries && defined($projid);
-      print $@ if $@;
-      print "retrying...\n";
-      sleep(60);
-    }
-    if ($@ || !$projpacksin) {
-      print $@ if $@;
-      if (@args) {
-	print "retrying...\n";
-	get_projpacks($gctx, undef);
-	get_projpacks_postprocess($gctx);       # just in case...
-	return 1;
-      }
-      die("could not get project/package information, aborting due to testmode\n") if $gctx->{'testmode'};
-      printf("could not get project/package information, sleeping 1 minute\n");
-      sleep(60);
-      print "retrying...\n";
-      next;
-    }
-    last;
   }
 
+  my $projpacksin;
+  for my $tries (4, 3, 2, 1, 0) {
+    my $param = {
+      'uri' => "$BSConfig::srcserver/getprojpack",
+    };
+    if ($doasync) {
+      $param->{'async'} = { %$doasync, '_resume' => \&get_projpacks_resume, '_projid' => $projid, '_changeprp' => $projid };
+      $param->{'async'}->{'_packids'} = [ @packids ] if @packids;
+    }
+    eval {
+      if ($usestorableforprojpack) {
+	$projpacksin = $gctx->{'rctx'}->xrpc($gctx, $projid, $param, \&BSUtil::fromstorable, 'view=storable', @args);
+      } else {
+	$projpacksin = $gctx->{'rctx'}->xrpc($gctx, $projid, $param, $BSXML::projpack, @args);
+      }
+    };
+    return 0 if !$@ && $projpacksin && $param->{'async'};	# in progress
+    last unless $@ || !$projpacksin;
+    print $@ if $@;
+    die("could not get project/package information, aborting due to testmode\n") if $gctx->{'testmode'};
+    return get_projpacks_all_sync($gctx) unless $tries;		# do it the hard way
+    print "retrying after 1 minute...\n";
+    sleep(60);
+  }
   update_projpacks($gctx, $projpacksin, $projid, \@packids);
 
   if ($testprojid) {
-    my $proj = $projpacks->{$projid};
+    my $proj = $projpacks->{$projid} || {};
     for my $repo (@{$proj->{'repository'} || []}) {
       for my $path (@{$repo->{'path'} || []}) {
 	next if $path->{'project'} eq $testprojid;
@@ -333,8 +354,15 @@ sub update_projpacks {
     delete $projpacks->{$projid};
     $isgone = 1;
   } elsif ($projpacks->{$projid} && $projpacks->{$projid}->{'package'}) {
+    my $packs =  $projpacks->{$projid}->{'package'};
     for my $packid (@$packids) {
-      delete $projpacks->{$projid}->{'package'}->{$packid};
+      delete $packs->{$packid};
+    }
+    # we always send all multibuild packages in the reply, so delete them as well
+    my %packids = map {$_ => 1} @$packids;
+    for my $packid (grep {/(?<!^_product)(?<!^_patchinfo):./} keys %$packs) {
+      next unless $packid =~ /^(.*):[^:]+$/;
+      delete $packs->{$packid} if $packids{$1};
     }
   }
   # incorporate new channel data
@@ -561,9 +589,15 @@ sub clone_projpacks_part {
   $oldprojdata = Storable::dclone($oldprojdata);
   my $oldpackdata = {};
   my $packs = ($projpacks->{$projid} || {})->{'package'} || {};
+  my %packids = map {$_ => 1} @$packids;
   for my $packid (@$packids) {
     $oldpackdata->{$packid} = $packs->{$packid} ? Storable::dclone($packs->{$packid}) : undef;
   }
+  # clone multibuild packages as well
+  for my $packid (grep {/(?<!^_product)(?<!^_patchinfo):./} keys %$packs) {
+    next unless $packid =~ /^(.*):[^:]+$/;
+    $oldpackdata->{$packid} = $packs->{$packid} ? Storable::dclone($packs->{$packid}) : undef if $packids{$1};
+  }
   $oldprojdata->{'package'} = $oldpackdata;
   return $oldprojdata;
 }
@@ -576,6 +610,7 @@ sub clone_projpacks_part {
 sub postprocess_needed_check {
   my ($gctx, $projid, $oldprojdata) = @_;
 
+  return 1 if $gctx->{'get_projpacks_postprocess_needed'};
   my $projpacks = $gctx->{'projpacks'};
   return 0 if !defined($oldprojdata) && !$projpacks->{$projid};
   return 1 unless $oldprojdata && $oldprojdata->{'package'};            # sanity
@@ -591,6 +626,11 @@ sub postprocess_needed_check {
       return 1;
     }
   }
+  # check if we had all multibuild packages before
+  for my $packid (grep {/(?<!^_product)(?<!^_patchinfo):./} keys %$packs) {
+    next unless $packid =~ /^(.*):[^:]+$/;
+    return 1 if $oldpackdata->{$1} && !$oldpackdata->{$packid};
+  }
   return 0;
 }
 
@@ -605,6 +645,7 @@ sub postprocess_needed_check {
 sub get_projpacks_postprocess {
   my ($gctx) = @_;
 
+  delete $gctx->{'get_projpacks_postprocess_needed'};
   BSSched::Remote::beginwatchcollection($gctx);
 
   #print Dumper($projpacks);
@@ -811,7 +852,7 @@ sub calc_prps {
     my @pdatas = values(%{$proj->{'package'} || {}});
     my @aggs = grep {$_->{'aggregatelist'}} @pdatas;
     my @channels = grep {$_->{'channel'}} @pdatas;
-    my @kiwiinfos = grep {$_->{'path'}} map {@{$_->{'info'} || []}} @pdatas;
+    my @kiwiinfos = grep {$_->{'path'} || $_->{'containerpath'}} map {@{$_->{'info'} || []}} @pdatas;
     @pdatas = ();               # free mem
     my %channelrepos;
     for my $channel (map {$_->{'channel'}} @channels) {
@@ -867,7 +908,10 @@ sub calc_prps {
       }
       if (@kiwiinfos) {
 	# push repositories used in all kiwi files
-	push @xsp, map {"$_->{'project'}/$_->{'repository'}"} grep {$_->{'project'} ne '_obsrepositories'} map {@{$_->{'path'}}} grep {$_->{'repository'} eq $repoid} @kiwiinfos;
+	for my $info (grep {$_->{'repository'} eq $repoid} @kiwiinfos) {
+	  push @xsp, map {"$_->{'project'}/$_->{'repository'}"} grep {$_->{'project'} ne '_obsrepositories'} @{$info->{'path'} || []};
+	  push @xsp, map {"$_->{'project'}/$_->{'repository'}"} grep {$_->{'project'} ne '_obsrepositories'} @{$info->{'containerpath'} || []};
+        }
       }
       if ($channelrepos{$repoid}) {
 	# let a channel repo target all non-channel repos
@@ -1296,6 +1340,8 @@ sub runningfetchprojpacks {
     my $meta;
     my $all;
     for my $async ($handle, map {$_->{'async'}} $gctx->{'rctx'}->xrpc_nextparams($handle)) {
+      # workaround for rpcs that are delayed due to server load
+      $async = $async->{'_xrpc_data'}->[2]->{'async'} if $async && $async->{'_xrpc_data'};
       next if !$async || ($async->{'_projid'} || '') ne $projid;
       $good = 1;
       if ($async->{'_packids'}) {
@@ -1315,4 +1361,50 @@ sub runningfetchprojpacks {
   return \%running;
 }
 
+sub get_remoteproject_resume {
+  my ($gctx, $handle, $error, $projpacksin) = @_;
+  my $projid = $handle->{'_projid'};
+  delete $gctx->{'remotemissing'}->{$projid};
+  if ($error) {
+    chomp $error;
+    warn("$error\n");
+    return;
+  }
+  BSSched::Remote::remotemap2remoteprojs($gctx, $projpacksin->{'remotemap'});
+  $gctx->{'remotemissing'}->{$projid} = 1 if !$gctx->{'projpacks'}->{$projid} && !$gctx->{'remoteprojs'}->{$projid};
+  BSSched::Lookat::setchanged($gctx, $handle->{'_changeprp'}, $handle->{'_changetype'}, $handle->{'_changelevel'});
+}
+
+sub get_remoteproject {
+  my ($gctx, $doasync, $projid) = @_;
+
+  my $myarch = $gctx->{'arch'};
+  print "getting data for remote project '$projid' from $BSConfig::srcserver\n";
+  my @args;
+  push @args, "partition=$BSConfig::partition" if $BSConfig::partition;
+  push @args, "project=$projid";
+  my $param = {
+    'uri' => "$BSConfig::srcserver/getprojpack",
+  };
+  if ($doasync) {
+    $param->{'async'} = { %$doasync, '_resume' => \&get_remoteproject_resume, '_projid' => $projid};
+  }
+  my $projpacksin;
+  eval {
+    if ($usestorableforprojpack) {
+      $projpacksin = $gctx->{'rctx'}->xrpc($gctx, $projid, $param, \&BSUtil::fromstorable, 'view=storable', 'withconfig', 'withremotemap', 'remotemaponly', "arch=$myarch", @args);
+    } else {
+      $projpacksin = $gctx->{'rctx'}->xrpc($gctx, $projid, $param, $BSXML::projpack, 'withconfig', 'withremotemap', 'remotemaponly', "arch=$myarch", @args);
+    }
+  };
+  return 0 if !$@ && $projpacksin && $param->{'async'};
+  delete $gctx->{'remotemissing'}->{$projid};
+  if ($@) {
+    warn($@) if $@;
+    return;
+  }
+  BSSched::Remote::remotemap2remoteprojs($gctx, $projpacksin->{'remotemap'});
+  $gctx->{'remotemissing'}->{$projid} = 1 if !$gctx->{'projpacks'}->{$projid} && !$gctx->{'remoteprojs'}->{$projid};
+}
+
 1;
