@@ -24,11 +24,123 @@ package BSSrcdiff;
 
 use Digest::MD5;
 use Fcntl;
+eval { require Diff::LibXDiff };
 
 use strict;
 
 use BSUtil;
 
+my $havelibxdiff;
+$havelibxdiff = 1 if defined(&Diff::LibXDiff::diff);
+
+#
+# batcher support: if we need to do lots of diffs for a bif tar archive,
+# we call the diff program from an extra process. While this sounds like
+# something that makes no sense at all, it actually speeds up diffing
+# by a factor of 20. The reason is that fork/exec is much slower if the
+# process has a big memory size.
+#
+# A better approach would be a perl module that does the diffing with
+# no exec at all but alas, there seems to be no such thing (execpt a
+# pure perl version that is too slow).
+#
+my $batcherpid;
+
+sub batcher {
+  $| = 1;
+  open(OUT, ">&3") || die("open fd 3: $!\n");
+  my $r = 0;
+  while (1) {
+    my $in = '';
+    my $inl = sysread(STDIN, $in, 4);
+    last if defined($inl) && $inl == 0;
+    die("read error length\n") unless $inl && $inl == 4;
+    $inl = unpack('N', $in);
+    if ($inl == 0) {	# ping
+      syswrite(OUT, $in, 4);
+      next;
+    }
+    $in = '';
+    while ($inl > 0) {
+      my $l = $inl > 8192 ? 8192 : $inl;
+      $l = sysread(STDIN, $in, $l, length($in));
+      die("read error body\n") unless $l && $l > 0;
+      $inl -= $l;
+    }
+    $in = BSUtil::fromstorable($in);
+    $in = BSSrcdiff::filediff(@$in);
+    $in = BSUtil::tostorable($in);
+    $in = pack('N', length($in)).$in;
+    while (length($in)) {
+      my $l = syswrite(OUT, $in, length($in));
+      die("write error: $!\n") unless $l;
+      $in = substr($in, $l);
+    }
+    eval {
+      exec("/usr/bin/perl", '-I', $INC[0], '-MBSSrcdiff', '-e', 'BSSrcdiff::batcher()') if $r++ == 1000;
+    };
+    warn($@) if $@;
+  }
+}
+
+sub startbatcher {
+  die("batcher is already running\n") if $batcherpid;
+  pipe(BATCHERIN, TOBATCHER);
+  pipe(FROMBATCHER, BATCHEROUT);
+  if (($batcherpid = xfork()) == 0) {
+    close(TOBATCHER);
+    close(FROMBATCHER);
+    POSIX::dup2(fileno(BATCHERIN), 0);
+    POSIX::dup2(fileno(BATCHEROUT), 3);
+    my $dir = __FILE__;
+    $dir =~ s/[^\/]+$/./;
+    exec("/usr/bin/perl", '-I', $dir, '-MBSSrcdiff', '-e', 'BSSrcdiff::batcher()');
+    die("/usr/bin/perl: $!\n");
+  }
+  my $p = '';
+  close(BATCHEROUT);
+  syswrite(TOBATCHER, "\000\000\000\000", 4);
+  if (sysread(FROMBATCHER, $p, 4) != 4 || $p ne "\000\000\000\000") {
+    warn("batcher did not start\n");
+    close(BATCHEROUT);
+    close(TOBATCHER);
+    close(FROMBATCHER);
+    waitpid($batcherpid, 0);
+    undef($batcherpid);
+    return;
+  }
+  close(BATCHERIN);
+}
+
+sub endbatcher {
+  return unless $batcherpid;
+  close(TOBATCHER);
+  close(FROMBATCHER);
+  waitpid($batcherpid, 0);
+  undef($batcherpid);
+}
+
+sub filediff_batcher {
+  die("batcher is not running\n") unless $batcherpid;
+  my $p = BSUtil::tostorable(\@_);
+  $p = pack('N', length($p)).$p;
+  while (length($p)) {
+    my $l = syswrite(TOBATCHER, $p, length($p));
+    die("batcher write: $!\n") unless $l;
+    $p = substr($p, $l);
+  }
+  $p = '';
+  sysread(FROMBATCHER, $p, 4) == 4 || die;
+  my $pl = unpack('N', $p);
+  $p = '';
+  while ($pl > 0) {
+    my $l = $pl > 8192 ? 8192 : $pl;
+    $l = sysread(FROMBATCHER, $p, $l, length($p));
+    die unless $l > 0;
+    $pl -= $l;
+  }
+  return BSUtil::fromstorable($p);
+}
 
 #
 # fmax: maximum number of lines in a diff
@@ -57,6 +169,15 @@ sub opentar {
   }
 }
 
+#
+# entries have the following attributes:
+#
+#   name: name in tar file
+#   type: [-dlbcp] type of file
+#   size: size in bytes
+#   mode: mode as rwx... string
+#   info: md5sum for plain files, link target for symlinks
+
 sub listtar {
   my ($tar, $gemdata) = @_;
   local *F;
@@ -84,7 +205,7 @@ sub listtar {
       if ($size == 0) {
 	$info = 'd41d8cd98f00b204e9800998ecf8427e';
       } else {
-	$fc++;
+	$fc++;		# need 2nd pass
       }
     }
     push @c, {'type' => $type, 'name' => $name, 'size' => $size, 'mode' => $mode};
@@ -128,7 +249,15 @@ sub extracttar {
       $skipgemdata = 1;
     }
     next if $skipgemdata && $c->{'type'} ne 'gemdata' && $c->{'name'} =~ /^data\//;
-    if (exists $c->{'extract'}) {
+    if (exists $c->{'content'}) {
+      my $s = $c->{'size'};
+      while ($s > 0) {
+	my $l = $s > 16384 ? 16384 : $s;
+	$l = sysread(F, $c->{'content'}, $l, length($c->{'content'}));
+	die("tar read error\n") unless $l;
+	$s -= $l;
+      }
+    } elsif (exists $c->{'extract'}) {
       open(G, '>', $c->{'extract'}) || die("$c->{'extract'}: $!\n");
       my $s = $c->{'size'};
       while ($s > 0) {
@@ -185,9 +314,9 @@ sub cpiomode {
     $mm .= $m & $b ? $_ : '-';
     $b >>= 1;
   }
-  substr($mm, 2, 1) = substr($mm, 2, 1) eq 'x' ? 'S' : 's' if $m & 0x800;
-  substr($mm, 5, 1) = substr($mm, 5, 1) eq 'x' ? 'S' : 's' if $m & 0x400;
-  substr($mm, 8, 1) = substr($mm, 8, 1) eq 'x' ? 'T' : 'T' if $m & 0x200;
+  substr($mm, 2, 1) = substr($mm, 2, 1) eq 'x' ? 's' : 'S' if $m & 0x800;
+  substr($mm, 5, 1) = substr($mm, 5, 1) eq 'x' ? 's' : 'S' if $m & 0x400;
+  substr($mm, 8, 1) = substr($mm, 8, 1) eq 'x' ? 't' : 'T' if $m & 0x200;
   return $mm;
 }
 
@@ -214,16 +343,20 @@ sub listextractcpio {
     $name = substr($name, 0, $nsize);
     $name =~ s/\0.*//s;
     my $type = $mode & 0xf000;
-    if ($type == 0x4000) {
-      $type = 'd';
+    if ($type == 0x1000) {
+      $type = 'p';
     } elsif ($type == 0x2000) {
       $type = 'c';
     } elsif ($type == 0x4000) {
+      $type = 'd';
+    } elsif ($type == 0x6000) {
       $type = 'b';
     } elsif ($type == 0x8000) {
       $type = '-';
     } elsif ($type == 0xa000) {
       $type = 'l';
+    } elsif ($type == 0xc000) {
+      $type = 's';
     } else {
       $type = '?';
     }
@@ -236,7 +369,8 @@ sub listextractcpio {
     my $fsizepad = 0;
     $fsizepad = 4 - ($fsize & 3) if $fsize & 3;
     my $info = $type eq 'l' ? '' : 'd41d8cd98f00b204e9800998ecf8427e';
-    if ($x) {
+    my $tomem = $x && exists($x->{'content'});
+    if ($x && !$tomem) {
       open(G, '>', $x->{'extract'}) || die("$x->{'extract'}: $!\n");
     }
     if ($fsize > 0) {
@@ -247,12 +381,16 @@ sub listextractcpio {
 	die("cpio read error body\n") unless (read(F, $data, $chunk) || 0) == $chunk;
 	$ctx->add($data);
 	$info .= $data if $type eq 'l';
-	print G $data if $x;
+	if ($tomem) {
+	  $x->{'content'} .= $data;
+	} elsif ($x) {
+	  print G $data;
+	}
 	$fsize -= $chunk;
       }
       $info = $ctx->hexdigest() unless $type eq 'l';
     }
-    close(G) if $x;
+    close(G) if $x && !$tomem;
     $c[-1]->{'info'} = $info if $type eq '-' || $type eq 'l';
     die("cpio read error bodypad\n") unless (read(F, $name, $fsizepad) || 0) == $fsizepad;
   }
@@ -261,20 +399,108 @@ sub listextractcpio {
 }
 
 
+sub filediff_libxdiff_check {
+  my ($f, $content) = @_;
+  return '' unless defined($f);
+  return $f if ref($f);
+  return undef if $f =~ /\.(?:gz|bz2|xz)$/;
+  if (!defined($content)) {
+    return undef unless -e $f;
+    return undef if -s _ > 65536;
+    $content = readstr($f, 1);
+    return undef unless defined $content;
+  }
+  return undef if $content =~ /\0/s;	# can't handle
+  my $ff = substr($content, 0, 4096);
+  my $bcnt = $ff =~ tr/\000-\007\016-\037/\000-\007\016-\037/;
+  return undef if $bcnt * 40 > length($ff);
+  return $content;
+}
+
+#
+# diff file f1 against file f2 using libxdiff
+#
+sub filediff_libxdiff {
+  my ($f1, $f2, %opts) = @_;
+
+  my $max = $opts{'fmax'};
+  my $maxc = defined($max) ? $max * 80 : undef;
+  $maxc = $opts{'fmaxc'} if exists $opts{'fmaxc'};
+
+  my $d = Diff::LibXDiff->diff(!defined($f1) || ref($f1) ? '' : $f1, !defined($f2) || ref($f2) ? '' : $f2);
+  my $lcnt = $d =~ tr/\n/\n/;
+  my $ccnt = 0;
+  if (defined($max)) {
+    if ($max <= 0) {
+      $d = '';
+    } elsif ($max < $lcnt) {
+      my @tmp = split("\n", $d, $max + 1);
+      pop(@tmp);
+      $d = join("\n", @tmp)."\n";
+    }
+  }
+  if (defined($maxc)) {
+    if ($maxc <= 0) {
+      $ccnt = $d =~ tr/\n/\n/;
+    } elsif (length($d) > $maxc) {
+      my $out = substr($d, $maxc);
+      $d = substr($d, 0, $maxc);
+      $d =~ s/[^\n]*\Z//s;
+      $ccnt = $out =~ tr/\n/\n/;
+    }
+  }
+  if (defined($f1) && ref($f1) && @$f1) {
+    $d = "-".join("\n-", @$f1)."\n$d";
+    $lcnt += @$f1;
+  }
+  if (defined($f2) && ref($f2) && @$f2) {
+    $d .= "+".join("\n+", @$f2)."\n";
+    $lcnt += @$f2;
+  }
+  my $ret = {};
+  if (!defined($f1)) {
+    $ret->{'state'} = 'added';
+  } elsif (!defined($f2)) {
+    $ret->{'state'} = 'deleted';
+  } else {
+    $ret->{'state'} = 'changed';
+  }
+  $ret->{'lines'} = $lcnt;
+  $ret->{'shown'} = $max if defined($max) && $lcnt > $max;
+  $ret->{'shown'} = ($ret->{'shown'} || $ret->{'lines'}) - $ccnt if $ccnt;
+  $ret->{'_content'} = $d;
+  return $ret;
+}
+
 #
 # diff file f1 against file f2
 #
 sub filediff {
   my ($f1, $f2, %opts) = @_;
 
-  my $nodecomp = $opts{'nodecomp'};
-  my $arg = $opts{'diffarg'} || '-u';
-  my $max = $opts{'fmax'};
-
   if (!defined($f1) && !defined($f2)) {
     return { 'lines' => 0 , '_content' => ''};
   }
 
+  my $diffarg = $opts{'diffarg'} || '-u';
+
+  if ($havelibxdiff && $diffarg eq '-u') {
+    my ($c1, $c2);
+    if (!defined($f1) || defined($c1 = filediff_libxdiff_check($f1))) {
+      if (!defined($f2) || defined($c2 = filediff_libxdiff_check($f2))) {
+        return filediff_libxdiff($c1, $c2, %opts);
+      }
+    }
+  }
+
+  return filediff_batcher(@_) if $batcherpid;
+
+  my $nodecomp = $opts{'nodecomp'};
+  my $max = $opts{'fmax'};
+  my $maxc = defined($max) ? $max * 80 : undef;
+  $maxc = $opts{'fmaxc'} if exists $opts{'fmaxc'};
+
+
   local *D;
   my $pid = open(D, '-|');
   if (!$pid) {
@@ -304,10 +530,11 @@ sub filediff {
     }
     fcntl(F1, F_SETFD, 0);
     fcntl(F2, F_SETFD, 0);
-    exec 'diff', $arg, '/dev/fd/'.fileno(F1), '/dev/fd/'.fileno(F2);
+    exec '/usr/bin/diff', $diffarg, '/dev/fd/'.fileno(F1), '/dev/fd/'.fileno(F2);
     die("diff: $!\n");
   }
   my $lcnt = $opts{'linestart'} || 0;
+  my $ccnt = 0;
   my $d = '';
   my $havediff;
   my $binary;
@@ -330,7 +557,11 @@ sub filediff {
     }
     $lcnt++;
     if (!defined($max) || $lcnt <= $max) {
-      $d .= $_;
+      if (defined($maxc) && length($d) + length($_) > $maxc) {
+	$ccnt++;
+      } else {
+        $d .= $_;
+      }
     }
   }
   close(D);
@@ -343,9 +574,10 @@ sub filediff {
       $havediff = 0;
       $binary = 1;
       $lcnt = $opts{'linestart'} || 0;
+      $ccnt = 0;
     }
   }
-  if ($d eq '' && !$havediff && ((defined($f1) && ref($f1)) || defined($f2) && ref($f2))) {
+  if (!$havediff && ((defined($f1) && ref($f1)) || defined($f2) && ref($f2))) {
     $havediff = 1;
     if (defined($f1) && ref($f1)) {
       $d .= "-$_\n" for @$f1;
@@ -367,12 +599,13 @@ sub filediff {
   $ret->{'binary'} = 1 if $binary;
   $ret->{'lines'} = $lcnt;
   $ret->{'shown'} = $max if defined($max) && $lcnt > $max;
+  $ret->{'shown'} = ($ret->{'shown'} || $ret->{'lines'}) - $ccnt if $ccnt;
   $ret->{'_content'} = $d;
   return $ret;
 }
 
 sub fixup {
-  my ($e) = @_;
+  my ($e, $nowrite) = @_;
   return undef unless defined $e;
   if ($e->{'type'} eq 'd') {
     return [ '(directory)' ];
@@ -383,12 +616,26 @@ sub fixup {
   } elsif ($e->{'type'} eq 'l') {
     return [ "(symlink to $e->{info})" ];
   } elsif ($e->{'type'} eq '-') {
+    writestr($e->{'extract'}, undef, $e->{'content'}) if !$nowrite && exists $e->{'content'};
     return $e->{'size'} ? $e->{'extract'} : undef;
   } else {
     return [ "(unknown type $e->{type})" ];
   }
 }
 
+sub filediff_fixup {
+  my ($f1, $f2, %opts) = @_;
+  if ($havelibxdiff && ($opts{'diffarg'} || '-u') eq '-u') {
+    my ($c1, $c2);
+    if (!$f1 || defined($c1 = filediff_libxdiff_check(fixup($f1, 1), $f1->{'content'}))) {
+      if (!$f2 || defined($c2 = filediff_libxdiff_check(fixup($f2, 1), $f2->{'content'}))) {
+        return filediff_libxdiff($c1, $c2, %opts);
+      }
+    }
+  }
+  return filediff(fixup($f1), fixup($f2), %opts);
+}
+
 sub adddiffheader {
   my ($r, $p1, $p2) = @_;
   my ($h, $hl);
@@ -396,11 +643,15 @@ sub adddiffheader {
   $r->{'_content'} = '' unless defined $r->{'_content'};
   if ($r->{'binary'}) {
     if (defined($p1) && defined($p2) && $state eq 'changed') {
-      $h = "Binary files $p1 and $p2 differ\n";
+      if ($p1 eq $p2) {
+        $h = "Binary file $p1 differs\n";
+      } else {
+        $h = "Binary files $p1 and $p2 differ\n";
+      }
     } elsif (defined($p1) && $state ne 'added') {
-      $h = "Binary files $p1 deleted\n";
+      $h = "Binary file $p1 deleted\n";
     } elsif (defined($p2) && $state ne 'deleted') {
-      $h = "Binary files $p2 added\n";
+      $h = "Binary file $p2 added\n";
     }
     $hl = 1;
   } else {
@@ -430,16 +681,6 @@ sub adddiffheader {
   return $r->{'_content'};
 }
 
-# strip first dir if it is the same for all files
-sub stripfirstdir {
-  my ($l) = @_;
-  return unless @$l;
-  my $l1 = $l->[0]->{'sname'};
-  $l1 =~ s/\/.*//s;
-  return if grep {!($_->{'sname'} eq $l1 || $_->{'sname'} =~ /^\Q$l1\E\//)} @$l;
-  $_->{'sname'} =~ s/^[^\/]*\/?// for @$l;
-}
-
 sub listit {
   my ($f) = @_;
   return listgem($f) if $f =~ /\.gem$/;
@@ -453,125 +694,186 @@ sub extractit {
   return extracttar($f, $cp);
 }
 
+# find renamed files. currently only looks for same content
+sub findren {
+  my ($old, $new) = @_;
+
+  my %l1md5;
+  for my $f (grep {!$new->{$_}} sort keys %$old) {
+    my $l = $old->{$f};
+    next unless $l->{'type'} eq '-' && $l->{'size'};
+    $l1md5{$l->{'info'}} = $f;
+  }
+  my %ren;
+  for my $f (grep {!$old->{$_}} sort keys %$new) {
+    my $l = $new->{$f};
+    next unless $l->{'type'} eq '-' && $l->{'size'};
+    next unless exists $l1md5{$l->{'info'}};
+    my $of = $l1md5{$l->{'info'}};
+    $ren{$of} = $f;
+    $ren{$f} = $of;
+    delete $l1md5{$l->{'info'}};	# used up
+  }
+  return \%ren;
+}
+
+sub findtarfiles {
+  my ($files) = @_;
+
+  my @names = map {$_->{'name'}} @$files;
+  # strip ./ prefix
+  s/^\.\/// for @names;
+  if (@names) {
+    # strip first dir if it is the same for all files
+    my $l1 = $names[0];
+    if ($l1 =~ s/\/.*//s || $files->[0]->{'type'} eq 'd') {
+      if (!grep {!($_ eq $l1 || $_ =~ /^\Q$l1\E\//)} @names) {
+	for (@names) {
+          s/^[^\/]*\/?//;
+	  $_ = '.' if $_ eq '';
+	}
+      }
+    }
+  }
+  # exclude some files
+  for (@names) {
+    $_ = '' if "/$_/" =~ /\/(?:CVS|\.cvsignore|\.svn|\.svnignore)\//;
+  }
+  my %l;
+  $l{shift @names} = $_ for @$files;
+  delete $l{''};
+  return \%l;
+}
+
 sub tardiff {
   my ($f1, $f2, %opts) = @_;
 
   my $max = $opts{'tmax'};
+  my $maxc = defined($max) ? $max * 80 : undef;
+  $maxc = $opts{'tmaxc'} if exists $opts{'tmaxc'};
+  my $tfmax = $opts{'tfmax'};
+  my $tfmaxc = $opts{'tfmaxc'};
   my $edir = $opts{'edir'};
+  die("doarchive needs the edir option\n") unless $edir;
 
   my @l1 = listit($f1);
   my @l2 = listit($f2);
 
-  die unless $edir;
-  for (@l1, @l2) {
-    $_->{'sname'} = $_->{'name'};
-    $_->{'sname'} =~ s/^\.\///;
-  }
-  stripfirstdir(\@l1);
-  stripfirstdir(\@l2);
+  # find the files we want to diff
+  my $t1 = findtarfiles(\@l1);
+  my $t2 = findtarfiles(\@l2);
 
-  for (@l1, @l2) {
-    $_->{'sname'} = '' if "/$_->{'sname'}/" =~ /\/(?:CVS|\.cvsignore|\.svn|\.svnignore)\//;
-  }
+  # find renamed files
+  my $ren = findren($t1, $t2);
 
-  my %l1 = map {$_->{'sname'} => $_} @l1;
-  my %l2 = map {$_->{'sname'} => $_} @l2;
-  my %l3 = (%l1, %l2);
-  my @f = sort keys %l3;
-
-  my %l1md5;
-  for (@l1) {
-    next unless $_->{'type'} eq '-' && $_->{'size'} && $_->{'sname'} ne '';
-    $l1md5{$_->{'info'}} = $_;
-  }
-  my %ren;
-  for my $l2 (@l2) {
-    next unless $l2->{'type'} eq '-' && $l2->{'size'};
-    my $f = $l2->{'sname'};
-    next if $f eq '' || $l1{$f};
-    my $l1 = $l1md5{$l2->{'info'}};
-    next unless $l1 && !$l2{$l1->{'sname'}};
-    $ren{$l1->{'sname'}} = $f;
-    $ren{$f} = $l1->{'sname'};
-    delete $l1md5{$l2->{'info'}};	# used up
-  }
+  my @f = sort keys %{ { %$t1, %$t2 } };
 
   my $e1cnt = 0;
   my $e2cnt = 0;
-
   my @efiles;
+  my $memsize = 50000000;
   for my $f (@f) {
-    next if $f eq '';
-    next if $ren{$f};
-    my $suf1 = '';
-    $suf1 = $1 if $l1{$f} && $l1{$f}->{'name'} =~ /(\.[gx]z)$/;
-    my $suf2 = '';
-    $suf2 = $1 if $l2{$f} && $l2{$f}->{'name'} =~ /(\.[gx]z)$/;
-    if ($l1{$f} && $l2{$f}) {
-      next if $l1{$f}->{'type'} ne $l2{$f}->{'type'};
-      next if $l1{$f}->{'type'} ne '-';
-      next if $l1{$f}->{'info'} eq $l2{$f}->{'info'};
-      $l1{$f}->{'extract'} = "$edir/a$e1cnt$suf1";
-      push @efiles, "$edir/a$e1cnt$suf1";
+    my $l1 = $t1->{$f};
+    my $l2 = $t2->{$f};
+    if (exists $ren->{$f}) {
+      next unless $l2;
+      $l1 = $t1->{$ren->{$f}};
+    }
+    next if $l1 && $l2 && $l1->{'type'} eq $l2->{'type'} && $l1->{'info'} eq $l2->{'info'};
+    if ($l1 && $l1->{'size'} && $l1->{'type'} eq '-') {
+      my $suf1 = '';
+      $suf1 = ".$1" if $l1->{'name'} =~ /\.(gz|xz|bz2)$/;
+      my $exfile = "$edir/a$e1cnt$suf1";
+      $l1->{'extract'} = $exfile;
+      push @efiles, $exfile;
       $e1cnt++;
-      $l2{$f}->{'extract'} = "$edir/b$e2cnt$suf2";
-      push @efiles, "$edir/b$e2cnt$suf2";
-      $e2cnt++;
-    } elsif ($l1{$f} && $l1{$f}->{'size'}) {
-      $l1{$f}->{'extract'} = "$edir/a$e1cnt$suf1";
-      push @efiles, "$edir/a$e1cnt$suf1";
-      $e1cnt++;
-    } elsif ($l2{$f} && $l2{$f}->{'size'}) {
-      $l2{$f}->{'extract'} = "$edir/b$e2cnt$suf2";
-      push @efiles, "$edir/b$e2cnt$suf2";
+    }
+    if ($l2 && $l2->{'size'} && $l2->{'type'} eq '-') {
+      my $suf2 = '';
+      $suf2 = ".$1" if $l2->{'name'} =~ /\.(gz|xz|bz2)$/;
+      my $exfile = "$edir/b$e2cnt$suf2";
+      $l2->{'extract'} = $exfile;
+      push @efiles, $exfile;
       $e2cnt++;
     }
+    if ($havelibxdiff) {
+      # extract small files to memory
+      if ($l1 && $l1->{'extract'} && $l1->{'size'} < 100000 && $memsize > 0) {
+	$l1->{'content'} = '';
+	$memsize -= $l1->{'size'};
+      }
+      if ($l2 && $l2->{'extract'} && $l2->{'size'} < 100000 && $memsize > 0) {
+	$l2->{'content'} = '';
+	$memsize -= $l2->{'size'};
+      }
+    }
   }
+
   if ($e1cnt || $e2cnt) {
+    # need to extract some files
     if (! -d $edir) {
       mkdir($edir) || die("mkdir $edir: $!\n");
     }
     extractit($f1, \@l1) if $e1cnt;
     extractit($f2, \@l2) if $e2cnt;
   }
+
+  startbatcher() if $e1cnt + $e2cnt > 100 || ($e1cnt + $e2cnt > 10 && @f > 20000);
+
   my $lcnt = 0;
   my $d = '';
   my @ret;
-  my $fmax = $max;
+  my $ccnt = 0;
   for my $f (@f) {
-    next if $f eq '';
-    if ($ren{$f}) {
-      my $r = {'lines' => 1, 'name' => $f};
-      if ($l1{$f}) {
-	$r->{'_content'} = "(renamed to $ren{$f})\n";
-	$r->{'new'} = {'name' => $ren{$f}, 'md5' => $l1{$f}->{'info'}, 'size' => $l1{$f}->{'size'}};
-      } else {
-	$r->{'_content'} = "(renamed from $ren{$f})\n";
-	$r->{'new'} = {'name' => $f, 'md5' => $l2{$f}->{'info'}, 'size' => $l2{$f}->{'size'}};
+    my $l1 = $t1->{$f};
+    my $l2 = $t2->{$f};
+    next unless $l1 || $l2;
+    if ($ren->{$f}) {
+      if (!$l1) {
+	my $r = {'name' => $f, 'lines' => 1, '_content' => "(renamed from $ren->{$f})\n"};
+	$r->{'new'} = {'name' => $f, 'md5' => $l2->{'info'}, 'size' => $l2->{'size'}};
+	push @ret, $r;
+	$lcnt += $r->{'lines'};
+	next;
+      }
+      $l2 = $t2->{$ren->{$f}};
+      # no need to diff if identical
+      if ($l1->{'type'} eq $l2->{'type'} && $l1->{'info'} eq $l2->{'info'}) {
+	my $r = {'name' => $f, 'lines' => 1, '_content' => "(renamed to $ren->{$f})\n"};
+	$r->{'old'} = {'name' => $f, 'md5' => $l1->{'info'}, 'size' => $l1->{'size'}};
+	$r->{'new'} = {'name' => $ren->{$f}, 'md5' => $l2->{'info'}, 'size' => $l2->{'size'}};
+	$lcnt += $r->{'lines'};
+	next;
       }
-      push @ret, $r;
-      $lcnt += $r->{'lines'};
-      next;
     }
-    next unless $l1{$f} || $l2{$f};
-    if ($l1{$f} && $l2{$f}) {
-      next if $l1{$f}->{'type'} eq $l2{$f}->{'type'} && (!defined($l1{$f}->{'info'}) || $l1{$f}->{'info'} eq $l2{$f}->{'info'});
-      next if $l1{$f}->{'type'} eq 'gemdata' && $l2{$f}->{'type'} eq 'gemdata';
+    if ($l1 && $l2) {
+      next if $l1->{'type'} eq $l2->{'type'} && (!defined($l1->{'info'}) || $l1->{'info'} eq $l2->{'info'});
+      next if $l1->{'type'} eq 'gemdata' && $l2->{'type'} eq 'gemdata';
     }
+    my $fmax;
     $fmax = $max > $lcnt ? $max - $lcnt : 0 if defined $max;
-    my $r = filediff(fixup($l1{$f}), fixup($l2{$f}), %opts, 'fmax' => $fmax);
+    $fmax = $tfmax if defined($tfmax) && (!defined($fmax) || $fmax > $tfmax);
+    my $r = filediff_fixup($l1, $l2, %opts, 'fmax' => $fmax, 'fmaxc' => $tfmaxc);
     $r->{'name'} = $f;
-    $r->{'old'} = {'name' => $f, 'md5' => $l1{$f}->{'info'}, 'size' => $l1{$f}->{'size'}} if $l1{$f};
-    $r->{'new'} = {'name' => $f, 'md5' => $l2{$f}->{'info'}, 'size' => $l2{$f}->{'size'}} if $l2{$f};
+    $r->{'old'} = {'name' => $f, 'md5' => $l1->{'info'}, 'size' => $l1->{'size'}} if $l1;
+    $r->{'new'} = {'name' => $f, 'md5' => $l2->{'info'}, 'size' => $l2->{'size'}} if $l2;
+    if ($ren->{$f}) {
+      $r->{'new'}->{'name'} = $ren->{$f};
+      $r->{'_content'} = "(renamed to $ren->{$f})\n" . ($r->{'content'} || '');
+      $r->{'lines'} = ($r->{'lines'} || 0) + 1;
+    }
     push @ret, $r;
-    $lcnt += $r->{'lines'};
+    $lcnt += $r->{'shown'} || $r->{'lines'};
+    $ccnt += length($r->{'_content'}) if exists $r->{'_content'};
   }
-  if (defined($max) && $lcnt > $max) {
+  if ((defined($max) && $lcnt > $max) || (defined($maxc) && $ccnt > $maxc)) {
     my $r = {'lines' => $lcnt, 'shown' => 0};
     @ret = ($r);
   }
   unlink($_) for @efiles;
   rmdir($edir);
+
+  endbatcher();
   return @ret;
 }
 
@@ -580,28 +882,20 @@ my @simclasses = (
   'dsc',
   'changes',
   '(?:diff?|patch)(?:\.gz|\.bz2|\.xz)?',
-  '(?:tar|tar\.gz|tar\.bz2|tar\.xz|tgz|tbz|gem|obscpio)',
+  '(?:tar|tar\.gz|tar\.bz2|tar\.xz|tgz|tbz|gem|obscpio|livebuild)',
 );
 
 sub findsim {
-  my ($of, @f) = @_;
+  my ($old, $new) = @_;
 
-  my %s = map {$_ => 1} @$of;	# old file pool
-  my %sim;
+  # find free files
+  my @f = grep {!exists($old->{$_})} sort keys %$new;
+  my @of = grep {!exists($new->{$_})} sort keys %$old;
 
+  # classify them
   my %fc;	# file base name
   my %ft;	# file class
-
-  for my $f (@f) {
-    if ($s{$f}) {
-      $sim{$f} = $f;	# trivial mapped
-      delete $s{$f};
-    }
-  }
-
-  # classify all files
-  for my $f (@f, @$of) {
-    next if $sim{$f};	# trivial mapped
+  for my $f (@f, @of) {
     next unless $f =~ /\./;
     next if exists $fc{$f};
     for my $sc (@simclasses) {
@@ -613,6 +907,7 @@ sub findsim {
       }
       $fc =~ s/\.bz2$//;
       $fc =~ s/\.gz$//;
+      $fc =~ s/\.xz$//;
       next if $fc =~ /\.(?:spec|dsc|changes)$/;	# no compression here!
       if ($fc =~ /^(.*)\.([^\/]+)$/) {
 	$fc{$f} = $1;
@@ -621,6 +916,9 @@ sub findsim {
     }
   }
 
+  my %sim;
+  my %s = map {$_ => 1} @of;	# old file pool
+
   # first pass: exact matches
   for my $f (grep {!exists($sim{$_})} @f) {
     my $fc = $fc{$f};
@@ -628,12 +926,31 @@ sub findsim {
     next unless defined $fc;
     my @s = grep {defined($fc{$_}) && $fc{$_} eq $fc && $ft{$_} eq $ft} sort keys %s;
     if (@s) {
+      unshift @s, grep {$old->{$_} eq $new->{$f}} @s if @s > 1;
       $sim{$f} = $s[0];
+      $sim{$s[0]} = $f;
       delete $s{$s[0]};
     }
   }
 
-  # second pass: ignore version
+  # second pass: ignore version, but same content
+  for my $f (grep {!exists($sim{$_})} @f) {
+    my $fc = $fc{$f};
+    my $ft = $ft{$f};
+    next unless defined $fc;
+    my @s = grep {defined($ft{$_}) && $ft{$_} eq $ft} sort keys %s;
+    my $fq = "\Q$fc\E";
+    $fq =~ s/\\\././g;
+    $fq =~ s/[0-9.]+/.*/g;
+    @s = grep {/^$fq$/ && $old->{$_} eq $new->{$f}} @s;
+    if (@s) {
+      $sim{$f} = $s[0];
+      $sim{$s[0]} = $f;
+      delete $s{$s[0]};
+    }
+  }
+
+  # third pass: ignore version
   for my $f (grep {!exists($sim{$_})} @f) {
     my $fc = $fc{$f};
     my $ft = $ft{$f};
@@ -644,52 +961,44 @@ sub findsim {
     $fq =~ s/[0-9.]+/.*/g;
     @s = grep {/^$fq$/} @s;
     if (@s) {
+      unshift @s, grep {$old->{$_} eq $new->{$f}} @s if @s > 1;
       $sim{$f} = $s[0];
+      $sim{$s[0]} = $f;
       delete $s{$s[0]};
     }
   }
 
-  #for my $f (@f) {
-  #  print "$f -> $sim{$f}\n";
-  #}
   return \%sim;
 }
 
 
+# return the filename of a resource
 sub fn {
-  my ($dir, $f, $md5) = @_;
-  return $dir->($f, $md5) if ref($dir);
-  return "$dir/$md5-$f";
+  my ($dir, $f) = @_;
+  return undef unless defined $f;
+  return ref($dir) ? $dir->($f) : "$dir/$f";
 }
 
 sub srcdiff {
-  my ($pold, $old, $orev, $pnew, $new, $rev, %opts) = @_;
+  my ($pold, $old, $pnew, $new, %opts) = @_;
 
   my $d = '';
   my $fmax = $opts{'fmax'};
 
   my @old = sort keys %$old;
   my @new = sort keys %$new;
-  my $sim = findsim(\@old, @new);
+  my $sim = $opts{'similar'} ? findsim($old, $new) : {};
 
   for my $extra ('changes', 'filelist', 'spec', 'dsc') {
     if ($extra eq 'filelist') {
-      my @xold = sort keys %$old;
-      my @xnew = sort keys %$new;
-      my %xold = map {$_ => 1} @xold;
-      my %xnew = map {$_ => 1} @xnew;
-      @xnew = grep {!$xold{$_}} @xnew;
-      @xold = grep {!$xnew{$_}} @xold;
+      my @xold = grep {!exists($new->{$_})} sort keys %$old;
+      my @xnew = grep {!exists($old->{$_})} sort keys %$new;
       if (@xold) {
-	$d .= "\n";
-	$d .= "old:\n";
-	$d .= "----\n";
+	$d .= "\nold:\n----\n";
 	$d .= "  $_\n" for @xold;
       }
       if (@xnew) {
-	$d .= "\n";
-	$d .= "new:\n";
-	$d .= "----\n";
+	$d .= "\nnew:\n----\n";
 	$d .= "  $_\n" for @xnew;
       }
       next;
@@ -702,26 +1011,22 @@ sub srcdiff {
       $d .= "$extra files:\n";
       $d .= "-------".('-' x length($extra))."\n";
     }
-    my $arg = '-ub';
-    $arg = '-U0' if $extra eq 'changes';
+    my $diffarg = '-ub';
+    $diffarg = '-U0' if $extra eq 'changes';
     for my $f (@xnew) {
+      my $of;
       if ($xold{$f}) {
-	my $of = $f;
+	$of = $f;
 	delete $xold{$of};
 	next if $old->{$of} eq $new->{$f};
-	my $r = filediff(fn($pold, $of, $old->{$of}), fn($pnew, $f, $new->{$f}), %opts, 'diffarg' => $arg, 'fmax' => undef);
-	$d .= adddiffheader($r, $of, $f);
-      } else {
-	$d .= "\n++++++ new $extra file:\n";
-	my $r = filediff(undef, fn($pnew, $f, $new->{$f}), %opts, 'diffarg' => $arg, 'fmax' => undef);
-	$d .= adddiffheader($r, undef, $f);
       }
+      $d .= "\n++++++ new $extra file:\n" unless defined $of;
+      my $r = filediff(fn($pold, $of), fn($pnew, $f), %opts, 'diffarg' => $diffarg, 'fmax' => undef);
+      $d .= adddiffheader($r, $of, $f);
     }
     if (%xold) {
       $d .= "\n++++++ deleted $extra files:\n";
-      for my $f (sort keys %xold) {
-	$d .= "--- $f\n";
-      }
+      $d .= "--- $_\n" for sort keys %xold;
     }
     @old = grep {!/\.$extra$/} @old;
     @new = grep {!/\.$extra$/} @new;
@@ -734,52 +1039,45 @@ sub srcdiff {
     $d .= "--------------\n";
   }
   for my $f (@new) {
-    my $of = $sim->{$f};
+    my $of = exists($sim->{$f}) ? $sim->{$f} : defined($old->{$f}) ? $f : undef;
     if (defined $of) {
       delete $oold{$of};
       $d .= "\n++++++ $of -> $f\n" if $of ne $f;
       next if $old->{$of} eq $new->{$f};
       $d .= "\n++++++ $f\n" if $of eq $f;
+    } else {
+      $d .= "\n++++++ $f (new)\n";
     }
-    if ($f =~ /\.(?:tgz|tar\.gz|tar\.bz2|tbz|tar\.xz|gem|obscpio)$/) {
+    if ($opts{'doarchive'} && $f =~ /\.(?:tar|tgz|tar\.gz|tar\.bz2|tbz|tar\.xz|gem|obscpio|livebuild)$/) {
       if (defined $of) {
-	my @r = tardiff(fn($pold, $of, $old->{$of}), fn($pnew, $f, $new->{$f}), %opts);
+	my @r = tardiff(fn($pold, $of), fn($pnew, $f), %opts);
 	for my $r (@r) {
 	  $d .= adddiffheader($r, $r->{'name'}, $r->{'name'});
 	}
-	next;
-      } else {
-	$d .= "\n++++++ $f (new)\n";
-	next;
       }
+      next;
     }
-    if (defined $of) {
-      my $r = filediff(fn($pold, $of, $old->{$of}), fn($pnew, $f, $new->{$f}), %opts);
-      $d .= adddiffheader($r, $of, $f);
-    } else {
-      $d .= "\n++++++ $f (new)\n";
-      my $r = filediff(undef, fn($pnew, $f, $new->{$f}), %opts);
-      $d .= adddiffheader($r, $of, $f);
-    }
+    my $r = filediff(fn($pold, $of), fn($pnew, $f), %opts);
+    $d .= adddiffheader($r, $of, $f);
   }
   if (%oold) {
     $d .= "\n++++++ deleted files:\n";
-    for my $f (sort keys %oold) {
-      $d .= "--- $f\n";
-    }
+    $d .= "--- $_\n" for sort keys %oold;
   }
   return $d;
 }
 
-sub udiff {
-  my ($pold, $old, $orev, $pnew, $new, $rev, %opts) = @_;
+sub unifieddiff {
+  my ($pold, $old, $pnew, $new, %opts) = @_;
 
-  $opts{'nodecomp'} = 1;
+  my $sim = $opts{'similar'} ? findsim($old, $new) : {};
   my @changed;
   my @added;
   my @deleted;
   for (sort(keys %{ { %$old, %$new } })) {
-    if (!defined($old->{$_})) {
+    if (defined($sim->{$_}) && $sim->{$_} ne $_) {
+      push @changed, $_ if $new->{$_};
+    } elsif (!defined($old->{$_})) {
       push @added, $_;
     } elsif (!defined($new->{$_})) {
       push @deleted, $_;
@@ -787,62 +1085,77 @@ sub udiff {
       push @changed, $_;
     }
   }
-  my $orevb = $orev && defined($orev->{'rev'}) ? " (revision $orev->{'rev'})" : '';
-  my $revb = $rev && defined($rev->{'rev'}) ? " (revision $rev->{'rev'})" : '';
+  my $orevb = defined($opts{'oldrevision'}) ? " (revision $opts{'oldrevision'})" : '';
+  my $revb = defined($opts{'newrevision'}) ? " (revision $opts{'newrevision'})" : '';
   my $d = '';
   for my $f (@changed) {
-    $d .= "Index: $f\n" . ("=" x 67) . "\n";
-    my $r = filediff(fn($pold, $f, $old->{$f}), fn($pnew, $f, $new->{$f}), %opts);
-    $d .= adddiffheader($r, "$f$orevb", "$f$revb");
+    my $of = defined($sim->{$f}) ? $sim->{$f} : $f;
+    if ($f ne $of) {
+      $d .= "Index: $of -> $f\n" . ("=" x 67) . "\n";
+    } else {
+      $d .= "Index: $f\n" . ("=" x 67) . "\n";
+    }
+    if ($opts{'doarchive'} && $f =~ /\.(?:tar|tgz|tar\.gz|tar\.bz2|tbz|tar\.xz|gem|obscpio|livebuild)$/) {
+      my @r = tardiff(fn($pold, $of), fn($pnew, $f), %opts);
+      for my $r (@r) {
+        $d .= adddiffheader($r, "$r->{'name'}$orevb", "$r->{'name'}$revb");
+      }
+      next;
+    }
+    my $r = filediff(fn($pold, $of), fn($pnew, $f), %opts);
+    $d .= adddiffheader($r, "$of$orevb", "$f$revb");
   }
   for my $f (@added) {
     $d .= "Index: $f\n" . ("=" x 67) . "\n";
-    my $r = filediff(undef, fn($pnew, $f, $new->{$f}), %opts);
+    if ($opts{'doarchive'} && $f =~ /\.(?:tar|tgz|tar\.gz|tar\.bz2|tbz|tar\.xz|gem|obscpio|livebuild)$/) {
+      my @r = tardiff(undef, fn($pnew, $f), %opts);
+      for my $r (@r) {
+        $d .= adddiffheader($r, "$r->{'name'} (added)", "$r->{'name'}$revb");
+      }
+      next;
+    }
+    my $r = filediff(undef, fn($pnew, $f), %opts);
     $d .= adddiffheader($r, "$f (added)", "$f$revb");
   }
   for my $f (@deleted) {
     $d .= "Index: $f\n" . ("=" x 67) . "\n";
-    my $r = filediff(fn($pold, $f, $old->{$f}), undef, %opts);
+    my $r = filediff(fn($pold, $f), undef, %opts);
     $d .= adddiffheader($r, "$f$orevb", "$f (deleted)");
   }
   return $d;
 }
 
 sub datadiff {
-  my ($pold, $old, $orev, $pnew, $new, $rev, %opts) = @_;
+  my ($pold, $old, $pnew, $new, %opts) = @_;
 
   my @changed;
   my @added;
   my @deleted;
 
-  my $sim;
-  if ($opts{'similar'}) {
-    $sim = findsim([ keys %$old ], keys %$new);
-  }
+  my $sim = $opts{'similar'} ? findsim($old, $new) : {};
 
   my %done;
   for my $f (sort(keys %$new)) {
-    my $of = $f;
-    $of = $sim->{$f} if defined $sim->{$f};
+    my $of = defined($sim->{$f}) ? $sim->{$f} : $f;
     $done{$of} = 1;
     if (!defined($old->{$of})) {
-      my @s = stat(fn($pnew, $f, $new->{$f}));
-      my $r = filediff(undef, fn($pnew, $f, $new->{$f}), %opts);
+      my @s = stat(fn($pnew, $f));
+      my $r = filediff(undef, fn($pnew, $f), %opts);
       delete $r->{'state'};
       push @added, {'state' => 'added', 'diff' => $r, 'new' => {'name' => $f, 'md5' => $new->{$f}, 'size' => $s[7]}};
     } elsif ($old->{$of} ne $new->{$f}) {
-      if ($opts{'doarchive'} && $f =~ /\.(?:tgz|tar\.gz|tar\.bz2|tbz|tar\.xz|gem|obscpio)$/) {
-	my @r = tardiff(fn($pold, $of, $old->{$of}), fn($pnew, $f, $new->{$f}), %opts);
+      if ($opts{'doarchive'} && $f =~ /\.(?:tar|tgz|tar\.gz|tar\.bz2|tbz|tar\.xz|gem|obscpio|livebuild)$/) {
+	my @r = tardiff(fn($pold, $of), fn($pnew, $f), %opts);
         if (@r == 0 && $f ne $of) {
 	  # (almost) identical tars but renamed
-	  my @os = stat(fn($pold, $of, $old->{$of}));
-          my @s = stat(fn($pnew, $f, $new->{$f}));
+	  my @os = stat(fn($pold, $of));
+          my @s = stat(fn($pnew, $f));
           push @changed, {'state' => 'renamed', 'old' => {'name' => $of, 'md5' => $old->{$of}, 'size' => $os[7]}, 'new' => {'name' => $f, 'md5' => $new->{$f}, 'size' => $s[7]}};
         }
         if (@r == 1 && !$r[0]->{'old'} && !$r[0]->{'new'}) {
 	  # tardiff was too big
-	  my @os = stat(fn($pold, $of, $old->{$of}));
-          my @s = stat(fn($pnew, $f, $new->{$f}));
+	  my @os = stat(fn($pold, $of));
+          my @s = stat(fn($pnew, $f));
           push @changed, {'state' => 'changed', 'diff' => $r[0], 'old' => {'name' => $of, 'md5' => $old->{$of}, 'size' => $os[7]}, 'new' => {'name' => $f, 'md5' => $new->{$f}, 'size' => $s[7]}};
           @r = ();
         }
@@ -858,21 +1171,21 @@ sub datadiff {
 	  delete $r->{'new'};
 	}
       } else {
-	my @os = stat(fn($pold, $of, $old->{$of}));
-        my @s = stat(fn($pnew, $f, $new->{$f}));
-	my $r = filediff(fn($pold, $of, $old->{$of}), fn($pnew, $f, $new->{$f}), %opts);
+	my @os = stat(fn($pold, $of));
+        my @s = stat(fn($pnew, $f));
+	my $r = filediff(fn($pold, $of), fn($pnew, $f), %opts);
 	delete $r->{'state'};
 	push @changed, {'state' => 'changed', 'diff' => $r, 'old' => {'name' => $of, 'md5' => $old->{$of}, 'size' => $os[7]}, 'new' => {'name' => $f, 'md5' => $new->{$f}, 'size' => $s[7]}};
       }
     } elsif ($f ne $of) {
-      my @os = stat(fn($pold, $of, $old->{$of}));
-      my @s = stat(fn($pnew, $f, $new->{$f}));
+      my @os = stat(fn($pold, $of));
+      my @s = stat(fn($pnew, $f));
       push @changed, {'state' => 'renamed', 'old' => {'name' => $of, 'md5' => $old->{$of}, 'size' => $os[7]}, 'new' => {'name' => $f, 'md5' => $new->{$f}, 'size' => $s[7]}};
     }
   }
   for my $of (grep {!$done{$_}} sort(keys %$old)) {
-    my @os = stat(fn($pold, $of, $old->{$of}));
-    my $r = filediff(fn($pold, $of, $old->{$of}), undef, %opts);
+    my @os = stat(fn($pold, $of));
+    my $r = filediff(fn($pold, $of), undef, %opts);
     delete $r->{'state'};
     push @added, {'state' => 'deleted', 'diff' => $r, 'old' => {'name' => $of, 'md5' => $old->{$of}, 'size' => $os[7]}};
   }
@@ -885,7 +1198,7 @@ sub issues {
     my @issues = $entry =~ /$tracker->{'regex'}/g;
     pop @issues if @issues & 1;	# hmm
     my %issues = @issues;
-    for (keys %issues) {
+    for (sort keys %issues) {
       my $label = $tracker->{'label'};
       $label =~ s/\@\@\@/$issues{$_}/g;
       $ret->{$label} = {
@@ -898,8 +1211,9 @@ sub issues {
 }
 
 sub issuediff {
-  my ($pold, $old, $orev, $pnew, $new, $rev, $trackers, %opts) = @_;
+  my ($pold, $old, $pnew, $new, %opts) = @_;
 
+  my $trackers = $opts{'trackers'};
   return [] unless @{$trackers || []};
 
   $trackers = [ @$trackers ];
@@ -919,12 +1233,12 @@ sub issuediff {
   my %oldchanges;
   my %newchanges;
   for my $f (grep {/\.changes$/} sort(keys %$old)) {
-    for (split(/------------------------------------------+/, readstr(fn($pold, $f, $old->{$f})))) {
+    for (split(/------------------------------------------+/, readstr(fn($pold, $f)))) {
       $oldchanges{Digest::MD5::md5_hex($_)} = $_;
     }
   }
   for my $f (grep {/\.changes$/} sort(keys %$new)) {
-    for (split(/------------------------------------------+/, readstr(fn($pnew, $f, $new->{$f})))) {
+    for (split(/------------------------------------------+/, readstr(fn($pnew, $f)))) {
       $newchanges{Digest::MD5::md5_hex($_)} = $_;
     }
   }
@@ -967,18 +1281,4 @@ sub issuediff {
   return [ @changed, @added, @deleted ];
 }
 
-sub diff {
-  my ($pold, $old, $orev, $pnew, $new, $rev, $fmax, $tmax, $edir, $unified) = @_;
-  my %opts;
-  $opts{'fmax'} = $fmax if defined $fmax;
-  $opts{'tmax'} = $tmax if defined $tmax;
-  $opts{'edir'} = $edir if defined $edir;
-  if ($unified) {
-    return udiff($pold, $old, $orev, $pnew, $new, $rev, %opts);
-  } else {
-    $opts{'doarchive'} = 1;
-    return srcdiff($pold, $old, $orev, $pnew, $new, $rev, %opts);
-  }
-}
-
 1;
