@@ -1,5 +1,6 @@
 #
 # Copyright (c) 2006, 2007 Michael Schroeder, Novell Inc.
+# Copyright (c) 2016  Frank Schreiner, SUSE LLC
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License version 2 as
@@ -16,12 +17,15 @@
 # 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 #
 ################################################################
-#
-# collection of useful functions
-#
 
 package BSUtil;
 
+=head1 NAME
+
+BSUtil - collection of useful functions
+
+=cut
+
 require Exporter;
 @ISA = qw(Exporter);
 @EXPORT = qw{writexml writestr readxml readstr ls mkdir_p xfork str2utf8 data2utf8 str2utf8xml data2utf8xml};
@@ -32,11 +36,18 @@ use Fcntl qw(:DEFAULT :flock);
 use Encode;
 use Storable ();
 use IO::Handle;
-
 use strict;
 
+# should we do a slow fdatasync?
 our $fdatasync_before_rename;
 
+# the current debug level
+my $debuglevel;
+
+=head1 FUNCTIONS / METHODS
+
+=cut
+
 sub set_fdatasync_before_rename {
   $fdatasync_before_rename = 1;
   if (!defined(&File::Sync::fdatasync_fd)) {
@@ -171,8 +182,13 @@ sub mkdir_p {
   return 1;
 }
 
-# calls mkdir_p and changes ownership of the created directory to the
-# supplied user and group if provided.
+=head2 mkdir_p_chown - create directory recursivly and change ownership
+
+ calls mkdir_p and changes ownership of the created directory to the
+ supplied user and group if provided.
+
+=cut
+
 sub mkdir_p_chown {
   my ($dir, $user, $group) = @_;
 
@@ -206,6 +222,7 @@ sub drop_privs_to {
   my ($user, $group) = @_;
 
   if (defined($group)) {
+    printlog("Drop privileges to group '$group'", 1);
     $group = getgrnam($group) unless $group =~ /^\d+$/;
     die("unknown group\n") unless defined $group;
     if ($) != $group || $( != $group) {
@@ -214,6 +231,7 @@ sub drop_privs_to {
     }
   }
   if (defined($user)) {
+    printlog("Drop privileges to user '$user'", 1);
     $user = getpwnam($user) unless $user =~ /^\d+$/;
     die("unknown user\n") unless defined $user;
     if ($> != $user || $< != $user) {
@@ -464,20 +482,19 @@ sub lockcreatexml {
   return 1;
 }
 
-sub isotime {
-  my ($t) = @_;
-  my @lt = localtime($t || time());
-  return sprintf "%04d-%02d-%02d %02d:%02d:%02d", $lt[5] + 1900, $lt[4] + 1, @lt[3,2,1,0];
-}
-
 # XXX: does that really belong here?
 #
-# Algorithm:
-# each enable/disable has a score:
-# +1 if it's a disable
-# +2 if the arch matches
-# +4 if the repo matches
-#
+
+=head2 enabled
+
+ Algorithm:
+ each enable/disable has a score:
+ +1 if it's a disable
+ +2 if the arch matches
+ +4 if the repo matches
+
+=cut
+
 sub enabled {
   my ($repoid, $disen, $default, $arch) = @_;
 
@@ -584,26 +601,57 @@ sub ping {
   }
 }
 
+sub drainping {
+  my ($ping) = @_; 
+  my $dummy;
+  fcntl($ping, F_SETFL, POSIX::O_NONBLOCK);
+  1 while (sysread($ping, $dummy, 1024, 0) || 0) > 0;
+  fcntl($ping, F_SETFL, 0); 
+}
+
+sub waitping {
+  my ($ping, $timeout) = @_; 
+
+  my $dummy;
+  if (!defined($timeout)) {
+    sysread($ping, $dummy, 1, 0); 
+    return;
+  }
+  fcntl($ping, F_SETFL, POSIX::O_NONBLOCK);
+  while ($timeout > 0) {
+    last if (sysread($ping, $dummy, 1024, 0) || 0) > 0;
+    sleep(1);
+    $timeout -= 1;
+  }
+  fcntl($ping, F_SETFL, 0); 
+}
+
 sub restartexit {
   my ($arg, $name, $runfile, $pingfile) = @_;
   return unless $arg;
+
+  # support option hash as arg
+  $arg = '--stop' if ref($arg) && $arg->{stop};
+  $arg = '--restart' if ref($arg) && $arg->{restart};
+  return if ref($arg);
+
   if ($arg eq '--stop' || $arg eq '--exit') {
     if (!(-e "$runfile.lock") || lockcheck('>>', "$runfile.lock")) {
       print "$name not running.\n";
       exit 0;
     }    
     print "exiting $name...\n";
-    BSUtil::touch("$runfile.exit");
+    touch("$runfile.exit");
     ping($pingfile) if $pingfile;
-    BSUtil::waituntilgone("$runfile.exit");
+    waituntilgone("$runfile.exit");
     exit(0);
   }
-  if ($ARGV[0] eq '--restart') {
-    die("$name not running.\n") if !(-e "$runfile.lock") || BSUtil::lockcheck('>>', "$runfile.lock");
+  if ($arg eq '--restart') {
+    die("$name not running.\n") if !(-e "$runfile.lock") || lockcheck('>>', "$runfile.lock");
     print "restarting $name...\n";
-    BSUtil::touch("$runfile.restart");
+    touch("$runfile.restart");
     ping($pingfile) if $pingfile;
-    BSUtil::waituntilgone("$runfile.restart");
+    waituntilgone("$runfile.restart");
     exit(0);
   }
 }
@@ -728,4 +776,54 @@ sub identical {
   return 1;
 }
 
+=head2 isotime - convert time to iso format
+
+ BSUtil::isotime($time);
+
+=cut
+
+sub isotime {
+  my ($t) = @_;
+  my @lt = localtime($t || time());
+  return sprintf "%04d-%02d-%02d %02d:%02d:%02d", $lt[5] + 1900, $lt[4] + 1, @lt[3,2,1,0];
+}
+
+=head2 getdebuglevel - get the current debug level
+
+ BSUtil::getdebuglevel();
+
+=cut
+
+sub getdebuglevel {
+  return $debuglevel;
+}
+
+=head2 setdebuglevel - set the current debug level
+
+ BSUtil::setdebuglevel($newlevel);
+
+=cut
+
+sub setdebuglevel {
+  my ($level) = @_;
+  my $oldlevel = $debuglevel;
+  $debuglevel = $level;
+  return $oldlevel;
+}
+
+=head2 printlog - print unified log messages
+
+  BSUtil::printlog($message [, $level]);
+
+FORMAT: "YYYY-MM-DD hh:mm:ss [$pid] $message"
+
+=cut
+
+sub printlog {
+  my ($msg, $level) = @_;
+  return if $level && !($debuglevel && $debuglevel >= $level);
+  $msg = "[debug $level] $msg" if $level;
+  printf "%s: %-7s %s\n", isotime(time), "[$$]", $msg;
+}
+
 1;
